@@ -2,11 +2,11 @@
 
 =head1 NAME
 
-to-8.2-realm-conf.pl
+to-10.1-realm-conf.pl
 
 =head1 DESCRIPTION
 
-Make all the realms tenant aware
+Add the eap configuration parameter.
 
 =cut
 
@@ -22,8 +22,10 @@ run_as_pf();
 my $ini = pf::IniFiles->new(-file => $realm_config_file, -allowempty => 1);
 
 for my $section ($ini->Sections()) {
-    next if $section =~ /^\d+ /;
-    $ini->RenameSection($section, "1 $section");
+    my $val = $ini->val($section, 'eap');
+    if (!defined($val)) {
+        $ini->newval($section, 'eap', 'default');
+    }
 }
 
 $ini->RewriteConfig();
@@ -34,7 +36,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
@@ -54,4 +56,3 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 USA.
 
 =cut
-
