@@ -28,10 +28,9 @@ configure_and_check() {
     VAGRANT_FORCE_COLOR=${VAGRANT_FORCE_COLOR:-true}
     VAGRANT_ANSIBLE_VERBOSE=${VAGRANT_ANSIBLE_VERBOSE:-false}
     VAGRANT_DIR=${VAGRANT_DIR:-'../../../addons/vagrant'}
-    VAGRANT_UP_OPTS=${VAGRANT_UP_OPTS:-'--destroy-on-error --no-parallel'}
+    VAGRANT_DOTFILE_PATH="${VAGRANT_DOTFILE_PATH:-${VAGRANT_DIR}/.vagrant}"
+    VAGRANT_UP_OPTS=${VAGRANT_UP_OPTS:-'--no-destroy-on-error --no-parallel'}
     CI_COMMIT_TAG=${CI_COMMIT_TAG:-}
-    # set to yes when testing new features on collections
-    LOCAL_COLLECTIONS=${LOCAL_COLLECTIONS:-no}    
     PF_VM_NAME=${PF_VM_NAME:-}
     INT_TEST_VM_NAMES=${INT_TEST_VM_NAMES:-}
 
@@ -51,21 +50,11 @@ configure_and_check() {
         RUN_TESTS=${INTEGRATION_TESTS}
     fi
     
-    declare -p VAGRANT_DIR VAGRANT_ANSIBLE_VERBOSE
+    declare -p VAGRANT_DIR VAGRANT_ANSIBLE_VERBOSE VAGRANT_DOTFILE_PATH
     declare -p CI_COMMIT_TAG
-    declare -p LOCAL_COLLECTIONS
     declare -p PF_VM_NAME INT_TEST_VM_NAMES
 }
 
-install_ansible_files() {
-    log_subsection "Install Ansible collections"
-    if [ "$LOCAL_COLLECTIONS" = "no" ]; then
-        ansible-galaxy collection install -r ${VAGRANT_DIR}/requirements.yml -p ${VAGRANT_DIR}/collections
-    else
-        echo "Using local collections"
-    fi
-}
-
 start_and_provision() {
     local vm_names=${@:-vmname}
     log_subsection "Start and provision $vm_names"
@@ -79,33 +68,47 @@ start_and_provision() {
 teardown() {
     log_section "Teardown"
     delete_ansible_files
-    halt_and_destroy ${PF_VM_NAME} ${INT_TEST_VM_NAMES}
+    destroy ${PF_VM_NAME} ${INT_TEST_VM_NAMES}
 }
 
 delete_ansible_files() {
     log_subsection "Remove Ansible files"
     delete_dir_if_exists ${VAGRANT_DIR}/roles
-    delete_dir_if_exists ${VAGRANT_DIR}/collections
+    delete_dir_if_exists ${VAGRANT_DIR}/ansible_collections
 }
 
-halt_and_destroy() {
-    log_subsection "Halt and destroy virtual machine(s)"
+halt() {
+    log_subsection "Halt virtual machine(s)"
     local vm_names=${@:-}
 
     # using "|| true" as a workaround to unusual behavior
     # see https://github.com/hashicorp/vagrant/issues/10024#issuecomment-404965057
     if [ -z "${vm_names}" ]; then
-        echo "Shutdown and destroy all VM"
+        echo "Shutdown all VM"
         ( cd $VAGRANT_DIR ; \
-          vagrant halt ; \
+          vagrant halt -f )
+    else
+        ( cd $VAGRANT_DIR ; \
+          vagrant halt -f ${vm_names} )
+    fi
+}
+
+destroy() {
+    log_subsection "Destroy virtual machine(s)"
+    local vm_names=${@:-}
+
+    # using "|| true" as a workaround to unusual behavior
+    # see https://github.com/hashicorp/vagrant/issues/10024#issuecomment-404965057
+    if [ -z "${vm_names}" ]; then
+        echo "Destroy all VM"
+        ( cd $VAGRANT_DIR ; \
           vagrant destroy -f || true )
-        delete_dir_if_exists ${VAGRANT_DIR}/.vagrant
+        delete_dir_if_exists ${VAGRANT_DOTFILE_PATH}
     else
         ( cd $VAGRANT_DIR ; \
-          vagrant halt ${vm_names} ; \
           vagrant destroy -f ${vm_names} || true )
         for vm in ${vm_names}; do
-            delete_dir_if_exists ${VAGRANT_DIR}/.vagrant/machines/${vm}
+            delete_dir_if_exists ${VAGRANT_DOTFILE_PATH}/machines/${vm}
         done
     fi
 }
@@ -116,7 +119,6 @@ run() {
     declare -p PERL_UNIT_TESTS GOLANG_UNIT_TESTS
     declare -p INTEGRATION_TESTS    
     if [ "$RUN_TESTS" = "yes" ]; then
-        install_ansible_files
         start_and_provision ${PF_VM_NAME}
         if [ "$PERL_UNIT_TESTS" = "yes" ] || [ "$GOLANG_UNIT_TESTS" = "yes" ]; then
             run_shell_provisioner ${PF_VM_NAME} run-unit-tests
@@ -142,6 +144,7 @@ configure_and_check
 
 case $1 in
     run) run ;;
+    halt) halt ${PF_VM_NAME} ${INT_TEST_VM_NAMES} ;;
     teardown) teardown ;;
     *)   die "Wrong argument"
 esac
