@@ -2,8 +2,8 @@
 -- Setting the major/minor/sub-minor version of the DB
 --
 
-SET @MAJOR_VERSION = 5;
-SET @MINOR_VERSION = 7;
+SET @MAJOR_VERSION = 6;
+SET @MINOR_VERSION = 5;
 SET @SUBMINOR_VERSION = 0;
 
 --
@@ -107,19 +107,31 @@ CREATE TABLE `node_category` (
 -- Insert 'default' category
 --
 
-INSERT INTO `node_category` (category_id,name,notes) VALUES ("1","default","Placeholder role/category, feel free to edit");
+INSERT INTO `node_category` (name,notes) VALUES ("default","Placeholder role/category, feel free to edit");
 
 --
 -- Insert 'guest' category
 --
 
-INSERT INTO `node_category` (category_id,name,notes) VALUES ("2","guest","Guests");
+INSERT INTO `node_category` (name,notes) VALUES ("guest","Guests");
 
 --
 -- Insert 'gaming' category
 --
 
-INSERT INTO `node_category` (category_id,name,notes) VALUES ("3","gaming","Gaming devices");
+INSERT INTO `node_category` (name,notes) VALUES ("gaming","Gaming devices");
+
+--
+-- Insert 'voice' category
+--
+
+INSERT INTO `node_category` (name,notes) VALUES ("voice","VoIP devices");
+
+--
+-- Insert 'REJECT' category
+--
+
+INSERT INTO `node_category` (name,notes) VALUES ("REJECT","Reject role (Used to block access)");
 
 --
 -- Table structure for table `node`
@@ -147,6 +159,8 @@ CREATE TABLE node (
   dhcp6_enterprise varchar(255) default NULL,
   device_type varchar(255) default NULL,
   device_class varchar(255) default NULL,
+  device_version varchar(255) DEFAULT NULL,
+  device_score varchar(255) DEFAULT NULL,
   bypass_vlan varchar(50) default NULL,
   voip enum('no','yes') NOT NULL DEFAULT 'no',
   autoreg enum('no','yes') NOT NULL DEFAULT 'no',
@@ -213,7 +227,6 @@ CREATE TABLE violation (
   status varchar(10) default "open",
   ticket_ref varchar(255) default NULL,
   notes text,
-  KEY mac (mac),
   KEY vid (vid),
   KEY status (status),
   KEY ind1 (mac,status,vid),
@@ -262,7 +275,10 @@ CREATE TABLE iplog_history (
   mac varchar(17) NOT NULL,
   ip varchar(45) NOT NULL,
   start_time datetime NOT NULL,
-  end_time timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP
+  end_time datetime NOT NULL,
+  KEY iplog_history_mac_end_time (mac,end_time),
+  KEY end_time (end_time),
+  KEY start_time (start_time)
 ) ENGINE=InnoDB;
 
 --
@@ -273,13 +289,15 @@ CREATE TABLE iplog_archive (
   mac varchar(17) NOT NULL,
   ip varchar(45) NOT NULL,
   start_time datetime NOT NULL,
-  end_time datetime NOT NULL
+  end_time datetime NOT NULL,
+  KEY end_time (end_time),
+  KEY start_time (start_time)
 ) ENGINE=InnoDB;
 
 CREATE TABLE `locationlog` (
   `mac` varchar(17) default NULL,
   `switch` varchar(17) NOT NULL default '',
-  `port` varchar(8) NOT NULL default '',
+  `port` varchar(20) NOT NULL default '',
   `vlan` varchar(50) default NULL,
   `role` varchar(255) default NULL,
   `connection_type` varchar(50) NOT NULL default '',
@@ -301,7 +319,7 @@ CREATE TABLE `locationlog` (
 CREATE TABLE `locationlog_archive` (
   `mac` varchar(17) default NULL,
   `switch` varchar(17) NOT NULL default '',
-  `port` varchar(8) NOT NULL default '',
+  `port` varchar(20) NOT NULL default '',
   `vlan` varchar(50) default NULL,
   `role` varchar(255) default NULL,
   `connection_type` varchar(50) NOT NULL default '',
@@ -340,21 +358,6 @@ CREATE TABLE `ifoctetslog` (
   PRIMARY KEY  (`switch`,`port`,`read_time`)
 ) ENGINE=InnoDB;
 
-CREATE TABLE `traplog` (
-  `switch` varchar(30) NOT NULL default '',
-  `ifIndex` smallint(6) NOT NULL default '0',
-  `parseTime` datetime NOT NULL default '0000-00-00 00:00:00',
-  `type` varchar(30) NOT NULL default '',
-  KEY `switch` (`switch`,`ifIndex`),
-  KEY `parseTime` (`parseTime`)
-) ENGINE=InnoDB;
-
-CREATE TABLE `configfile` (
-  `filename` varchar(255) NOT NULL,
-  `filecontent` text NOT NULL,
-  `lastmodified` datetime NOT NULL
-) ENGINE=InnoDB default CHARSET=latin1;
-
 --
 -- Table structure for table `password`
 --
@@ -362,13 +365,14 @@ CREATE TABLE `configfile` (
 CREATE TABLE `password` (
   `pid` varchar(255) NOT NULL,
   `password` varchar(255) NOT NULL,
-  `valid_from` datetime default NULL,
+  `valid_from` datetime NOT NULL DEFAULT "0000-00-00 00:00:00",
   `expiration` datetime NOT NULL,
   `access_duration` varchar(255) default NULL,
   `access_level` varchar(255) DEFAULT 'NONE',
   `category` int DEFAULT NULL,
   `sponsor` tinyint(1) NOT NULL default 0,
   `unregdate` datetime NOT NULL default "0000-00-00 00:00:00",
+  `login_remaining` int DEFAULT NULL,
   PRIMARY KEY (pid)
 ) ENGINE=InnoDB;
 
@@ -490,35 +494,40 @@ VALUES
 -- Adding RADIUS nas client table
 
 CREATE TABLE radius_nas (
+  id int(10) NOT NULL auto_increment,
   nasname varchar(128) NOT NULL,
   shortname varchar(32),
   type varchar(30) default 'other',
   ports int(5),
   secret varchar(60) default 'secret' NOT NULL,
+  server varchar(64),
   community varchar(50),
   description varchar(200) default 'RADIUS Client',
   config_timestamp BIGINT,
   start_ip INT UNSIGNED DEFAULT 0,
   end_ip INT UNSIGNED DEFAULT 0,
   range_length INT DEFAULT 0,
-  PRIMARY KEY nasname (nasname)
+  PRIMARY KEY nasname (nasname),
+  KEY id (id)
 ) ENGINE=InnoDB;
 
 -- Adding RADIUS accounting table
 
 CREATE TABLE radacct (
-  radacctid bigint(21) NOT NULL AUTO_INCREMENT,
+  radacctid bigint(21) NOT NULL auto_increment,
   acctsessionid varchar(64) NOT NULL default '',
   acctuniqueid varchar(32) NOT NULL default '',
   username varchar(64) NOT NULL default '',
   groupname varchar(64) NOT NULL default '',
   realm varchar(64) default '',
   nasipaddress varchar(15) NOT NULL default '',
-  nasportid varchar(15) default NULL,
+  nasportid varchar(32) default NULL,
   nasporttype varchar(32) default NULL,
   acctstarttime datetime NULL default NULL,
+  acctupdatetime datetime NULL default NULL,
   acctstoptime datetime NULL default NULL,
-  acctsessiontime int(12) default NULL,
+  acctinterval int(12) default NULL,
+  acctsessiontime int(12) unsigned default NULL,
   acctauthentic varchar(32) default NULL,
   connectinfo_start varchar(50) default NULL,
   connectinfo_stop varchar(50) default NULL,
@@ -530,20 +539,18 @@ CREATE TABLE radacct (
   servicetype varchar(32) default NULL,
   framedprotocol varchar(32) default NULL,
   framedipaddress varchar(15) NOT NULL default '',
-  acctstartdelay int(12) default NULL,
-  acctstopdelay int(12) default NULL,
-  xascendsessionsvrkey varchar(10) default NULL,
-  PRIMARY KEY  (radacctid),
+  PRIMARY KEY (radacctid),
+  KEY acctuniqueid (acctuniqueid),
   KEY username (username),
   KEY framedipaddress (framedipaddress),
   KEY acctsessionid (acctsessionid),
   KEY acctsessiontime (acctsessiontime),
-  KEY acctuniqueid (acctuniqueid),
-  KEY acctstarttime (acctstarttime),
+  KEY acctinterval (acctinterval),
   KEY acctstoptime (acctstoptime),
   KEY nasipaddress (nasipaddress),
-  KEY callingstationid (callingstationid)
-) ENGINE=InnoDB;
+  KEY callingstationid (callingstationid),
+  KEY acctstart_acctstop (acctstarttime,acctstoptime)
+) ENGINE = INNODB;
 
 -- Adding RADIUS update log table
 
@@ -556,129 +563,91 @@ CREATE TABLE radacct_log (
   acctinputoctets bigint(20) default NULL,
   acctoutputoctets bigint(20) default NULL,
   acctsessiontime int(12) default NULL,
+  acctuniqueid varchar(32) NOT NULL default '',
   KEY acctsessionid (acctsessionid),
   KEY username (username),
   KEY nasipaddress (nasipaddress),
-  KEY timestamp (timestamp)
+  KEY timestamp (timestamp),
+  KEY acctuniqueid (acctuniqueid)
 ) ENGINE=InnoDB;
 
 -- Adding RADIUS Updates Stored Procedure
-DROP PROCEDURE IF EXISTS acct_update;
-DELIMITER /
-CREATE PROCEDURE acct_update(
-  IN p_timestamp datetime,
-  IN p_acctsessiontime int(12),
-  IN p_acctinputoctets bigint(20),
-  IN p_acctoutputoctets bigint(20),
-  IN p_acctsessionid varchar(64),
-  IN p_username varchar(64),
-  IN p_nasipaddress varchar(15),
-  IN p_framedipaddress varchar(15),
-  IN p_acctstatustype varchar(25)
-)
-BEGIN
-  DECLARE Previous_Input_Octets bigint(20);
-  DECLARE Previous_Output_Octets bigint(20);
-  DECLARE Previous_Session_Time int(12);
-
-  # Collect traffic previous values in the update table
-  SELECT acctinputoctets, acctoutputoctets, acctsessiontime
-    INTO Previous_Input_Octets, Previous_Output_Octets, Previous_Session_Time
-    FROM radacct
-    WHERE acctsessionid = p_acctsessionid
-    AND username = p_username
-    AND nasipaddress = p_nasipaddress
-    AND (acctstoptime IS NULL OR acctstoptime = 0);
-
-  # Set values to 0 when no previous records
-  IF (Previous_Session_Time IS NULL) THEN
-    SET Previous_Session_Time = 0;
-    SET Previous_Input_Octets = 0;
-    SET Previous_Output_Octets = 0;
-  END IF;
-
-  # Update record with new traffic
-  UPDATE radacct SET
-    framedipaddress = p_framedipaddress,
-    acctsessiontime = p_acctsessiontime,
-    acctinputoctets = p_acctinputoctets,
-    acctoutputoctets = p_acctoutputoctets
-    WHERE acctsessionid = p_acctsessionid
-    AND username = p_username
-    AND nasipaddress = p_nasipaddress
-    AND (acctstoptime IS NULL OR acctstoptime = 0);
-
-  # Create new record in the log table
-  INSERT INTO radacct_log
-   (acctsessionid, username, nasipaddress,
-    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime)
-  VALUES
-   (p_acctsessionid, p_username, p_nasipaddress,
-    p_timestamp, p_acctstatustype, (p_acctinputoctets - Previous_Input_Octets), (p_acctoutputoctets - Previous_Output_Octets),
-    (p_acctsessiontime - Previous_Session_Time));
-END /
-DELIMITER ;
-
-
--- Adding RADIUS Start Stored Procedure
 
 DROP PROCEDURE IF EXISTS acct_start;
 DELIMITER /
 CREATE PROCEDURE acct_start (
-  IN p_acctsessionid varchar(64),
-  IN p_acctuniqueid varchar(32),
-  IN p_username varchar(64),
-  IN p_realm varchar(64),
-  IN p_nasipaddress varchar(15),
-  IN p_nasportid varchar(15),
-  IN p_nasporttype varchar(32),
-  IN p_acctstarttime datetime,
-  IN p_acctstoptime datetime,
-  IN p_acctsessiontime int(12),
-  IN p_acctauthentic varchar(32),
-  IN p_connectioninfo_start varchar(50),
-  IN p_connectioninfo_stop varchar(50),
-  IN p_acctinputoctets bigint(20),
-  IN p_acctoutputoctets bigint(20),
-  IN p_calledstationid varchar(50),
-  IN p_callingstationid varchar(50),
-  IN p_acctterminatecause varchar(32),
-  IN p_servicetype varchar(32),
-  IN p_framedprotocol varchar(32),
-  IN p_framedipaddress varchar(15),
-  IN p_acctstartdelay varchar(12),
-  IN p_acctstopdelay varchar(12),
-  IN p_xascendsessionsvrkey varchar(10),
-  IN p_acctstatustype varchar(25)
+    IN p_acctsessionid varchar(64),
+    IN p_acctuniqueid varchar(32),
+    IN p_username varchar(64),
+    IN p_realm varchar(64),
+    IN p_nasipaddress varchar(15),
+    IN p_nasportid varchar(32),
+    IN p_nasporttype varchar(32),
+    IN p_acctstarttime datetime,
+    IN p_acctupdatetime datetime,
+    IN p_acctstoptime datetime,
+    IN p_acctsessiontime int(12) unsigned,
+    IN p_acctauthentic varchar(32),
+    IN p_connectinfo_start varchar(50),
+    IN p_connectinfo_stop varchar(50),
+    IN p_acctinputoctets bigint(20),
+    IN p_acctoutputoctets bigint(20),
+    IN p_calledstationid varchar(50),
+    IN p_callingstationid varchar(50),
+    IN p_acctterminatecause varchar(32),
+    IN p_servicetype varchar(32),
+    IN p_framedprotocol varchar(32),
+    IN p_framedipaddress varchar(15),
+    IN p_acctstatustype varchar(25)
 )
 BEGIN
-  # Insert new record with new traffic
-  INSERT INTO radacct
-    (acctsessionid, acctuniqueid, username,
-     realm, nasipaddress, nasportid,
-     nasporttype, acctstarttime, acctstoptime,
-     acctsessiontime, acctauthentic, connectinfo_start,
-     connectinfo_stop, acctinputoctets, acctoutputoctets,
-     calledstationid, callingstationid, acctterminatecause,
-     servicetype, framedprotocol, framedipaddress,
-     acctstartdelay, acctstopdelay, xascendsessionsvrkey)
-  VALUES
-    (p_acctsessionid, p_acctuniqueid, p_username,
-     p_realm, p_nasipaddress, p_nasportid,
-     p_nasporttype, p_acctstarttime, p_acctstoptime,
-     p_acctsessiontime, p_acctauthentic, p_connectioninfo_start,
-     p_connectioninfo_stop, p_acctinputoctets, p_acctoutputoctets,
-     p_calledstationid, p_callingstationid, p_acctterminatecause,
-     p_servicetype, p_framedprotocol, p_framedipaddress,
-     p_acctstartdelay, p_acctstopdelay, p_xascendsessionsvrkey);
 
-  # Create new record in the log table
+# We make sure there are no left over sessions for which we never received a "stop"
+DECLARE Previous_Session_Time int(12);
+SELECT acctsessiontime
+INTO Previous_Session_Time
+FROM radacct
+WHERE acctuniqueid = p_acctuniqueid
+AND (acctstoptime IS NULL OR acctstoptime = 0) LIMIT 1;
+
+IF (Previous_Session_Time IS NOT NULL) THEN
+    UPDATE radacct SET
+      acctstoptime = p_acctstarttime,
+      acctterminatecause = 'UNKNOWN'
+      WHERE acctuniqueid = p_acctuniqueid
+      AND (acctstoptime IS NULL OR acctstoptime = 0);
+END IF;
+
+INSERT INTO radacct 
+           (
+            acctsessionid,      acctuniqueid,       username, 
+            realm,          nasipaddress,       nasportid, 
+            nasporttype,        acctstarttime,      acctupdatetime, 
+            acctstoptime,       acctsessiontime,    acctauthentic, 
+            connectinfo_start,  connectinfo_stop,   acctinputoctets, 
+            acctoutputoctets,   calledstationid,    callingstationid, 
+            acctterminatecause, servicetype,        framedprotocol, 
+            framedipaddress
+           ) 
+VALUES 
+    (
+    p_acctsessionid, p_acctuniqueid, p_username,
+    p_realm, p_nasipaddress, p_nasportid,
+    p_nasporttype, p_acctstarttime, p_acctupdatetime,
+    p_acctstoptime, p_acctsessiontime, p_acctauthentic,
+    p_connectinfo_start, p_connectinfo_stop, p_acctinputoctets,
+    p_acctoutputoctets, p_calledstationid, p_callingstationid,
+    p_acctterminatecause, p_servicetype, p_framedprotocol,
+    p_framedipaddress
+    );
+
+
   INSERT INTO radacct_log
    (acctsessionid, username, nasipaddress,
-    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime)
+    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime, acctuniqueid)
   VALUES
    (p_acctsessionid, p_username, p_nasipaddress,
-    p_acctstarttime, p_acctstatustype,p_acctinputoctets,p_acctoutputoctets,p_acctsessiontime);
+    p_acctstarttime, p_acctstatustype, p_acctinputoctets, p_acctoutputoctets, p_acctsessiontime, p_acctuniqueid);
 END /
 DELIMITER ;
 
@@ -686,17 +655,26 @@ DELIMITER ;
 
 DROP PROCEDURE IF EXISTS acct_stop;
 DELIMITER /
-CREATE PROCEDURE acct_stop(
+CREATE PROCEDURE acct_stop (
   IN p_timestamp datetime,
+  IN p_framedipaddress varchar(15),
   IN p_acctsessiontime int(12),
   IN p_acctinputoctets bigint(20),
   IN p_acctoutputoctets bigint(20),
-  IN p_acctterminatecause varchar(12),
-  IN p_acctdelaystop varchar(32),
-  IN p_connectinfo_stop varchar(50),
+  IN p_acctuniqueid varchar(32),
   IN p_acctsessionid varchar(64),
   IN p_username varchar(64),
+  IN p_realm varchar(64),
   IN p_nasipaddress varchar(15),
+  IN p_nasportid varchar(32),
+  IN p_nasporttype varchar(32),
+  IN p_acctauthentic varchar(32),
+  IN p_connectinfo_stop varchar(50),
+  IN p_calledstationid varchar(50),
+  IN p_callingstationid varchar(50),
+  IN p_servicetype varchar(32),
+  IN p_framedprotocol varchar(32),
+  IN p_acctterminatecause varchar(12),
   IN p_acctstatustype varchar(25)
 )
 BEGIN
@@ -704,45 +682,174 @@ BEGIN
   DECLARE Previous_Output_Octets bigint(20);
   DECLARE Previous_Session_Time int(12);
 
-  # Collect traffic previous values in the update table
+  # Collect traffic previous values in the radacct table
   SELECT acctinputoctets, acctoutputoctets, acctsessiontime
     INTO Previous_Input_Octets, Previous_Output_Octets, Previous_Session_Time
     FROM radacct
-    WHERE acctsessionid = p_acctsessionid
-    AND username = p_username
-    AND nasipaddress = p_nasipaddress
-    AND (acctstoptime IS NULL OR acctstoptime = 0);
+    WHERE acctuniqueid = p_acctuniqueid
+    AND (acctstoptime IS NULL OR acctstoptime = 0) LIMIT 1;
 
   # Set values to 0 when no previous records
   IF (Previous_Session_Time IS NULL) THEN
     SET Previous_Session_Time = 0;
     SET Previous_Input_Octets = 0;
     SET Previous_Output_Octets = 0;
+    # If there is no open session for this, open one.
+    INSERT INTO radacct 
+           (
+            acctsessionid,      acctuniqueid,       username, 
+            realm,              nasipaddress,       nasportid, 
+            nasporttype,        acctstoptime,       acctstarttime,
+            acctsessiontime,    acctauthentic, 
+            connectinfo_stop,  acctinputoctets, 
+            acctoutputoctets,   calledstationid,    callingstationid, 
+            servicetype,        framedprotocol,     acctterminatecause,
+            framedipaddress
+           ) 
+    VALUES 
+        (
+            p_acctsessionid,        p_acctuniqueid,     p_username,
+            p_realm,                p_nasipaddress,     p_nasportid,
+            p_nasporttype,          p_timestamp,     date_sub(p_timestamp, INTERVAL p_acctsessiontime SECOND ), 
+            p_acctsessiontime,      p_acctauthentic,
+            p_connectinfo_stop,     p_acctinputoctets,
+            p_acctoutputoctets,     p_calledstationid,  p_callingstationid,
+            p_servicetype,          p_framedprotocol,   p_acctterminatecause,
+            p_framedipaddress
+        );
+  ELSE 
+    # Update record with new traffic
+    UPDATE radacct SET
+      acctstoptime = p_timestamp,
+      acctsessiontime = p_acctsessiontime,
+      acctinputoctets = p_acctinputoctets,
+      acctoutputoctets = p_acctoutputoctets,
+      acctterminatecause = p_acctterminatecause,
+      connectinfo_stop = p_connectinfo_stop
+      WHERE acctuniqueid = p_acctuniqueid
+      AND (acctstoptime IS NULL OR acctstoptime = 0);
   END IF;
 
-  # Update record with new traffic
-  UPDATE radacct SET
-    acctstoptime = p_timestamp,
-    acctsessiontime = p_acctsessiontime,
-    acctinputoctets = p_acctinputoctets,
-    acctoutputoctets = p_acctoutputoctets,
-    acctterminatecause = p_acctterminatecause,
-    connectinfo_stop = p_connectinfo_stop
-    WHERE acctsessionid = p_acctsessionid
-    AND username = p_username
-    AND nasipaddress = p_nasipaddress
-    AND (acctstoptime IS NULL OR acctstoptime = 0);
-
   # Create new record in the log table
   INSERT INTO radacct_log
    (acctsessionid, username, nasipaddress,
-    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime)
+    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime, acctuniqueid)
   VALUES
    (p_acctsessionid, p_username, p_nasipaddress,
     p_timestamp, p_acctstatustype, (p_acctinputoctets - Previous_Input_Octets), (p_acctoutputoctets - Previous_Output_Octets),
-    (p_acctsessiontime - Previous_Session_Time));
+    (p_acctsessiontime - Previous_Session_Time), p_acctuniqueid);
 END /
 DELIMITER ;
+
+-- Adding RADIUS Updates Stored Procedure
+
+DROP PROCEDURE IF EXISTS acct_update;
+DELIMITER /
+CREATE PROCEDURE acct_update(
+  IN p_timestamp datetime,
+  IN p_framedipaddress varchar(15),
+  IN p_acctsessiontime int(12),
+  IN p_acctinputoctets bigint(20),
+  IN p_acctoutputoctets bigint(20),
+  IN p_acctuniqueid varchar(32),
+  IN p_acctsessionid varchar(64),
+  IN p_username varchar(64),
+  IN p_realm varchar(64),
+  IN p_nasipaddress varchar(15),
+  IN p_nasportid varchar(32),
+  IN p_nasporttype varchar(32),
+  IN p_acctauthentic varchar(32),
+  IN p_connectinfo_start varchar(50),
+  IN p_calledstationid varchar(50),
+  IN p_callingstationid varchar(50),
+  IN p_servicetype varchar(32),
+  IN p_framedprotocol varchar(32),
+  IN p_acctstatustype varchar(25)
+)
+BEGIN
+  DECLARE Previous_Input_Octets bigint(20);
+  DECLARE Previous_Output_Octets bigint(20);
+  DECLARE Previous_Session_Time int(12);
+  DECLARE Previous_AcctUpdate_Time datetime;
+
+  DECLARE Opened_Sessions int(12);
+  DECLARE Latest_acctstarttime datetime;
+  SELECT count(acctuniqueid), max(acctstarttime)
+  INTO Opened_Sessions, Latest_acctstarttime
+  FROM radacct
+  WHERE acctuniqueid = p_acctuniqueid
+  AND (acctstoptime IS NULL OR acctstoptime = 0);
+
+  IF (Opened_Sessions > 1) THEN
+      UPDATE radacct SET
+        acctstoptime = NOW(),
+        acctterminatecause = 'UNKNOWN'
+        WHERE acctuniqueid = p_acctuniqueid
+        AND acctstarttime < Latest_acctstarttime
+        AND (acctstoptime IS NULL OR acctstoptime = 0);
+  END IF;
+
+  # Collect traffic previous values in the update table
+  SELECT acctinputoctets, acctoutputoctets, acctsessiontime, acctupdatetime
+    INTO Previous_Input_Octets, Previous_Output_Octets, Previous_Session_Time, Previous_AcctUpdate_Time
+    FROM radacct
+    WHERE acctuniqueid = p_acctuniqueid 
+    AND (acctstoptime IS NULL OR acctstoptime = 0) LIMIT 1;
+
+  IF (Previous_Session_Time IS NULL) THEN
+    # Set values to 0 when no previous records
+    SET Previous_Session_Time = 0;
+    SET Previous_Input_Octets = 0;
+    SET Previous_Output_Octets = 0;
+    SET Previous_AcctUpdate_Time = p_timestamp;
+    # If there is no open session for this, open one.
+    INSERT INTO radacct 
+           (
+            acctsessionid,      acctuniqueid,       username, 
+            realm,              nasipaddress,       nasportid, 
+            nasporttype,        acctstarttime,      
+            acctupdatetime,     acctsessiontime,    acctauthentic, 
+            connectinfo_start,  acctinputoctets, 
+            acctoutputoctets,   calledstationid,    callingstationid, 
+            servicetype,        framedprotocol, 
+            framedipaddress
+           ) 
+    VALUES 
+        (
+            p_acctsessionid,        p_acctuniqueid,     p_username,
+            p_realm,                p_nasipaddress,     p_nasportid,
+            p_nasporttype,          date_sub(p_timestamp, INTERVAL p_acctsessiontime SECOND ), 
+            p_timestamp,            p_acctsessiontime , p_acctauthentic,
+            p_connectinfo_start,    p_acctinputoctets,
+            p_acctoutputoctets,     p_calledstationid, p_callingstationid,
+            p_servicetype,          p_framedprotocol,
+            p_framedipaddress
+        );
+  ELSE 
+    # Update record with new traffic
+    UPDATE radacct SET
+        framedipaddress = p_framedipaddress,
+        acctsessiontime = p_acctsessiontime,
+        acctinputoctets = p_acctinputoctets,
+        acctoutputoctets = p_acctoutputoctets,
+        acctupdatetime = p_timestamp,
+        acctinterval = timestampdiff( second, Previous_AcctUpdate_Time,  p_timestamp  )
+    WHERE acctuniqueid = p_acctuniqueid 
+    AND (acctstoptime IS NULL OR acctstoptime = 0);
+
+  END IF;
+
+  # Create new record in the log table
+  INSERT INTO radacct_log
+   (acctsessionid, username, nasipaddress,
+    timestamp, acctstatustype, acctinputoctets, acctoutputoctets, acctsessiontime, acctuniqueid)
+  VALUES
+   (p_acctsessionid, p_username, p_nasipaddress,
+    p_timestamp, p_acctstatustype, (p_acctinputoctets - Previous_Input_Octets), (p_acctoutputoctets - Previous_Output_Octets),
+    (p_acctsessiontime - Previous_Session_Time), p_acctuniqueid);
+END /
+DELIMITER ;
+
 --
 -- Statement of Health (SoH) related
 --
@@ -854,8 +961,7 @@ CREATE TABLE inline_accounting (
    firstseen DATETIME NOT NULL,
    lastmodified DATETIME NOT NULL,
    status int unsigned NOT NULL default 0,
-   PRIMARY KEY (ip, firstseen),
-   INDEX (ip)
+   PRIMARY KEY (ip, firstseen)
  ) ENGINE=InnoDB;
 
 --
@@ -915,6 +1021,7 @@ CREATE TABLE activation (
   `carrier_id` int(11) NULL,
   `activation_code` varchar(255) NOT NULL,
   `expiration` datetime NOT NULL,
+  `unregdate` datetime default NULL,
   `status` varchar(60) default NULL,
   `type` varchar(60) NOT NULL,
   `portal` varchar(255) default NULL,
@@ -983,6 +1090,7 @@ CREATE TABLE radius_audit_log (
   uuid varchar(255) NULL,
   radius_request TEXT,
   radius_reply TEXT,
+  request_time int(11) DEFAULT NULL,
   PRIMARY KEY (id),
   KEY `created_at` (created_at),
   KEY `mac` (mac),
@@ -990,6 +1098,77 @@ CREATE TABLE radius_audit_log (
   KEY `user_name` (user_name)
 ) ENGINE=InnoDB;
 
+--
+-- Table structure for table `dhcp_option82`
+--
+
+CREATE TABLE `dhcp_option82` (
+  `mac` varchar(17) NOT NULL PRIMARY KEY,
+  `created_at` TIMESTAMP NOT NULL,
+  `option82_switch` varchar(17) NULL,
+  `switch_id` varchar(17) NULL,
+  `port` varchar(8) NOT NULL default '',
+  `vlan` varchar(255) default NULL,
+  `circuit_id_string` varchar(255) default NULL,
+  `module` varchar(255) default NULL,
+  `host` varchar(255) default NULL,
+  UNIQUE KEY mac (mac)
+) ENGINE=InnoDB;
+
+--
+-- Table structure for table `dhcp_option82_history`
+--
+
+CREATE TABLE `dhcp_option82_history` (
+  `dhcp_option82_history_id` int NOT NULL PRIMARY KEY AUTO_INCREMENT,
+  `mac` varchar(17) NOT NULL,
+  `created_at` TIMESTAMP NOT NULL,
+  `option82_switch` varchar(17) NULL,
+  `switch_id` varchar(17) NULL,
+  `port` varchar(8) NOT NULL default '',
+  `vlan` varchar(255) default NULL,
+  `circuit_id_string` varchar(255) default NULL,
+  `module` varchar(255) default NULL,
+  `host` varchar(255) default NULL,
+  INDEX (mac)
+) ENGINE=InnoDB;
+
+--
+-- Trigger to archive dhcp_option82 entries to the history table after an update
+--
+
+DROP TRIGGER IF EXISTS dhcp_option82_after_update_trigger;
+DELIMITER /
+CREATE TRIGGER dhcp_option82_after_update_trigger AFTER UPDATE ON dhcp_option82
+FOR EACH ROW
+BEGIN
+    INSERT INTO dhcp_option82_history
+           (
+            created_at,
+            mac,
+            option82_switch,
+            switch_id,
+            port,
+            vlan,
+            circuit_id_string,
+            module,
+            host
+           )
+    VALUES
+           (
+            OLD.created_at,
+            OLD.mac,
+            OLD.option82_switch,
+            OLD.switch_id,
+            OLD.port,
+            OLD.vlan,
+            OLD.circuit_id_string,
+            OLD.module,
+            OLD.host
+           );
+END /
+DELIMITER ;
+
 --
 -- Updating to current version
 --
@@ -1010,5 +1189,6 @@ CREATE TABLE auth_log (
   `completed_at` datetime,
   `source` varchar(255) NOT NULL,
   PRIMARY KEY (id),
-  KEY pid (pid)
+  KEY pid (pid),
+  KEY  attempted_at (attempted_at)
 ) ENGINE=InnoDB;
