@@ -21,8 +21,9 @@ var configApiPrefix = apiPrefix + "/config"
 var configNamespaceRe = regexp.MustCompile("^" + regexp.QuoteMeta(configApiPrefix))
 
 type adminRoleMapping struct {
-	prefix string
-	role   string
+	prefix     string
+	role       string
+	roleSuffix string
 }
 
 var multipleTenants = false
@@ -91,6 +92,7 @@ var pathAdminRolesMap = []adminRoleMapping{
 	adminRoleMapping{prefix: apiPrefix + "/ip6logs", role: "NODES"},
 	adminRoleMapping{prefix: apiPrefix + "/locationlog/", role: "NODES"},
 	adminRoleMapping{prefix: apiPrefix + "/locationlogs", role: "NODES"},
+	adminRoleMapping{prefix: apiPrefix + "/nodes/network_graph", role: "NODES", roleSuffix: "_READ"},
 	adminRoleMapping{prefix: apiPrefix + "/node/", role: "NODES"},
 	adminRoleMapping{prefix: apiPrefix + "/nodes", role: "NODES"},
 	adminRoleMapping{prefix: apiPrefix + "/node_categories", role: "NODES"},
@@ -143,8 +145,8 @@ var pathAdminRolesMap = []adminRoleMapping{
 	adminRoleMapping{prefix: configApiPrefix + "/interfaces", role: "INTERFACES"},
 	adminRoleMapping{prefix: configApiPrefix + "/l2_network/", role: "INTERFACES"},
 	adminRoleMapping{prefix: configApiPrefix + "/l2_networks", role: "INTERFACES"},
-	adminRoleMapping{prefix: configApiPrefix + "/maintenance_task/", role: "PFMON"},
-	adminRoleMapping{prefix: configApiPrefix + "/maintenance_tasks", role: "PFMON"},
+	adminRoleMapping{prefix: configApiPrefix + "/maintenance_task/", role: "PFCRON"},
+	adminRoleMapping{prefix: configApiPrefix + "/maintenance_tasks", role: "PFCRON"},
 	adminRoleMapping{prefix: configApiPrefix + "/pki_provider/", role: "PKI_PROVIDER"},
 	adminRoleMapping{prefix: configApiPrefix + "/pki_providers", role: "PKI_PROVIDER"},
 	adminRoleMapping{prefix: configApiPrefix + "/portal_module/", role: "PORTAL_MODULE"},
@@ -200,6 +202,8 @@ var methodSuffixMap = map[string]string{
 	"DELETE":  "_DELETE",
 }
 
+var InvalidTokenInfoErr = "Invalid token info"
+
 type TokenAuthorizationMiddleware struct {
 	tokenBackend TokenBackend
 }
@@ -233,7 +237,7 @@ func (tam *TokenAuthorizationMiddleware) BearerRequestIsAuthorized(ctx context.C
 	tokenInfo, _ := tam.tokenBackend.TokenInfoForToken(token)
 
 	if tokenInfo == nil {
-		return false, errors.New("Invalid token info")
+		return false, errors.New(InvalidTokenInfoErr)
 	}
 
 	var tenantId int
@@ -270,7 +274,7 @@ func (tam *TokenAuthorizationMiddleware) BearerRequestIsAuthorized(ctx context.C
 // Checks whether or not that request is authorized based on the path and method
 func (tam *TokenAuthorizationMiddleware) IsAuthorized(ctx context.Context, method, path string, tenantId int, tokenInfo *TokenInfo) (bool, error) {
 	if tokenInfo == nil {
-		return false, errors.New("Invalid token info")
+		return false, errors.New(InvalidTokenInfoErr)
 	}
 
 	authAdminRoles, err := tam.isAuthorizedAdminActions(ctx, method, path, tokenInfo.AdminActions())
@@ -314,11 +318,13 @@ func (tam *TokenAuthorizationMiddleware) isAuthorizedTenantId(ctx context.Contex
 func (tam *TokenAuthorizationMiddleware) isAuthorizedAdminActions(ctx context.Context, method, path string, roles map[string]bool) (bool, error) {
 
 	var baseAdminRole string
+	var suffix string
 	for _, o := range pathAdminRolesMap {
 		base := o.prefix
 		role := o.role
 		if strings.HasPrefix(path, base) && role != "" {
 			baseAdminRole = role
+			suffix = o.roleSuffix
 			break
 		}
 	}
@@ -329,12 +335,15 @@ func (tam *TokenAuthorizationMiddleware) isAuthorizedAdminActions(ctx context.Co
 		baseAdminRole = "SYSTEM"
 	}
 
-	suffix := methodSuffixMap[method]
-
+	// Take suffix from the methodSuffixMap unless it was defined above
 	if suffix == "" {
-		msg := fmt.Sprintf("Impossible to find admin role suffix for unknown method %s", method)
-		log.LoggerWContext(ctx).Warn(msg)
-		return false, errors.New(msg)
+		suffix = methodSuffixMap[method]
+
+		if suffix == "" {
+			msg := fmt.Sprintf("Impossible to find admin role suffix for unknown method %s", method)
+			log.LoggerWContext(ctx).Warn(msg)
+			return false, errors.New(msg)
+		}
 	}
 
 	// Rewrite suffix for search
