@@ -29,6 +29,17 @@ func TestTokenAuthorizationMiddlewareIsAuthorized(t *testing.T) {
 		t.Error("Request was unauthorized although it should have gone through, error:", err)
 	}
 
+	// Test the role suffix override
+	res, err = m.IsAuthorized(ctx, "POST", "/api/v1/nodes/network_graph", 0, &TokenInfo{
+		AdminRoles: map[string]bool{
+			"NodesRead": true,
+		},
+	})
+
+	if !res {
+		t.Error("Request was unauthorized although it should have gone through, error:", err)
+	}
+
 	res, err = m.IsAuthorized(ctx, "GET", "/api/v1/current_user", 0, &TokenInfo{
 		AdminRoles: map[string]bool{
 			"NodesRead": true,
@@ -174,7 +185,7 @@ func TestTokenAuthorizationMiddlewareIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"NodesDelete": true,
 		},
-		Tenant: Tenant{Id:0},
+		Tenant: Tenant{Id: 0},
 	})
 
 	if !res {
@@ -186,22 +197,22 @@ func TestTokenAuthorizationMiddlewareIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"NodesDelete": true,
 		},
-		Tenant: Tenant{Id:1},
+		Tenant: Tenant{Id: 1},
 	})
 
 	if !res {
 		t.Error("Request was unauthorized although it should have gone through, error:", err)
 	}
 
-    multipleTenants = true
+	multipleTenants = true
 	// Test invalid scoped tenant ID
 	res, err = m.IsAuthorized(ctx, "DELETE", "/api/v1/nodes", 1, &TokenInfo{
 		AdminRoles: map[string]bool{
 			"NodesDelete": true,
 		},
-		Tenant: Tenant{Id:2},
+		Tenant: Tenant{Id: 2},
 	})
-    multipleTenants = false
+	multipleTenants = false
 
 	if res {
 		t.Error("Request was authorized although it should haven't gone through, error:", err)
@@ -212,7 +223,7 @@ func TestTokenAuthorizationMiddlewareIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"NodesDelete": true,
 		},
-		Tenant: Tenant{Id:-1},
+		Tenant: Tenant{Id: -1},
 	})
 
 	if res {
@@ -257,7 +268,7 @@ func TestTokenAuthorizationMiddlewareBearerRequestIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"UsersRead": true,
 		},
-		Tenant: Tenant{Id:1},
+		Tenant: Tenant{Id: 1},
 	})
 
 	addBearerTokenToTestRequest(req, token, 1)
@@ -281,7 +292,7 @@ func TestTokenAuthorizationMiddlewareBearerRequestIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"UsersRead": true,
 		},
-		Tenant: Tenant{Id:0},
+		Tenant: Tenant{Id: 0},
 	})
 
 	addBearerTokenToTestRequest(req, token, 1)
@@ -297,7 +308,7 @@ func TestTokenAuthorizationMiddlewareBearerRequestIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"UsersRead": true,
 		},
-		Tenant: Tenant{Id:1},
+		Tenant: Tenant{Id: 1},
 	})
 
 	addBearerTokenToTestRequest(req, token, 2)
@@ -322,22 +333,22 @@ func TestTokenAuthorizationMiddlewareBearerRequestIsAuthorized(t *testing.T) {
 		AdminRoles: map[string]bool{
 			"FirewallSSODelete": true,
 		},
-		Tenant: Tenant{Id:0},
+		Tenant: Tenant{Id: 0},
 	})
 
 	if !res {
 		t.Error("Request was unauthorized although it should have gone through, error:", err)
 	}
 
-    multipleTenants=true
+	multipleTenants = true
 	// Test invalid scoped tenant ID
 	res, err = m.IsAuthorized(ctx, "DELETE", "/api/v1/config/firewall/1", 1, &TokenInfo{
 		AdminRoles: map[string]bool{
 			"FirewallSSODelete": true,
 		},
-		Tenant: Tenant{Id:2},
+		Tenant: Tenant{Id: 2},
 	})
-    multipleTenants=false
+	multipleTenants = false
 
 	if res {
 		t.Error("Request was authorized although it should haven't gone through, error:", err)
