@@ -1,22 +1,19 @@
+//go:generate go run owners_generate.go
+
 package chaos
 
 import (
+	"sort"
+
+	"github.com/coredns/caddy"
 	"github.com/inverse-inc/packetfence/go/coredns/core/dnsserver"
 	"github.com/inverse-inc/packetfence/go/coredns/plugin"
-
-	"github.com/mholt/caddy"
 )
 
-func init() {
-	caddy.RegisterPlugin("chaos", caddy.Plugin{
-		ServerType: "dns",
-		Action:     setup,
-	})
-
-}
+func init() { plugin.Register("chaos", setup) }
 
 func setup(c *caddy.Controller) error {
-	version, authors, err := chaosParse(c)
+	version, authors, err := parse(c)
 	if err != nil {
 		return plugin.Error("chaos", err)
 	}
@@ -28,28 +25,42 @@ func setup(c *caddy.Controller) error {
 	return nil
 }
 
-func chaosParse(c *caddy.Controller) (string, map[string]bool, error) {
+func parse(c *caddy.Controller) (string, []string, error) {
 	// Set here so we pick up AppName and AppVersion that get set in coremain's init().
 	chaosVersion = caddy.AppName + "-" + caddy.AppVersion
-
 	version := ""
-	authors := make(map[string]bool)
 
 	for c.Next() {
 		args := c.RemainingArgs()
 		if len(args) == 0 {
-			return chaosVersion, nil, nil
+			return trim(chaosVersion), Owners, nil
 		}
 		if len(args) == 1 {
-			return args[0], nil, nil
+			return trim(args[0]), Owners, nil
 		}
+
 		version = args[0]
+		authors := make(map[string]struct{})
 		for _, a := range args[1:] {
-			authors[a] = true
+			authors[a] = struct{}{}
 		}
-		return version, authors, nil
+		list := []string{}
+		for k := range authors {
+			k = trim(k) // limit size to 255 chars
+			list = append(list, k)
+		}
+		sort.Strings(list)
+		return version, list, nil
 	}
-	return version, authors, nil
+
+	return version, Owners, nil
+}
+
+func trim(s string) string {
+	if len(s) < 256 {
+		return s
+	}
+	return s[:255]
 }
 
 var chaosVersion string
