@@ -1,7 +1,6 @@
 package dnssec
 
 import (
-	"log"
 	"time"
 
 	"github.com/inverse-inc/packetfence/go/coredns/plugin"
@@ -10,10 +9,11 @@ import (
 	"github.com/miekg/dns"
 )
 
-// ResponseWriter sign the response on the fly.
+// ResponseWriter signs the response on the fly.
 type ResponseWriter struct {
 	dns.ResponseWriter
-	d Dnssec
+	d      Dnssec
+	server string // server label for metrics.
 }
 
 // WriteMsg implements the dns.ResponseWriter interface.
@@ -26,23 +26,18 @@ func (d *ResponseWriter) WriteMsg(res *dns.Msg) error {
 	if zone == "" {
 		return d.ResponseWriter.WriteMsg(res)
 	}
+	state.Zone = zone
 
-	if state.Do() {
-		res = d.d.Sign(state, zone, time.Now().UTC())
-
-		cacheSize.WithLabelValues("signature").Set(float64(d.d.cache.Len()))
-	}
-	state.SizeAndDo(res)
+	res = d.d.Sign(state, time.Now().UTC(), d.server)
+	cacheSize.WithLabelValues(d.server, "signature").Set(float64(d.d.cache.Len()))
+	// No need for EDNS0 trickery, as that is handled by the server.
 
 	return d.ResponseWriter.WriteMsg(res)
 }
 
 // Write implements the dns.ResponseWriter interface.
 func (d *ResponseWriter) Write(buf []byte) (int, error) {
-	log.Printf("[WARNING] Dnssec called with Write: not signing reply")
+	log.Warning("Dnssec called with Write: not signing reply")
 	n, err := d.ResponseWriter.Write(buf)
 	return n, err
 }
-
-// Hijack implements the dns.ResponseWriter interface.
-func (d *ResponseWriter) Hijack() { d.ResponseWriter.Hijack() }
