@@ -34,6 +34,7 @@ import (
 )
 
 type pfdns struct {
+	InternalPortalIP    net.IP
 	RedirectIP          net.IP
 	Db                  *sql.DB
 	IP4log              *sql.Stmt // prepared statement for ip4log queries
@@ -49,7 +50,7 @@ type pfdns struct {
 	FqdnPort            map[*regexp.Regexp][]string
 	FqdnIsolationPort   map[*regexp.Regexp][]string
 	FqdnDomainPort      map[*regexp.Regexp][]string
-	Network             map[*net.IPNet]net.IP
+	Network             map[string]net.IP
 	NetworkType         map[*net.IPNet]*pfconfigdriver.NetworkConf
 	DNSFilter           *cache.Cache
 	IpsetCache          *cache.Cache
@@ -57,6 +58,7 @@ type pfdns struct {
 	refreshLauncher     *sync.Once
 	PortalFQDN          map[int]map[*net.IPNet]*regexp.Regexp
 	mutex               sync.Mutex
+	detectionBypass     bool
 	detectionMechanisms []*regexp.Regexp
 	recordDNS           bool
 }
@@ -117,6 +119,10 @@ func (pf *pfdns) RefreshPfconfig(ctx context.Context) {
 			go func(ctx context.Context) {
 				for {
 					pfconfigdriver.PfconfigPool.Refresh(ctx)
+					err = pf.detectVIP(ctx)
+					if err != nil {
+						log.LoggerWContext(ctx).Error(err.Error())
+					}
 					time.Sleep(1 * time.Second)
 				}
 			}(ctx)
@@ -132,6 +138,7 @@ func (pf *pfdns) ServeDNS(ctx context.Context, w dns.ResponseWriter, r *dns.Msg)
 	pf.RefreshPfconfig(ctx)
 
 	state := request.Request{W: w, Req: r}
+
 	a := new(dns.Msg)
 	a.SetReply(r)
 	a.Compress = true
@@ -143,12 +150,12 @@ func (pf *pfdns) ServeDNS(ctx context.Context, w dns.ResponseWriter, r *dns.Msg)
 	var ipVersion int
 	srcIP := state.IP()
 	bIP := net.ParseIP(srcIP)
+
 	if bIP.To4() == nil {
 		ipVersion = 6
 	} else {
 		ipVersion = 4
 	}
-
 	mac, err := pf.IP2Mac(ctx, srcIP, ipVersion)
 	if err != nil {
 		log.LoggerWContext(ctx).Error(fmt.Sprintf("ERROR cannot find mac for ip %s\n", srcIP))
@@ -384,14 +391,16 @@ func (pf *pfdns) ServeDNS(ctx context.Context, w dns.ResponseWriter, r *dns.Msg)
 
 		var returnedIP []byte
 		found = false
-		for k, v := range pf.Network {
+		id, _ := GlobalTransactionLock.RLock()
+		for n, v := range pf.Network {
+			_, k, _ := net.ParseCIDR(n)
 			if k.Contains(bIP) {
 				for w, x := range pf.NetworkType {
 					if k.String() == w.String() {
 						if x.NextHop != "" {
 							returnedIP = append([]byte(nil), v.To4()...)
 						} else {
-							returnedIP = append([]byte(nil), []byte{192, 0, 2, 1}...)
+							returnedIP = append([]byte(nil), []byte{pf.InternalPortalIP[0], pf.InternalPortalIP[1], pf.InternalPortalIP[2], pf.InternalPortalIP[3]}...)
 						}
 						rr.(*dns.A).A = returnedIP
 						found = true
@@ -402,11 +411,12 @@ func (pf *pfdns) ServeDNS(ctx context.Context, w dns.ResponseWriter, r *dns.Msg)
 				if found {
 					break
 				}
-				rr.(*dns.A).A = pf.RedirectIP.To4()
+				rr.(*dns.A).A = nil
 			}
 		}
+		GlobalTransactionLock.RUnlock(id)
 		if rr.(*dns.A).A == nil {
-			pf.detectVIP()
+			rr.(*dns.A).A = append([]byte(nil), []byte{127, 0, 0, 2}...)
 		}
 	case 2:
 		rr = new(dns.AAAA)
@@ -433,17 +443,20 @@ func (pf *pfdns) ServeDNS(ctx context.Context, w dns.ResponseWriter, r *dns.Msg)
 				}
 			}
 		}
-		for k, v := range pf.Network {
+		id, _ := GlobalTransactionLock.RLock()
+		for n, v := range pf.Network {
+			_, k, _ := net.ParseCIDR(n)
 			if k.Contains(bIP) {
 				returnedIP := append([]byte(nil), v.To16()...)
 				rr.(*dns.AAAA).AAAA = returnedIP
 				break
 			} else {
-				rr.(*dns.AAAA).AAAA = pf.RedirectIP.To16()
+				rr.(*dns.AAAA).AAAA = nil
 			}
 		}
+		GlobalTransactionLock.RUnlock(id)
 		if rr.(*dns.AAAA).AAAA == nil {
-			pf.detectVIP()
+			rr.(*dns.AAAA).AAAA = net.IPv6loopback
 		}
 	}
 
@@ -466,8 +479,7 @@ func readConfig(ctx context.Context) pfconfigdriver.PfConfDatabase {
 	return sections
 }
 
-func (pf *pfdns) DomainPassthroughInit() error {
-	var ctx = context.Background()
+func (pf *pfdns) DomainPassthroughInit(ctx context.Context) error {
 	var keyConfDNS pfconfigdriver.PfconfigKeys
 	keyConfDNS.PfconfigNS = "resource::domain_dns_servers"
 
@@ -507,8 +519,7 @@ func (pf *pfdns) DomainPassthroughInit() error {
 }
 
 // WebservicesInit read pfconfig webservices configuration
-func (pf *pfdns) WebservicesInit() error {
-	var ctx = context.Background()
+func (pf *pfdns) WebservicesInit(ctx context.Context) error {
 	var webservices pfconfigdriver.PfConfWebservices
 	webservices.PfconfigNS = "config::Pf"
 	webservices.PfconfigMethod = "hash_element"
@@ -521,13 +532,12 @@ func (pf *pfdns) WebservicesInit() error {
 }
 
 // detectType of each network
-func (pf *pfdns) detectType() error {
-	var ctx = context.Background()
+func (pf *pfdns) detectType(ctx context.Context) error {
 	var NetIndex net.IPNet
 	pf.NetworkType = make(map[*net.IPNet]*pfconfigdriver.NetworkConf)
 
-	var interfaces pfconfigdriver.ListenInts
-	pfconfigdriver.FetchDecodeSocket(ctx, &interfaces)
+	pfconfigdriver.FetchDecodeSocket(ctx, &pfconfigdriver.Config.Interfaces.ListenInts)
+	pfconfigdriver.FetchDecodeSocket(ctx, &pfconfigdriver.Config.Interfaces.DNSInts)
 
 	var keyConfNet pfconfigdriver.PfconfigKeys
 	keyConfNet.PfconfigNS = "config::Network"
@@ -537,7 +547,16 @@ func (pf *pfdns) detectType() error {
 	var keyConfCluster pfconfigdriver.NetInterface
 	keyConfCluster.PfconfigNS = "config::Pf(CLUSTER," + pfconfigdriver.FindClusterName(ctx) + ")"
 
-	for _, v := range interfaces.Element {
+	var intDNS []string
+
+	for _, vi := range pfconfigdriver.Config.Interfaces.DNSInts.Element {
+		for key, DNSint := range vi.(map[string]interface{}) {
+			if key == "int" {
+				intDNS = append(intDNS, DNSint.(string))
+			}
+		}
+	}
+	for _, v := range sharedutils.RemoveDuplicates(append(pfconfigdriver.Config.Interfaces.ListenInts.Element, intDNS...)) {
 
 		keyConfCluster.PfconfigHashNS = "interface " + v
 		pfconfigdriver.FetchDecodeSocket(ctx, &keyConfCluster)
@@ -576,8 +595,7 @@ func (pf *pfdns) detectType() error {
 	return nil
 }
 
-func (pf *pfdns) DbInit() error {
-	var ctx = context.Background()
+func (pf *pfdns) DbInit(ctx context.Context) error {
 
 	var err error
 
@@ -737,6 +755,11 @@ func (pf *pfdns) MakeDetectionMecanism(ctx context.Context) error {
 
 	pfconfigdriver.FetchDecodeSocket(ctx, &portal)
 
+	pf.detectionBypass = false
+	if portal.DetectionMecanismBypass == "enabled" {
+		pf.detectionBypass = true
+	}
+
 	pf.detectionMechanisms = make([]*regexp.Regexp, 0)
 	var err error
 	for _, v := range portal.DetectionMecanismUrls {
@@ -765,7 +788,7 @@ func (pf *pfdns) addDetectionMechanismsToList(ctx context.Context, r string) err
 
 // checkDetectionMechanisms compare the url to the detection mechanisms regex
 func (pf *pfdns) checkDetectionMechanisms(ctx context.Context, e string) bool {
-	if pf.detectionMechanisms == nil {
+	if pf.detectionMechanisms == nil || pf.detectionBypass {
 		return false
 	}
 	for _, rgx := range pf.detectionMechanisms {
