@@ -6,17 +6,19 @@ import (
 	"sync"
 	"time"
 
+	"github.com/coredns/caddy"
 	"github.com/inverse-inc/packetfence/go/coredns/core/dnsserver"
 	"github.com/inverse-inc/packetfence/go/coredns/plugin"
 	"github.com/inverse-inc/packetfence/go/pfconfigdriver"
 	"github.com/inverse-inc/packetfence/go/timedlock"
 	"github.com/inverse-inc/packetfence/go/unifiedapiclient"
-	"github.com/mholt/caddy"
 	cache "github.com/patrickmn/go-cache"
 )
 
 func init() {
 	GlobalTransactionLock = timedlock.NewRWLock()
+	GlobalTransactionLock.Panic = false
+	GlobalTransactionLock.PrintErrors = true
 	caddy.RegisterPlugin("pfdns", caddy.Plugin{
 		ServerType: "dns",
 		Action:     setuppfdns,
@@ -26,8 +28,15 @@ func init() {
 func setuppfdns(c *caddy.Controller) error {
 	var pf = &pfdns{}
 	var ip net.IP
+	pf.Network = make(map[string]net.IP)
 	ctx := context.Background()
 	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.PfConf.General)
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.PfConf.CaptivePortal)
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.Interfaces.ListenInts)
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.Interfaces.DNSInts)
+
+	pfconfigdriver.PfconfigPool.Refresh(ctx)
+
 	for c.Next() {
 		// block with extra parameters
 		for c.NextBlock() {
@@ -45,29 +54,29 @@ func setuppfdns(c *caddy.Controller) error {
 		}
 	}
 
-	if err := pf.DbInit(); err != nil {
+	if err := pf.DbInit(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize database connection")
 	}
-	if err := pf.PassthroughsInit(); err != nil {
+	if err := pf.PassthroughsInit(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize passthrough")
 	}
-	if err := pf.PassthroughsIsolationInit(); err != nil {
+	if err := pf.PassthroughsIsolationInit(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize isolation passthrough")
 	}
 
-	if err := pf.WebservicesInit(); err != nil {
+	if err := pf.WebservicesInit(ctx); err != nil {
 		return c.Errf("pfdns: unable to fetch Webservices credentials")
 	}
 
-	if err := pf.detectVIP(); err != nil {
+	if err := pf.detectVIP(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize the vip network map")
 	}
 
-	if err := pf.DomainPassthroughInit(); err != nil {
+	if err := pf.DomainPassthroughInit(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize domain passthrough")
 	}
 
-	if err := pf.detectType(); err != nil {
+	if err := pf.detectType(ctx); err != nil {
 		return c.Errf("pfdns: unable to initialize Network Type")
 	}
 
@@ -91,6 +100,7 @@ func setuppfdns(c *caddy.Controller) error {
 
 	dnsserver.GetConfig(c).AddPlugin(
 		func(next plugin.Handler) plugin.Handler {
+			pf.InternalPortalIP = net.ParseIP(pfconfigdriver.Config.PfConf.CaptivePortal.IpAddress).To4()
 			pf.RedirectIP = ip
 			pf.Next = next
 			return pf
