@@ -6,6 +6,7 @@ import (
 	"encoding/json"
 	"errors"
 	"fmt"
+	"html/template"
 	"net"
 	"net/http"
 	"net/http/httputil"
@@ -14,7 +15,6 @@ import (
 	"regexp"
 	"strings"
 	"sync"
-	"text/template"
 	"time"
 
 	"github.com/inverse-inc/packetfence/go/db"
@@ -41,10 +41,11 @@ type Proxy struct {
 type passthrough struct {
 	proxypassthrough        []*regexp.Regexp
 	detectionmechanisms     []*regexp.Regexp
-	DetectionMecanismBypass bool
 	mutex                   sync.Mutex
 	PortalURL               map[int]map[*net.IPNet]*url.URL
 	URIException            *regexp.Regexp
+	OtherDomains            []*regexp.Regexp
+	DetectionMecanismBypass bool
 	SecureRedirect          bool
 	Wispr                   bool
 }
@@ -53,21 +54,32 @@ type fqdn struct {
 	FQDN map[*net.IPNet]*url.URL
 }
 
+type RFC7710bis struct {
+	UserPortalURL    string `json:"user-portal-url"`
+	VenueInfoURL     string `json:"venue-info-url,omitempty"`
+	SecondsRemaining int    `json:"seconds-remaining,omitempty"`
+	BytesRemaining   int    `json:"bytes-remaining,omitempty"`
+	CanExtendSession bool   `json:"can-extend-session,omitempty"`
+	Captive          bool   `json:"captive"`
+}
+
 var passThrough *passthrough
 
 // TenantID constant
 const TenantID = 1
 
+var successDBConnect = false
+
 // NewProxy creates a new instance of proxy.
 // It sets request logger using rLogPath as output file or os.Stdout by default.
 // If whitePath of blackPath is not empty they are parsed to set endpoint lists.
 func NewProxy(ctx context.Context) *Proxy {
-	var p Proxy
+	p := &Proxy{}
 
 	passThrough = newProxyPassthrough(ctx)
 	passThrough.readConfig(ctx)
 	p.Configure(ctx)
-	return &p
+	return p
 }
 
 // Refresh the configuration
@@ -124,6 +136,25 @@ func (p *Proxy) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 
 	parking := p.handleParking(ctx, w, r)
 
+	if r.URL.Path == "/rfc7710" {
+		_, PortalURL := p.detectPortalURL(r)
+
+		answer := RFC7710bis{}
+
+		answer.Captive = true
+		if p.DetectRegistrationStatus(ctx, w, r) {
+			answer.Captive = false
+		}
+		answer.UserPortalURL = PortalURL.String()
+		w.Header().Set("Cache-Control", "private")
+		w.Header().Set("Content-Type", "application/captive+json")
+		w.WriteHeader(http.StatusOK)
+		if err := json.NewEncoder(w).Encode(&answer); err != nil {
+			fmt.Println(err)
+		}
+		return
+	}
+
 	if r.URL.Path == "/kindle-wifi/wifistub.html" {
 		log.LoggerWContext(ctx).Debug(fmt.Sprintln(host, "KINDLE WIFI PROBE HANDLING"))
 		w.WriteHeader(http.StatusOK)
@@ -151,6 +182,9 @@ func (p *Proxy) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 		}
 
 		_, PortalURL := p.detectPortalURL(r)
+		if passThrough.checkOtherDomains(ctx, fqdn.Host) {
+			PortalURL.Host = fqdn.Host
+		}
 
 		log.LoggerWContext(ctx).Debug(fmt.Sprintln(host, "Redirect to the portal"))
 
@@ -238,10 +272,40 @@ func (p *Proxy) ServeHTTP(w http.ResponseWriter, r *http.Request) {
 func (p *Proxy) Configure(ctx context.Context) {
 	p.addToEndpointList(ctx, "localhost")
 	p.addToEndpointList(ctx, "127.0.0.1")
+	p.addToEndpointList(ctx, "127.1")
+	p.addToEndpointList(ctx, "127.0.1")
+	p.addToEndpointList(ctx, "0177.1")
+	p.addToEndpointList(ctx, "0177.0.1")
+	p.addToEndpointList(ctx, "0x7f.1")
+	p.addToEndpointList(ctx, "0x7f.0.1")
+	p.addToEndpointList(ctx, "7f.00.00.01")
+	p.addToEndpointList(ctx, "0x7f.0x0.0x0.0x1")
+	p.addToEndpointList(ctx, "0177.0.0.01")
+	p.addToEndpointList(ctx, "2130706433")
+	p.addToEndpointList(ctx, "0x7f.0.0.0x1")
+	p.addToEndpointList(ctx, "7f.00.00.01")
+	p.addToEndpointList(ctx, "0x7f000001")
+	// protection against SSRF obfuscation in order to trigger the localhost vhost.
 
-	db, err := db.DbFromConfig(ctx)
-	sharedutils.CheckError(err)
-	p.Db = db
+	Database, err := db.DbFromConfig(ctx)
+	for err != nil {
+		if err != nil {
+			time.Sleep(time.Duration(5) * time.Second)
+		}
+
+		Database, err = db.DbFromConfig(ctx)
+	}
+
+	for !successDBConnect {
+		err = Database.Ping()
+		if err != nil {
+			time.Sleep(time.Duration(5) * time.Second)
+		} else {
+			successDBConnect = true
+		}
+	}
+
+	p.Db = Database
 
 	p.IP4log, err = p.Db.Prepare("select mac from ip4log where ip = ? AND tenant_id = ?")
 	if err != nil {
@@ -277,13 +341,21 @@ func (p *Proxy) Configure(ctx context.Context) {
 
 	go func() {
 		for {
-			p.Db.Ping()
-			time.Sleep(5 * time.Second)
+			err = p.Db.Ping()
+			if err != nil {
+				p.Db, err = db.DbFromConfig(ctx)
+			}
+			time.Sleep(time.Duration(5) * time.Second)
 		}
 	}()
+
 }
 
 func (p *passthrough) readConfig(ctx context.Context) {
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.PfConf.Fencing)
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.PfConf.General)
+	pfconfigdriver.PfconfigPool.AddStruct(ctx, &pfconfigdriver.Config.PfConf.CaptivePortal)
+
 	fencing := pfconfigdriver.Config.PfConf.Fencing
 	general := pfconfigdriver.Config.PfConf.General
 	portal := pfconfigdriver.Config.PfConf.CaptivePortal
@@ -300,6 +372,11 @@ func (p *passthrough) readConfig(ctx context.Context) {
 		p.addDetectionMechanismsToList(ctx, v)
 	}
 
+	p.OtherDomains = make([]*regexp.Regexp, 0)
+	for _, v := range portal.OtherDomainNames {
+		p.addOtherDomainsToList(ctx, v)
+	}
+
 	p.DetectionMecanismBypass = portal.DetectionMecanismBypass == "enabled"
 
 	rgx, _ := regexp.Compile("CaptiveNetworkSupport")
@@ -400,6 +477,17 @@ func (p *passthrough) addDetectionMechanismsToList(ctx context.Context, r string
 	return err
 }
 
+// addOtherDomainsToList add all detection mechanisms in a list
+func (p *passthrough) addOtherDomainsToList(ctx context.Context, r string) error {
+	rgx, err := regexp.Compile(r)
+	if err == nil {
+		p.mutex.Lock()
+		p.OtherDomains = append(p.OtherDomains, rgx)
+		p.mutex.Unlock()
+	}
+	return err
+}
+
 // checkProxyPassthrough compare the host to the list of regex
 func (p *passthrough) checkProxyPassthrough(ctx context.Context, e string) bool {
 	if p.proxypassthrough == nil {
@@ -428,6 +516,20 @@ func (p *passthrough) checkDetectionMechanisms(ctx context.Context, e string) bo
 	return false
 }
 
+// checkOtherDomains compare the url to the detection mechanisms regex
+func (p *passthrough) checkOtherDomains(ctx context.Context, e string) bool {
+	if p.OtherDomains == nil {
+		return false
+	}
+
+	for _, rgx := range p.OtherDomains {
+		if rgx.MatchString(e) {
+			return true
+		}
+	}
+	return false
+}
+
 // HasSecurityEvents search for parking security event
 func (p *Proxy) HasSecurityEvents(ctx context.Context, mac string) bool {
 	securityEvent := false
@@ -479,32 +581,30 @@ func (p *Proxy) handleParking(ctx context.Context, w http.ResponseWriter, r *htt
 
 	ipAddress = p.getIP(ctx, r)
 
-	if ipAddress != "" {
-		MAC, err := p.IP2Mac(ctx, ipAddress)
-		if err == nil {
-			if p.HasSecurityEvents(ctx, MAC) && p.ShowParkingPortal {
-				if found && (PortalURL.Host == r.Host) {
-					if r.RequestURI == "/release-parking" {
-						reqURL := r.URL
-						// Call the API
-						err = p.APIUnpark(ctx, MAC, ipAddress)
-						if err == nil {
-							reqURL.Path = "/back-on-network.html"
-						} else {
-							reqURL.Path = "/max-attempts.html"
-						}
-						r.URL = reqURL
+	MAC, err := p.IP2Mac(ctx, ipAddress)
+	if err == nil {
+		if p.HasSecurityEvents(ctx, MAC) && p.ShowParkingPortal {
+			if found && (PortalURL.Host == r.Host) {
+				if r.RequestURI == "/release-parking" {
+					reqURL := r.URL
+					// Call the API
+					err = p.APIUnpark(ctx, MAC, ipAddress)
+					if err == nil {
+						reqURL.Path = "/back-on-network.html"
+					} else {
+						reqURL.Path = "/max-attempts.html"
 					}
-					if rgx.MatchString(r.RequestURI) {
-						reverseHost = "127.0.0.1:8889"
-					}
-					log.LoggerWContext(ctx).Info("Parking detected for " + MAC)
-					p.reverse(ctx, w, r, reverseHost)
+					r.URL = reqURL
 				}
-				return true
+				if rgx.MatchString(r.RequestURI) {
+					reverseHost = "127.0.0.1:8889"
+				}
+				log.LoggerWContext(ctx).Info("Parking detected for " + MAC)
+				p.reverse(ctx, w, r, reverseHost)
 			}
-			return false
+			return true
 		}
+		return false
 	}
 	return false
 }
@@ -533,14 +633,12 @@ func (p *Proxy) handleDetectionMechanismRegister(ctx context.Context, w http.Res
 	var ipAddress string
 	ipAddress = p.getIP(ctx, r)
 
-	if ipAddress != "" {
-		MAC, err := p.IP2Mac(ctx, ipAddress)
+	MAC, err := p.IP2Mac(ctx, ipAddress)
 
-		if err == nil {
-			if p.nodeIsReg(ctx, MAC) && passThrough.checkDetectionMechanisms(ctx, fqdn) {
-				log.LoggerWContext(ctx).Info("Device register and match the portal detection mechanism for " + MAC)
-				p.reverse(ctx, w, r, r.Host)
-			}
+	if err == nil {
+		if p.nodeIsReg(ctx, MAC) && passThrough.checkDetectionMechanisms(ctx, fqdn) {
+			log.LoggerWContext(ctx).Info("Device register and match the portal detection mechanism for " + MAC)
+			p.reverse(ctx, w, r, r.Host)
 		}
 	}
 }
@@ -562,7 +660,7 @@ func (p *Proxy) nodeIsReg(ctx context.Context, mac string) bool {
 func (p *Proxy) getIP(ctx context.Context, r *http.Request) string {
 
 	var ipAddress string
-
+	ipAddress = "0.0.0.0"
 	fwdAddress := r.Header.Get("X-Forwarded-For")
 	if fwdAddress != "" {
 
@@ -627,3 +725,21 @@ func (p *Proxy) APIUnpark(ctx context.Context, mac string, ip string) error {
 	}
 	return nil
 }
+
+func (p *Proxy) DetectRegistrationStatus(ctx context.Context, w http.ResponseWriter, r *http.Request) bool {
+	var ipAddress string
+	ipAddress = p.getIP(ctx, r)
+
+	if ipAddress != "" {
+		MAC, err := p.IP2Mac(ctx, ipAddress)
+
+		if err == nil {
+			if p.nodeIsReg(ctx, MAC) {
+				return true
+			}
+			return false
+		}
+		return false
+	}
+	return false
+}
