@@ -53,6 +53,7 @@ type configStruct struct {
 		ManagementNetwork ManagementNetwork
 		DHCPInts          DHCPInts
 		DNSInts           DNSInts
+		RADIUSInts        RADIUSInts
 	}
 	PfConf struct {
 		Advanced      PfConfAdvanced
@@ -64,6 +65,7 @@ type configStruct struct {
 		Parking       PfConfParking
 		Alerting      PfConfAlerting
 		ActiveActive  PfConfActiveActive
+		Services      PfConfServices
 	}
 	AdminRoles AdminRoles
 	Cluster    struct {
@@ -79,6 +81,7 @@ type configStruct struct {
 	}
 	UnifiedApiSystemUser UnifiedApiSystemUser
 	EAPConfiguration     EAPConfiguration
+	RolesChildren        RolesChildren
 }
 
 var Config configStruct
@@ -122,7 +125,6 @@ type PfConfFencing struct {
 	Range                 string   `json:"range"`
 	InterceptionProxyPort string   `json:"interception_proxy_port"`
 	Registration          string   `json:"registration"`
-	Whitelist             string   `json:"whitelist"`
 	ProxyPassthroughs     []string `json:"proxy_passthroughs"`
 	Passthroughs          []string `json:"passthroughs"`
 	WaitForRedirect       string   `json:"wait_for_redirect"`
@@ -134,6 +136,7 @@ type PfConfCaptivePortal struct {
 	PfconfigMethod               string   `val:"hash_element"`
 	PfconfigNS                   string   `val:"config::Pf"`
 	PfconfigHashNS               string   `val:"captive_portal"`
+	IpAddress                    string   `json:"ip_address"`
 	DetectionMecanismBypass      string   `json:"detection_mecanism_bypass"`
 	DetectionMecanismUrls        []string `json:"detection_mecanism_urls"`
 	NetworkDetection             string   `json:"network_detection"`
@@ -147,6 +150,58 @@ type PfConfCaptivePortal struct {
 	SecureRedirect               string   `json:"secure_redirect"`
 	StatusOnlyOnProduction       string   `json:"status_only_on_production"`
 	WisprRedirection             string   `json:"wispr_redirection"`
+	RateLimiting                 string   `json:"rate_limiting"`
+	RateLimitingThreshold        string   `json:"rate_limiting_threshold"`
+	OtherDomainNames             []string `json:"other_domain_names"`
+}
+
+type PfConfServices struct {
+	StructConfig
+	PfconfigMethod       string `val:"hash_element"`
+	PfconfigNS           string `val:"config::Pf"`
+	PfconfigHashNS       string `val:"services"`
+	ApiFrontend          string `json:"api-frontend"`
+	GaleraAutofix        string `json:"galera-autofix"`
+	FingerbankCollector  string `json:"fingerbank-collector"`
+	HaproxyAdmin         string `json:"haproxy-admin"`
+	HaproxyDB            string `json:"haproxy-db"`
+	HaproxyPortal        string `json:"haproxy-portal"`
+	HttpdAAA             string `json:"httpd_aaa"`
+	HttpdAdmin           string `json:"httpd_admin"`
+	HttpdCollector       string `json:"httpd_collector"`
+	HttpdAdminDispatcher string `json:"httpd_admin_dispatcher"`
+	HttpdDispatcher      string `json:"httpd_dispatcher"`
+	HttpdPortal          string `json:"httpd_portal"`
+	HttpdProxy           string `json:"httpd_proxy"`
+	HttpdWebservices     string `json:"httpd_webservices"`
+	Iptables             string `json:"iptables"`
+	Keepalived           string `json:"keepalived"`
+	Netdata              string `json:"netdata"`
+	NetFlowAddress       string `json:"netflow_address"`
+	Pfacct               string `json:"pfacct"`
+	PfcertManager        string `json:"pfcertmanager"`
+	Pfdhcp               string `json:"pfdhcp"`
+	Pfdhcplistener       string `json:"pfdhcplistener"`
+	Pfdns                string `json:"pfdns"`
+	Pffilter             string `json:"pffilter"`
+	Pfipset              string `json:"pfipset"`
+	Pfcron               string `json:"pfcron"`
+	PfperlAPI            string `json:"pfperl-api"`
+	PfPKI                string `json:"pfpki"`
+	Pfqueue              string `json:"pfqueue"`
+	PfSSO                string `json:"pfsso"`
+	Pfstats              string `json:"pfstats"`
+	Radiusd              string `json:"radiusd"`
+	RadiusdAcct          string `json:"radiusd_acct"`
+	RadiusdAuth          string `json:"radiusd_auth"`
+	Radsniff             string `json:"radsniff"`
+	RedisCache           string `json:"redis_cache"`
+	RedisNtlmCache       string `json:"redis_ntlm_cache"`
+	RedisQueue           string `json:"redis_queue"`
+	Snmptrapd            string `json:"snmptrapd"`
+	TC                   string `json:"tc"`
+	TrackingConfig       string `json:"tracking-config"`
+	Winbindd             string `json:"winbindd"`
 }
 
 type PfConfWebservices struct {
@@ -257,6 +312,14 @@ type DNSInts struct {
 	Element                 []interface{}
 }
 
+type RADIUSInts struct {
+	StructConfig
+	PfconfigMethod          string `val:"element"`
+	PfconfigNS              string `val:"interfaces::radius_ints"`
+	PfconfigArray           string `val:"yes"`
+	PfconfigHostnameOverlay string `val:"yes"`
+	Element                 []interface{}
+}
 type PfClusterIp struct {
 	StructConfig
 	PfconfigMethod             string `val:"hash_element"`
@@ -340,6 +403,7 @@ type RessourseNetworkConf struct {
 	PoolBackend              string    `json:"pool_backend"`
 	Algorithm                string    `json:"algorithm"`
 	NetflowAccountingEnabled string    `json:"netflow_accounting_enabled"`
+	NatDNS                   string    `json:"nat_dns"`
 }
 
 type PfRoles struct {
@@ -358,6 +422,14 @@ type RolesConf struct {
 	MaxNodesPerPid string `json:"max_nodes_per_pid"`
 }
 
+type RolesChildren struct {
+	StructConfig
+	PfconfigMethod          string `val:"element"`
+	PfconfigNS              string `val:"resource::roles_children"`
+	PfconfigDecodeInElement string `val:"yes"`
+	Element                 map[string][]string
+}
+
 type ClusterName struct {
 	StructConfig
 	PfconfigMethod          string `val:"hash_element"`
@@ -367,6 +439,14 @@ type ClusterName struct {
 	Element                 string
 }
 
+type LocalSecret struct {
+	StructConfig
+	PfconfigMethod          string `val:"element"`
+	PfconfigNS              string `val:"resource::local_secret"`
+	PfconfigDecodeInElement string `val:"yes"`
+	Element                 string
+}
+
 type NetInterface struct {
 	StructConfig
 	PfconfigHostnameOverlay string `val:"yes"`
@@ -401,6 +481,8 @@ type AuthenticationSourceEduroam struct {
 	RadiusSecret   string `json:"radius_secret"`
 	Server1Address string `json:"server1_address"`
 	Server2Address string `json:"server2_address"`
+	Server1Port    string `json:"server1_port"`
+	Server2Port    string `json:"server2_port"`
 	Monitor        string `json:"monitor"`
 	Type           string `json:"type"`
 }
@@ -421,23 +503,23 @@ type AuthenticationSourceRadius struct {
 
 type AuthenticationSourceLdap struct {
 	StructConfig
-	PfconfigMethod    string `val:"hash_element"`
-	PfconfigNS        string `val:"resource::authentication_sources_ldap"`
-	PfconfigHashNS    string `val:"-"`
-	Description       string `json:"description"`
-	Password          string `json:"password"`
-	Port              string `json:"port"`
-	Host              string `json:"host"`
-	ReadTimeout       string `json:"read_timeout"`
-	WriteTimeout      string `json:"write_timeout"`
-	BaseDN            string `json:"basedn"`
-	Scope             string `json:"scope"`
-	EmailAttribute    string `json:"email_attribute"`
-	UserNameAttribute string `json:"usernameattribute"`
-	BindDN            string `json:"binddn"`
-	Encryption        string `json:"encryption"`
-	Monitor           string `json:"monitor"`
-	Type              string `json:"type"`
+	PfconfigMethod    string   `val:"hash_element"`
+	PfconfigNS        string   `val:"resource::authentication_sources_ldap"`
+	PfconfigHashNS    string   `val:"-"`
+	Description       string   `json:"description"`
+	Password          string   `json:"password"`
+	Port              string   `json:"port"`
+	Host              []string `json:"host"`
+	ReadTimeout       string   `json:"read_timeout"`
+	WriteTimeout      string   `json:"write_timeout"`
+	BaseDN            string   `json:"basedn"`
+	Scope             string   `json:"scope"`
+	EmailAttribute    string   `json:"email_attribute"`
+	UserNameAttribute string   `json:"usernameattribute"`
+	BindDN            string   `json:"binddn"`
+	Encryption        string   `json:"encryption"`
+	Monitor           string   `json:"monitor"`
+	Type              string   `json:"type"`
 }
 
 type PfStats struct {
@@ -470,33 +552,35 @@ type ClusterSummary struct {
 
 type PfConfAdvanced struct {
 	StructConfig
-	PfconfigMethod                   string   `val:"hash_element"`
-	PfconfigNS                       string   `val:"config::Pf"`
-	PfconfigHashNS                   string   `val:"advanced"`
-	HashingCost                      string   `json:"hashing_cost"`
-	ScanOnAccounting                 string   `json:"scan_on_accounting"`
-	PffilterProcesses                string   `json:"pffilter_processes"`
-	UpdateIplogWithAccounting        string   `json:"update_iplog_with_accounting"`
-	AdminCspSecurityHeaders          string   `json:"admin_csp_security_headers"`
-	Multihost                        string   `json:"multihost"`
-	SsoOnAccessReevaluation          string   `json:"sso_on_access_reevaluation"`
-	DisablePfDomainAuth              string   `json:"disable_pf_domain_auth"`
-	TimingStatsLevel                 string   `json:"timing_stats_level"`
-	SsoOnDhcp                        string   `json:"sso_on_dhcp"`
-	Language                         string   `json:"language"`
-	StatsdListenPort                 string   `json:"statsd_listen_port"`
-	SsoOnAccounting                  string   `json:"sso_on_accounting"`
-	LocationlogCloseOnAccountingStop string   `json:"locationlog_close_on_accounting_stop"`
-	PortalCspSecurityHeaders         string   `json:"portal_csp_security_headers"`
-	HashPasswords                    string   `json:"hash_passwords"`
-	SourceToSendSmsWhenCreatingUsers string   `json:"source_to_send_sms_when_creating_users"`
-	ActiveDirectoryOsJoinCheckBypass string   `json:"active_directory_os_join_check_bypass"`
-	PfperlApiTimeout                 string   `json:"pfperl_api_timeout"`
-	LdapAttributes                   []string `json:"ldap_attributes"`
-	ApiInactivityTimeout             int      `json:"api_inactivity_timeout"`
-	ApiMaxExpiration                 int      `json:"api_max_expiration"`
-	NetFlowOnAllNetworks             string   `json:"netflow_on_all_networks"`
-	AccountingTimebucketSize         int      `json:"accounting_timebucket_size"`
+	PfconfigMethod                   string      `val:"hash_element"`
+	PfconfigNS                       string      `val:"config::Pf"`
+	PfconfigHashNS                   string      `val:"advanced"`
+	HashingCost                      string      `json:"hashing_cost"`
+	ScanOnAccounting                 string      `json:"scan_on_accounting"`
+	PffilterProcesses                string      `json:"pffilter_processes"`
+	UpdateIplogWithAccounting        string      `json:"update_iplog_with_accounting"`
+	AdminCspSecurityHeaders          string      `json:"admin_csp_security_headers"`
+	Multihost                        string      `json:"multihost"`
+	SsoOnAccessReevaluation          string      `json:"sso_on_access_reevaluation"`
+	DisablePfDomainAuth              string      `json:"disable_pf_domain_auth"`
+	TimingStatsLevel                 string      `json:"timing_stats_level"`
+	SsoOnDhcp                        string      `json:"sso_on_dhcp"`
+	Language                         string      `json:"language"`
+	StatsdListenPort                 string      `json:"statsd_listen_port"`
+	SsoOnAccounting                  string      `json:"sso_on_accounting"`
+	LocationlogCloseOnAccountingStop string      `json:"locationlog_close_on_accounting_stop"`
+	PortalCspSecurityHeaders         string      `json:"portal_csp_security_headers"`
+	HashPasswords                    string      `json:"hash_passwords"`
+	SourceToSendSmsWhenCreatingUsers string      `json:"source_to_send_sms_when_creating_users"`
+	ActiveDirectoryOsJoinCheckBypass string      `json:"active_directory_os_join_check_bypass"`
+	PfperlApiTimeout                 string      `json:"pfperl_api_timeout"`
+	LdapAttributes                   []string    `json:"ldap_attributes"`
+	ApiInactivityTimeout             int         `json:"api_inactivity_timeout"`
+	ApiMaxExpiration                 int         `json:"api_max_expiration"`
+	NetFlowOnAllNetworks             string      `json:"netflow_on_all_networks"`
+	AccountingTimebucketSize         int         `json:"accounting_timebucket_size"`
+	ZeroTrustNetworkStartingIP       string      `json:"zero_trust_network_starting_ip"`
+	ZeroTrustNetworkNetmask          json.Number `json:"zero_trust_network_netmask"`
 }
 
 type PfConfDns struct {
@@ -557,6 +641,14 @@ type ClusterServer struct {
 	Host         string `json:"host"`
 }
 
+type AllClusterServersRaw struct {
+	StructConfig
+	PfconfigMethod string `val:"element"`
+	PfconfigNS     string `val:"resource::all_cluster_servers"`
+	PfconfigArray  string `val:"yes"`
+	Element        []interface{}
+}
+
 type SyslogFiles struct {
 	StructConfig
 	PfconfigMethod string `val:"element"`
@@ -652,3 +744,19 @@ type EAPConfiguration struct {
 	PfconfigHostnameOverlay string `val:"yes"`
 	Element                 map[string]EAP
 }
+
+type Cron struct {
+	StructConfig
+	PfconfigMethod          string `val:"element"`
+	PfconfigNS              string `val:"config::Cron"`
+	PfconfigDecodeInElement string `val:"yes"`
+	Element                 map[string]interface{}
+}
+
+type NtlmRedisCachedDomains struct {
+	StructConfig
+	PfconfigMethod          string `val:"element"`
+	PfconfigNS              string `val:"resource::NtlmRedisCachedDomains"`
+	PfconfigDecodeInElement string `val:"yes"`
+	Element                 []string
+}
