@@ -32,6 +32,7 @@ use pf::api::queue;
 use pf::file_paths qw($install_dir);
 use pf::config qw(%Config);
 use pf::activation;
+use fingerbank::Config;
 
 has 'session' => (is => 'rw', required => 1);
 
@@ -136,6 +137,11 @@ Fingerbank processing
 sub process_fingerbank {
     my ( $self ) = @_;
 
+    unless(fingerbank::Config::is_api_key_configured()) {
+        get_logger->debug("Skipping Fingerbank processing because no API key is configured");
+        return $FALSE;
+    }
+
     my $attributes = pf::fingerbank::endpoint_attributes($self->current_mac);
     if($attributes->{most_accurate_user_agent} ne $self->current_user_agent) {
         pf::fingerbank::update_collector_endpoint_data($self->current_mac, {
@@ -582,7 +588,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
