@@ -115,7 +115,12 @@ after validate => sub {
     my ($self) = @_;
     my $value = $self->value;
     my $advanced_filter = $value->{advanced_filter};
-    if (@{$value->{filter}} == 0 && !defined $advanced_filter) {
+    my $condition_str = '';
+    if (defined $advanced_filter) {
+        $condition_str = pf::condition_parser::object_to_str($advanced_filter);
+    }
+
+    if (@{$value->{filter}} == 0 && (!defined $advanced_filter || $condition_str eq '')) {
         $self->field('filter')->add_error("A filter or an advanced filter must be specified");
         $self->field('advanced_filter')->add_error("A filter or an advanced filter must be specified");
     }
@@ -169,7 +174,7 @@ The main definition block
 
 has_block 'definition' =>
   (
-    render_list => [qw(id description status root_module preregistration autoregister reuse_dot1x_credentials dot1x_recompute_role_from_portal mac_auth_recompute_role_from_portal dot1x_unset_on_unmatch dpsk default_psk_key unreg_on_acct_stop)],
+    render_list => [qw(id description status root_module preregistration autoregister reuse_dot1x_credentials dot1x_recompute_role_from_portal mac_auth_recompute_role_from_portal dot1x_unset_on_unmatch dpsk unbound_dpsk default_psk_key unreg_on_acct_stop)],
   );
 
 my %ADDITIONAL_FIELD_OPTIONS = (
@@ -190,6 +195,8 @@ sub options_field_names {
       category
       category_id
       computername
+      connection_sub_type
+      connection_type
       detect_date
       device_class
       device_manufacturer
@@ -222,22 +229,28 @@ sub options_field_names {
       machine_account
       notes
       pid
+      port
       realm
       regdate
       sessionid
+      ssid
       status
       stripped_user_name
+      switch
+      switch_mac
       tenant_id
       time_balance
       unregdate
+      uri
       user_agent
+      vlan
       voip
     );
 }
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
