@@ -21,9 +21,13 @@ use pf::config qw(%Config);
 
 our $META = pf::Authentication::Source::LDAPSource->meta;
 
+has_field 'host' => (
+    type => 'Repeatable',
+    required => 1,
+);
 
 # Form fields
-has_field 'host' =>
+has_field 'host.contains' =>
   (
    type => 'Text',
    label => 'Host',
@@ -40,6 +44,14 @@ has_field 'port' =>
    element_attr => {'placeholder' => '389'},
    default => $META->get_attribute('port')->default,
   );
+has_field 'dead_duration' =>
+  (
+    type         => 'PosInteger',
+    element_attr => {
+        'placeholder' => $META->get_attribute('dead_duration')->default
+    },
+    default => $META->get_attribute('dead_duration')->default,
+  );
 has_field 'connection_timeout' =>
   (
     type         => 'Float',
@@ -243,7 +255,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
