@@ -53,7 +53,7 @@ has_field 'description' =>
 has_field 'TenantId' =>
   (
    type => 'Select',
-   label => 'Type',
+   label => 'Tenant ID',
    options_method => \&options_tenant,
    element_class => ['chzn-deselect'],
   );
@@ -63,7 +63,6 @@ has_field 'type' =>
    type => 'Select',
    label => 'Type',
    element_class => ['chzn-deselect'],
-   required_when => { 'id' => sub { $_[0] eq 'default' } },
    messages => { required => 'Please select the type of the switch.' },
   );
 
@@ -80,7 +79,6 @@ has_field 'mode' =>
   (
    type => 'Select',
    label => 'Mode',
-   required_when => { 'id' => sub { $_[0] eq 'default' } },
    element_class => ['chzn-deselect'],
   );
 has_field 'deauthMethod' =>
@@ -577,6 +575,11 @@ sub _add_role_mappings {
         wrap_label_method => \&role_label_wrap,
     };
     push(@$list, $role . 'AccessList' => $text_area_field);
+    
+    my $toggle_field = {
+        type    => 'Toggle',
+    };
+    push(@$list, $role . 'DynamicAccessListFingerbank' => $toggle_field);
 }
 
 sub role_label_wrap {
@@ -834,7 +837,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
