@@ -69,7 +69,7 @@ sub options_attributes {
     my $self = shift;
 
     my $form = $self->form;
-    my @attributes = map {{label => $_->{value}, value => $_->{value}, attributes => {'data-type' => $_->{type}}}}
+    my @attributes = map {{label => ($_->{label} // $_->{value}), value => $_->{value}, attributes => {'data-type' => $_->{type}}}}
       @{$form->get_source->available_attributes // []};
 
     return @attributes;
@@ -131,7 +131,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
