@@ -92,6 +92,14 @@ has_field 'nat_enabled' => (
     label => 'Enable NATting',
 );
 
+has_field 'nat_dns' => (
+    type => 'Toggle',
+    checkbox_value => 1,
+    unchecked_value => 0,
+    default => 1,
+    label => 'Enable DNS NATting',
+);
+
 has_field 'split_network' => (
     type => 'Toggle',
     checkbox_value => 1,
@@ -207,7 +215,7 @@ sub validate {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
