@@ -270,6 +270,7 @@ sub get {
                 $result->{"$interface"}->{'dns'} = $network->{dns};
                 $result->{"$interface"}->{'dhcpd_enabled'} = $network->{dhcpd};
                 $result->{"$interface"}->{'nat_enabled'} = $network->{nat_enabled};
+                $result->{"$interface"}->{'nat_dns'} = $network->{nat_dns};
                 $result->{"$interface"}->{'split_network'} = $network->{split_network};
                 $result->{"$interface"}->{'coa'} = $network->{coa};
                 $result->{"$interface"}->{'netflow_accounting_enabled'} = $network->{netflow_accounting_enabled};
@@ -546,6 +547,7 @@ sub setType {
             }
             $network_ref->{dhcpd} = isenabled($interface_ref->{'dhcpd_enabled'}) ? 'enabled' : 'disabled';
             $network_ref->{nat_enabled} = isenabled($interface_ref->{'nat_enabled'}) ? 'enabled' : 'disabled';
+            $network_ref->{nat_dns} = isenabled($interface_ref->{'nat_dns'}) ? 'enabled' : 'disabled';
             $network_ref->{split_network} = isenabled($interface_ref->{'split_network'}) ? 'enabled' : 'disabled';
             $network_ref->{coa} = isenabled($interface_ref->{'coa'}) ? 'enabled' : 'disabled';
             $network_ref->{netflow_accounting_enabled} = isenabled($interface_ref->{'netflow_accounting_enabled'}) ? 'enabled' : 'disabled';
@@ -886,7 +888,7 @@ sub _build_models {
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
