@@ -11,7 +11,7 @@ pf::Authentication::Source::LDAPSource
 use pf::log;
 use pf::constants qw($TRUE $FALSE);
 use pf::constants::authentication::messages;
-use pf::Authentication::constants qw($DEFAULT_LDAP_READ_TIMEOUT $DEFAULT_LDAP_WRITE_TIMEOUT $DEFAULT_LDAP_CONNECTION_TIMEOUT);
+use pf::Authentication::constants qw($DEFAULT_LDAP_READ_TIMEOUT $DEFAULT_LDAP_WRITE_TIMEOUT $DEFAULT_LDAP_CONNECTION_TIMEOUT $DEFAULT_LDAP_DEAD_DURATION);
 use pf::Authentication::Condition;
 use pf::CHI;
 use pf::util;
@@ -26,6 +26,7 @@ use pf::StatsD::Timer;
 use pf::util::statsd qw(called);
 
 use Moose;
+use pf::Moose::Types;
 extends 'pf::Authentication::Source';
 with qw(pf::Authentication::InternalRole);
 
@@ -49,7 +50,7 @@ Readonly our %ATTRIBUTES_MAP => (
 );
 
 has '+type' => (default => 'LDAP');
-has 'host' => (isa => 'Maybe[Str]', is => 'rw', default => '');
+has 'host' => (isa => 'ArrayOfStr', is => 'rw', default => sub { [] }, coerce => 1);
 has 'port' => (isa => 'Maybe[Int]', is => 'rw', default => 389);
 has 'connection_timeout' => ( isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_CONNECTION_TIMEOUT );
 has 'write_timeout' => (isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_WRITE_TIMEOUT);
@@ -67,6 +68,7 @@ has 'cache_match' => ( isa => 'Bool', is => 'rw', default => '0' );
 has 'email_attribute' => (isa => 'Maybe[Str]', is => 'rw', default => 'mail');
 has 'monitor' => ( isa => 'Bool', is => 'rw', default => '1' );
 has 'shuffle' => ( isa => 'Bool', is => 'rw', default => '0' );
+has 'dead_duration' => ( isa => 'Num', is => 'rw', default => $DEFAULT_LDAP_DEAD_DURATION);
 
 our $logger = get_logger();
 
@@ -223,7 +225,11 @@ sub _connect {
   my $connection;
   my $logger = Log::Log4perl::get_logger(__PACKAGE__);
   my ($LDAPServer, $LDAPServerPort);
-  my @LDAPServers = split(/\s*,\s*/, $self->{'host'});
+  my @LDAPServers = @{$self->{'host'} // []};
+  
+  # Lookup the server hostnames to IPs so they can be shuffled better and to improve the failure detection
+  @LDAPServers = map { valid_ip($_) ? $_ : @{resolve($_)} } @LDAPServers;
+
   if ($self->shuffle) {
       @LDAPServers = List::Util::shuffle @LDAPServers;
   }
@@ -232,40 +238,65 @@ sub _connect {
     @credentials = ($self->{'binddn'}, password => $self->{'password'})
   }
 
-  TRYSERVER:
-  foreach my $s (@LDAPServers) {
-    $LDAPServer = $s;
-    $LDAPServerPort = undef;
-    # check to see if the hostname includes a port (e.g. server:port)
-    if ($LDAPServer =~ /:/) {
-        $LDAPServerPort = (split(/:/, $LDAPServer))[-1];
-    }
-    $LDAPServerPort //=  $self->{'port'} ;
-    $connection = pf::LDAP->new(
-        $LDAPServer,
-        port       => $LDAPServerPort,
-        timeout    => $self->{'connection_timeout'},
-        write_timeout  => $self->{'write_timeout'},
-        read_timeout  => $self->{'read_timeout'},
-        encryption => $self->{encryption},
-        credentials => \@credentials,
-    );
+  my $try_connect = sub {
+      my $honor_dead = shift;
+      TRYSERVER:
+      foreach my $s (@LDAPServers) {
+        $LDAPServer = $s;
+        $LDAPServerPort =  $self->{'port'} ;
+        
+        my $dead_cache_key = "SERVER_DEAD:".$self->{id}.":$LDAPServer";
 
-    if (! defined($connection)) {
-      $logger->warn("[$self->{'id'}] Unable to connect to $LDAPServer");
-      next TRYSERVER;
-    }
+        if($honor_dead && $self->cache->get($dead_cache_key)) {
+          $logger->warn("[$self->{'id'}] $LDAPServer detected as dead, switching to next server");
+          next TRYSERVER;
+        }
+
+        $connection = pf::LDAP->new(
+            $LDAPServer,
+            port       => $LDAPServerPort,
+            timeout    => $self->{'connection_timeout'},
+            write_timeout  => $self->{'write_timeout'},
+            read_timeout  => $self->{'read_timeout'},
+            encryption => $self->{encryption},
+            credentials => \@credentials,
+        );
+
+        if (! defined($connection)) {
+          $logger->warn("[$self->{'id'}] Unable to connect to $LDAPServer");
+          if($honor_dead && $self->dead_duration) {
+              $self->cache->set($dead_cache_key, $TRUE, $self->dead_duration);
+          }
+          next TRYSERVER;
+        }
 
 
-    $logger->debug("[$self->{'id'}] Using LDAP connection to $LDAPServer");
-    return ( $connection, $LDAPServer, $LDAPServerPort );
+        $logger->debug("[$self->{'id'}] Using LDAP connection to $LDAPServer");
+        return ( $connection, $LDAPServer, $LDAPServerPort );
+      }
+      return ( undef, $LDAPServer, $LDAPServerPort );
+  };
+
+  ($connection, $LDAPServer, $LDAPServerPort) = $try_connect->($TRUE);
+
+  if (! defined($connection)) {
+    $logger->error("[$self->{'id'}] Unable to connect to any LDAP server, will try while ignoring the dead servers detection");
+    $pf::StatsD::statsd->increment("${timer_stat_prefix}.error.count" );
+  } else {
+    return ($connection, $LDAPServer, $LDAPServerPort);
   }
-  # if the connection is still undefined after trying every server, we fail and return undef.
+  
+  # If we're here then all servers were marked dead or failed to get a valid connection
+  # We now try again without honoring the dead servers flags
+  ($connection, $LDAPServer, $LDAPServerPort) = $try_connect->($FALSE);
+  
   if (! defined($connection)) {
     $logger->error("[$self->{'id'}] Unable to connect to any LDAP server");
     $pf::StatsD::statsd->increment("${timer_stat_prefix}.error.count" );
+    return (undef, $LDAPServer, $LDAPServerPort);
+  } else {
+    return ($connection, $LDAPServer, $LDAPServerPort);
   }
-  return (undef, $LDAPServer, $LDAPServerPort);
 }
 
 
@@ -327,11 +358,13 @@ rule_cache_key
 
 sub rule_cache_key {
     my ($self, $rule, $params, $extra) = @_;
-    my %allowed_conditions = map { $_->{attributes} => 1  } @{$self->{conditions} // []};
+    my %allowed_conditions = map { $_->{attribute} => 1 } @{$rule->{conditions} // []};
     my @key_values = (
         $self->{id},
         $rule->{id},
+        $rule->{class},
         $rule->{cache_key},
+        $params->{username} || $params->{email} || '',
         (
             map {
                 my $v = $_->{value};
@@ -715,7 +748,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
