@@ -24,7 +24,7 @@ extends 'pf::Authentication::Source';
 
 has '+class' => (default => 'external');
 has '+type' => (default => 'Null');
-has 'email_required' => (isa => 'Str', is => 'rw', default => 'no');
+has 'email_required' => (is => 'rw', default => 'no');
 
 =head2 authenticate
 
@@ -114,7 +114,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
