@@ -18,7 +18,7 @@ use Readonly;
 use pf::constants qw($TRUE $FALSE);
 
 use base qw(Exporter);
-our @EXPORT_OK = qw($LOCAL_ACCOUNT_UNLIMITED_LOGINS $LOGIN_SUCCESS $LOGIN_FAILURE $LOGIN_CHALLENGE $DEFAULT_LDAP_READ_TIMEOUT $DEFAULT_LDAP_WRITE_TIMEOUT $DEFAULT_LDAP_CONNECTION_TIMEOUT $HASH_PASSWORDS_DEFAULT $MATCH_NOT_FOUND);
+our @EXPORT_OK = qw($LOCAL_ACCOUNT_UNLIMITED_LOGINS $LOGIN_SUCCESS $LOGIN_FAILURE $LOGIN_CHALLENGE $DEFAULT_LDAP_READ_TIMEOUT $DEFAULT_LDAP_WRITE_TIMEOUT $DEFAULT_LDAP_CONNECTION_TIMEOUT $DEFAULT_LDAP_DEAD_DURATION $HASH_PASSWORDS_DEFAULT $MATCH_NOT_FOUND);
 
 Readonly::Scalar our $LOCAL_ACCOUNT_UNLIMITED_LOGINS => "0";
 Readonly::Scalar our $LOGIN_SUCCESS => $TRUE;
@@ -28,6 +28,7 @@ Readonly::Scalar our $MATCH_NOT_FOUND => 2;
 Readonly::Scalar our $DEFAULT_LDAP_READ_TIMEOUT => 10;
 Readonly::Scalar our $DEFAULT_LDAP_WRITE_TIMEOUT => 5;
 Readonly::Scalar our $DEFAULT_LDAP_CONNECTION_TIMEOUT => 1;
+Readonly::Scalar our $DEFAULT_LDAP_DEAD_DURATION => 60;
 Readonly::Scalar our $HASH_PASSWORDS_DEFAULT => 'bcrypt';
 
 
@@ -237,7 +238,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
