@@ -67,7 +67,7 @@ validates id
 
 =cut
 
-sub validId { 1; }
+sub validId { return defined($_[1]) && length($_[1]) > 0 }
 
 =head2 validParam
 
@@ -188,7 +188,7 @@ Get all the sections names
 =cut
 
 sub readAllIds {
-    my ($self,$itemKey) = @_;
+    my ($self) = @_;
     my @sections = $self->_Sections();
     return \@sections;
 }
@@ -212,17 +212,21 @@ _readAll
 
 sub _readAll {
     my ($self, $idKey, $method) = @_;
-    my $config = $self->cachedConfig;
     my $default_section = $self->default_section;
+    if (!defined $default_section) {
+        return [ map { $self->$method($_, $idKey) } $self->_Sections() ];
+    }
+
     my @sections;
     foreach my $id ($self->_Sections()) {
-        my $section = $self->$method($id,$idKey);
-        if (defined $default_section &&  $id eq $default_section ) {
+        my $section = $self->$method($id, $idKey);
+        if ( $id eq $default_section ) {
             unshift @sections, $section;
         } else {
             push @sections,$section;
         }
     }
+
     return \@sections;
 }
 
@@ -311,17 +315,18 @@ read all parameters from a section
 
 sub readFromSection {
     my ($self, $id, $idKey, $config) = @_;
-    my $data;
     my $section = $self->_formatSectionName($id);
-    if ( $config->SectionExists($section) ) {
-        $data = {};
-        $self->populateItem($config, $data, $section, $config->Parameters($section));
-        for my $parent ($self->parentSections($id, $data)) {
-            $self->populateItem($config, $data, $parent, grep {!exists $data->{$_}} $config->Parameters($parent))
-        }
-
-        $data->{$idKey} = $id if defined $idKey;
+    if ( !$config->SectionExists($section) ) {
+        return undef;
     }
+
+    my $data = {};
+    $self->populateItem($config, $data, $section, $config->Parameters($section));
+    for my $parent ($self->parentSections($id, $data)) {
+        $self->populateItem($config, $data, $parent, grep {!exists $data->{$_}} $config->Parameters($parent))
+    }
+
+    $data->{$idKey} = $id if defined $idKey;
     return $data;
 }
 
@@ -334,12 +339,11 @@ parentSections
 sub parentSections {
     my ($self, $id, $item) = @_;
     my $default_section = $self->default_section;
-    my @parents;
     if (defined $default_section && length($default_section) && $default_section ne $id) {
-        push @parents, $default_section;
+        return $default_section;
     }
 
-    return @parents;
+    return;
 }
 
 
@@ -351,19 +355,7 @@ populateItem
 
 sub populateItem {
     my ($self, $config, $item, $id, @params) = @_;
-    foreach my $param (@params) {
-        my $val;
-        my @vals = $config->val($id, $param);
-        if (@vals == 1 ) {
-            $val = $vals[0];
-        } elsif (@vals == 0) {
-            $val = undef;
-        } else {
-            $val = \@vals;
-        }
-
-        $item->{$param} = $val;
-    }
+    $config->populate($id, $item, @params);
     return ;
 }
 
@@ -406,7 +398,8 @@ sub update {
 sub _update_section {
     my ($self, $section, $assignments) = @_;
     my $config = $self->cachedConfig;
-    my $default_section = $self->default_section if defined($self->default_section);
+    my @parentSections = $self->parentSections($section, $assignments);
+    my $default_section = $parentSections[0];
     my $imported = $config->{imported} if exists $config->{imported};
     my $use_default = $default_section && $section ne $default_section;
     while ( my ($param, $value) = each %$assignments ) {
@@ -485,10 +478,22 @@ sub remove {
         return $msg, $deletable;
     }
 
-    my $deleted = $self->cachedConfig->DeleteSection($self->_formatSectionName($id));
+    $self->cleanupBeforeDelete($id);
+    my $section = $self->_formatSectionName($id);
+    my $deleted = $self->cachedConfig->DeleteSection($section);
     return "Removed", $deleted;
 }
 
+
+=head2 cleanupBeforeDelete
+
+cleanup Before Delete
+
+=cut
+
+sub cleanupBeforeDelete { }
+
+
 =head2 remove_always
 
 remove_always
@@ -824,7 +829,7 @@ sub flattenCondition {
 
     my $top_op = $condition->{op};
     if ($top_op eq 'and' || $top_op eq 'or' || $top_op eq 'not_and' || $top_op eq 'not_or') {
-        if (@{$condition->{values}} == 1) {
+        if (@{$condition->{values} // []} == 1) {
             $item->{top_op} = $top_op;
         }
     } else {
@@ -916,11 +921,31 @@ sub expand_ordered_array {
     return pf::util::expand_ordered_array($item, $items_key, $item_key);
 }
 
+sub join_list_cr {
+    my ($self, @list) = @_;
+    return join("\n",@list);
+}
+
+=head2 flatten_list_cr
+
+=cut
+
+sub flatten_list_cr {
+    my ($self, $object, @columns) = @_;
+    foreach my $column (@columns) {
+        next unless exists $object->{$column};
+        my $val = $object->{$column};
+        if (ref($val) eq 'ARRAY') {
+            $object->{$column} = $self->join_list_cr(@$val);
+        }
+    }
+}
+
 __PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
