@@ -15,6 +15,7 @@ pf::ConfigStore::VlanFilters
 use strict;
 use warnings;
 use Moo;
+use List::MoreUtils qw(any);
 use namespace::autoclean;
 extends 'pf::ConfigStore';
 
@@ -55,6 +56,19 @@ sub _fields_expanded {
     return qw(scopes);
 }
 
+sub _update_section {
+    my ($self, $section, $assignments) = @_;
+    my $cachedConfig = $self->cachedConfig;
+    my @array_items = $self->ordered_arrays;
+    for my $p ($cachedConfig->Parameters($section)) {
+        if ( any { $p =~ /^\Q$_->[1]\E\./ } @array_items ) {
+            $cachedConfig->delval($section, $p);
+        }
+    }
+
+    $self->SUPER::_update_section($section, $assignments);
+}
+
 __PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 AUTHOR
@@ -63,7 +77,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
