@@ -12,10 +12,7 @@ ConfigStore for L2 networks in networks.conf
 
 use Moo;
 use namespace::autoclean;
-use pf::log;
-use pf::config qw(%ConfigNetworks %Config);
-use pf::util qw(isenabled);
-use pf::file_paths qw($network_config_file);
+use pf::constants::config;
 
 extends 'pf::ConfigStore::Network';
 with 'pf::ConfigStore::Filtered';
@@ -32,14 +29,15 @@ Filter the sections of this ConfigStore
 
 sub filterSection {
     my ($self, $section) = @_;
-    return !$self->cachedConfig->exists($section, "next_hop");
+    my $cachedConfig = $self->cachedConfig;
+    return !$cachedConfig->exists($section, "next_hop") && $cachedConfig->val($section, 'type') ne $pf::constants::config::NET_TYPE_OTHER;
 }
 
 __PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
