@@ -37,8 +37,8 @@ _fields_expanded
 our %TYPE_TO_EXPANDED_FIELDS = (
     SMS => [qw(sms_carriers)],
     Eduroam => [qw(local_realm reject_realm)],
-    AD => [qw(searchattributes)],
-    LDAP => [qw(searchattributes)],
+    AD => [qw(searchattributes host)],
+    LDAP => [qw(searchattributes host)],
     SponsorEmail => [qw(sources)],
 );
 
@@ -196,11 +196,20 @@ sub join_options {
     return join("\n",@$options);
 }
 
+sub cleanupBeforeDelete {
+    my ($self, $id) = @_;
+    my $section = $self->_formatSectionName($id);
+    my $cachedConfig = $self->cachedConfig();
+    for my $sub_section ( grep {/^$section rule/} $cachedConfig->Sections ) {
+        $cachedConfig->DeleteSection($sub_section);
+    }
+}
+
 __PACKAGE__->meta->make_immutable unless $ENV{"PF_SKIP_MAKE_IMMUTABLE"};
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
