@@ -30,6 +30,10 @@ subtype 'PfInterval', as 'Int';
 
 coerce 'PfInterval', from 'Str', via { return normalize_time($_) };
 
+subtype 'ArrayOfStr', as 'ArrayRef[Str]';
+
+coerce 'ArrayOfStr', from 'Str', via { [ split(/\s*,\s*/, $_) ] };
+
 no Moose::Util::TypeConstraints;
 
 =head1 AUTHOR
@@ -38,7 +42,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
