@@ -432,15 +432,8 @@ sub returnRadiusAccessAccept {
             push @av_pairs, "url-redirect=".$redirect_url;
         }
     }
-    if ($args->{profile}->dpskEnabled()) {
-        if (defined($args->{owner}->{psk})) {
-            push @av_pairs, "psk=$args->{owner}->{psk}";
-        } else {
-            push @av_pairs, "psk=$args->{profile}->{_default_psk_key}";
-        }
-        push @av_pairs, "psk-mode=ascii";
-    }
 
+    $self->addDPSK($args, $radius_reply_ref, \@av_pairs);
     $radius_reply_ref->{'Cisco-AVPair'} = \@av_pairs;
 
     my $filter = pf::access_filter::radius->new;
@@ -449,6 +442,18 @@ sub returnRadiusAccessAccept {
     return [$status, %$radius_reply_ref];
 }
 
+sub addDPSK {
+    my ($self, $args, $radius_reply_ref, $av_pairs) = @_;
+    if ($args->{profile}->dpskEnabled()) {
+        if (defined($args->{owner}->{psk})) {
+            push @$av_pairs, "psk=$args->{owner}->{psk}";
+        } else {
+            push @$av_pairs, "psk=$args->{profile}->{_default_psk_key}";
+        }
+        push @$av_pairs, "psk-mode=ascii";
+    }
+}
+
 =item radiusDisconnect
 
 Sends a RADIUS Disconnect-Request to the NAS with the MAC as the Calling-Station-Id to disconnect.
@@ -656,7 +661,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
