@@ -78,6 +78,7 @@ use pf::util;
 # CAPABILITIES
 # access technology supported
 use pf::SwitchSupports qw(
+    RoleBasedEnforcement
     WiredMacAuth
     WiredDot1x
 );
@@ -1557,6 +1558,29 @@ sub returnAuthorizeWrite {
     return [$status, %$radius_reply_ref];
 }
 
+=item returnRoleAttribute
+
+What RADIUS Attribute (usually VSA) should the role be returned into.
+
+=cut
+
+sub returnRoleAttribute {
+    my ($self) = @_;
+
+    return 'Filter-Id';
+}
+
+=item returnRoleAttributes
+
+Overriding L<pf::Switch>'s implementation to return the decorated role attribute of the switch.
+
+=cut
+
+sub returnRoleAttributes {
+    my ($self, $role) = @_;
+    return ($self->returnRoleAttribute() => "Enterasys:version=1:policy=".$role);
+}
+
 =back
 
 =head1 AUTHOR
@@ -1565,7 +1589,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
