@@ -48,6 +48,7 @@ use pf::SwitchSupports qw(
     WirelessMacAuth
     WiredMacAuth
     WirelessDot1x
+    RoleBasedEnforcement
     VPN
 );
 
@@ -159,6 +160,18 @@ sub getAcceptForm {
     return $html_form;
 }
 
+=item returnRoleAttribute
+
+What RADIUS Attribute (usually VSA) should the role returned into.
+
+=cut
+
+sub returnRoleAttribute {
+    my ($self) = @_;
+
+    return 'Fortinet-Group-Name';
+}
+
 =item deauthenticateMacDefault
 
 Overrides base method to send Acct-Session-Id within the RADIUS disconnect request
@@ -272,7 +285,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
