@@ -59,9 +59,10 @@ sub description { 'Ruckus Wireless Controllers' }
 
 # CAPABILITIES
 # access technology supported
+
 use pf::SwitchSupports qw(
     WirelessDot1x
-    -WirelessMacAuth
+    WirelessMacAuth
     ExternalPortal
     RoleBasedEnforcement
 );
@@ -118,12 +119,18 @@ sub parseTrap {
     my $trapHashRef;
     my $logger = $self->logger;
 
-    $logger->debug("trap currently not handled.  TrapString was: $trapString");
-    $trapHashRef->{'trapType'} = 'unknown';
-
+    # Handle WIPS Trap
+    if ( $trapString =~ /\.1\.3\.6\.1\.4\.1\.25053\.2\.2\.2\.20 = STRING: \"([a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2}:[a-f0-9]{2})/ ) {
+        $trapHashRef->{'trapType'}    = 'wirelessIPS';
+        $trapHashRef->{'trapMac'} = clean_mac($1);
+    } else {
+        $logger->debug("trap currently not handled.  TrapString was: $trapString");
+        $trapHashRef->{'trapType'} = 'unknown';
+    }
     return $trapHashRef;
 }
 
+
 =item deauthenticateMacDefault
 
 De-authenticate a MAC address from wireless network (including 802.1x).
@@ -170,7 +177,6 @@ sub deauthTechniques {
     return $method,$tech{$method};
 }
 
-
 =item parseExternalPortalRequest
 
 Parse external portal request using URI and it's parameters then return an hash reference with the appropriate parameters
@@ -249,7 +255,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
