@@ -17,6 +17,8 @@ use Try::Tiny;
 use pf::util::radius qw(perform_coa perform_disconnect);
 use pf::Switch::constants;
 use pf::constants;
+use pf::constants::switch qw($DEFAULT_ACL_TEMPLATE);
+use pf::radius::constants;
 use pf::util qw(isenabled);
 use List::MoreUtils qw(uniq);
 use pf::constants::role qw($REJECT_ROLE $VOICE_ROLE);
@@ -24,6 +26,7 @@ use pf::access_filter::radius;
 use pf::accounting qw(node_accounting_dynauth_attr);
 use pf::roles::custom;
 use pf::mini_template;
+use pf::locationlog;
 use pf::SwitchSupports qw(
     WiredMacAuth
     WiredDot1x
@@ -279,7 +282,7 @@ sub disconnectAddress {
         $send_disconnect_to = $self->{'_controllerIp'};
     }
     # allowing client code to override where we connect with NAS-IP-Address
-    if ( defined($add_attributes_ref->{'NAS-IP-Address'}) && $add_attributes_ref->{'NAS-IP-Address'} ne '' ) {
+    if ( defined $add_attributes_ref && defined($add_attributes_ref->{'NAS-IP-Address'}) && $add_attributes_ref->{'NAS-IP-Address'} ne '' ) {
         $logger->info("'NAS-IP-Address' additionnal attribute is set. Using it '" . $add_attributes_ref->{'NAS-IP-Address'} . "' to perform deauth");
         $send_disconnect_to = $add_attributes_ref->{'NAS-IP-Address'};
     }
@@ -453,13 +456,136 @@ sub deauthenticateMacRadius {
     $self->radiusDisconnect($mac );
 }
 
+=head2 aclTemplate
+
+Override the default ACL template if applicable
+
+=cut
+
+sub aclTemplate {
+    my ($self) = @_;
+    return $self->{_template}{acl_template} || $DEFAULT_ACL_TEMPLATE
+}
+
+sub bouncePort {
+    my ($self, $ifindex) = @_;
+    my $logger = $self->logger;
+    if ( !$self->isProductionMode() ) {
+        $logger->info("Switch not in production mode... we won't perform port bounce");
+        return $TRUE;
+    }
+
+    my $radiusBounce = $self->{_template}{bounce};
+    if (!defined $radiusBounce) {
+        return $self->SUPER::bouncePort($ifindex);
+    }
+
+    return $self->_bouncePortCoa($ifindex, $radiusBounce);
+}
+
+sub handleReAssignVlanTrapForWiredMacAuth {
+    my ($self, $ifIndex, $mac) = @_;
+    return $self->bouncePortSNMP($ifIndex);
+}
+
+sub _bouncePortCoa {
+    my ($self, $ifIndex, $radiusBounce) = @_;
+    my $logger = $self->logger;
+    my $id = $self->{_id};
+
+    if (!defined($self->{'_radiusSecret'})) {
+        $logger->warn(
+            "Unable to perform RADIUS CoA-Request on $id: RADIUS Shared Secret not configured"
+        );
+        return;
+    }
+
+    #We need to fetch the MAC on the ifIndex in order to bounce switch port with CoA.
+    my @locationlog = locationlog_view_open_switchport_no_VoIP( $id, $ifIndex );
+    my $mac = $locationlog[0]->{'mac'};
+    if (!$mac) {
+        @locationlog = locationlog_view_open_switchport_only_VoIP( $id, $ifIndex );
+        $mac = $locationlog[0]->{'mac'};
+    }
+
+    if (!$mac) {
+        $logger->info("Can't find MAC address in the locationlog... we won't perform port bounce");
+        return $FALSE;
+    }
+
+    my $send_disconnect_to = $self->disconnectAddress({});
+    my $connection_info = {
+        nas_ip => $send_disconnect_to,
+        secret => $self->{'_radiusSecret'},
+        LocalAddr => $self->deauth_source_ip($send_disconnect_to),
+    };
+    my %args = (
+        disconnectIp => $send_disconnect_to,
+        mac => $mac,
+        ifIndex => $ifIndex,
+        switch => $self,
+    );
+
+    $self->updateArgsVariablesForSet(\%args, $radiusBounce);
+    my ($attrs, $vsa) = $self->makeRadiusAttributesWithVSA($radiusBounce, \%args);
+    # Standard Attributes
+    return perform_coa($connection_info, {@$attrs}, $vsa);
+}
+
+sub NasPortToIfIndex {
+    my ($self, $nasPort) = @_;
+    if ($self->{_template}{nasPortToIfindex}) {
+        my $ifindex = $self->{_template}{nasPortToIfindex}->process({ nasPort => $nasPort});
+        if ($ifindex) {
+            return $ifindex;
+        }
+    }
+
+    return $self->SUPER::NasPortToIfIndex($nasPort);
+}
+
+sub returnAuthorizeRead {
+    my ($self, $args) = @_;
+    return $self->returnCliAuthorize($args, 'Read');
+}
+
+sub returnAuthorizeWrite {
+    my ($self, $args) = @_;
+    return $self->returnCliAuthorize($args, 'Write');
+}
+
+sub returnCliAuthorize {
+    my ($self, $args, $accessType) = @_;
+    my $logger = $self->logger;
+    my %radius_reply;
+    my $template = $self->{_template}{"cliAuthorize${accessType}"};
+    my %tmp_args = %$args;
+    if ($template) {
+        $self->updateArgsVariablesForSet(\%tmp_args, $template);
+        my $attrs = $self->makeRadiusAttributes($template, \%tmp_args);
+        %radius_reply = @$attrs;
+    } else {
+        $radius_reply{'Reply-Message'} = "Switch $accessType access granted by PacketFence";
+    }
+
+    $logger->info("User $args->{'user_name'} logged in $args->{'switch'}{'_id'} with $accessType access");
+    my $filter = pf::access_filter::radius->new;
+    my $rule = $filter->test("returnAuthorize${accessType}", \%tmp_args);
+    if ($rule) {
+        my ($radius_reply_ref, $status) = $filter->handleAnswerInRule($rule, \%tmp_args, \%radius_reply);
+        return [$status, %$radius_reply_ref];
+    }
+
+    return [$RADIUS::RLM_MODULE_OK, %radius_reply];
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
