@@ -351,10 +351,10 @@ sub populateAccessPointMACIP {
         my $json_data_ap = decode_json($response->decoded_content());
         my %exists;
         foreach my $AP (@{$json_data_ap->{'data'}}) {
-            $cache->compute("Ubiquiti-" . $AP->{'mac'} , sub { return $AP->{'ip'} } );
+            $cache->set("Ubiquiti-" . $AP->{'mac'} , $AP->{'ip'} );
             $exists{$AP->{'mac'}} = $TRUE;
             foreach my $vap (@{$AP->{'vap_table'}}) {
-                $cache->compute("Ubiquiti-" . $vap->{'bssid'},  sub { return $AP->{'ip'} } ) unless $exists{$vap->{'bssid'}};
+                $cache->set("Ubiquiti-" . $vap->{'bssid'},  $AP->{'ip'} ) unless $exists{$vap->{'bssid'}};
                 $exists{$vap->{'bssid'}} = $TRUE;
             }
         }
@@ -462,7 +462,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
