@@ -404,7 +404,10 @@ sub setup_api_v1_locationlogs_routes {
     $collection_route->register_sub_action({ action => 'search', method => 'POST' });
     $collection_route->register_sub_action({ action => 'ssids', method => 'GET' });
 
-    return ($collection_route, undef);
+    my $resource_route = $root->under("/locationlog/#locationlog_id")->to(controller => $controller, action => "resource")->name("${name}.resource");
+    $resource_route->register_sub_action({path => '', action => 'get', method => 'GET'});
+
+    return ($collection_route, $resource_route);
 }
 
 =head2 setup_api_v1_dhcp_option82s_routes
@@ -648,6 +651,11 @@ sub setup_api_v1_nodes_routes {
         action => 'network_graph',
     });
 
+    $collection_route->register_sub_action({
+        method => 'DELETE',
+        action => 'bulk_delete',
+    });
+
     return ( $collection_route, $resource_route );
 }
 
@@ -1061,6 +1069,7 @@ sub setup_api_v1_config_maintenance_tasks_routes {
         "api.v1.Config.MaintenanceTasks"
       );
 
+    $resource_route->register_sub_action({ action => 'run', method => 'POST' });
     return ($collection_route, $resource_route);
 }
 
@@ -1228,6 +1237,7 @@ sub setup_api_v1_config_roles_routes {
         "api.v1.Config.Roles"
     );
 
+    $resource_route->register_sub_action({action => 'reassign', method => 'PATCH'});
     return ($collection_route, $resource_route);
 }
 
@@ -1426,9 +1436,9 @@ sub setup_api_v1_config_connection_profiles_files_routes {
     $files_route->any(['GET'])->to("$controller#files" => {})->name("${name}.dir");
     my $file_route = $files_route->any("/*file_name")->name("${name}.file");
     $file_route->any(['GET'])->to("$controller#get_file" => {})->name("${name}.file.get");
-    $file_route->any(['PATCH'])->to("$controller#replace_file" => {})->name("${name}.file.replace");
-    $file_route->any(['PUT'])->to("$controller#new_file" => {})->name("${name}.file.new");
-    $file_route->any(['DELETE'])->to("$controller#delete_file" => {})->name("${name}.file.delete");
+    $file_route->any(['PATCH'])->to("$controller#replace_file" => {auditable => 1})->name("${name}.file.replace");
+    $file_route->any(['PUT'])->to("$controller#new_file" => {auditable => 1})->name("${name}.file.new");
+    $file_route->any(['DELETE'])->to("$controller#delete_file" => {auditable => 1})->name("${name}.file.delete");
     my $preview_route = $root->get("/preview/*file_name")->to("$controller#preview_file")->name("api.v1.Config.ConnectionProfiles.resource.preview");
 
     return ;
@@ -1924,6 +1934,7 @@ sub setup_api_v1_authentication_routes {
     my ($self, $root) = @_;
     my $route = $root->any("/authentication")->name("api.v1.Authentication");
     $route->any(['POST'] => "/admin_authentication")->to("Authentication#adminAuthentication")->name("api.v1.Authentication.admin_authentication");
+    $route->any(['POST'] => "/role_authentication")->to("Authentication#roleAuthentication")->name("api.v1.Authentication.role_authentication");
     return ;
 }
 
@@ -1940,6 +1951,20 @@ sub setup_api_v1_queues_routes {
     return ;
 }
 
+=head2 setup_api_v1_pfqueues_routes
+
+setup_api_v1_queues_routes
+
+=cut
+
+sub setup_api_v1_pfqueues_routes {
+    my ($self, $root) = @_;
+    my $route = $root->any("/pfqueue/task/:job_id")->to(controller => 'Pfqueue')->name("api.v1.Pfqueues");
+    $route->register_sub_action({ path => "/status/poll", action => 'poll', method => "GET" });
+    $route->register_sub_action({ action => "status", method => "GET" });
+    return ;
+}
+
 =head2 setup_api_v1_fingerbank_routes
 
 setup_api_v1_fingerbank_routes
@@ -2177,18 +2202,18 @@ setup_api_v1_configurator_routes
 
 sub setup_api_v1_configurator_routes {
     my ($self, $root) = @_;
-    my $config = $root->under("/config")->name("api.v1.Configurator.Config");
-    $self->setup_api_v1_config_bases_routes($config, 1);
-    $self->setup_api_v1_config_fingerbank_settings_routes($config);
-    $self->setup_api_v1_config_interfaces_routes($config);
-    $self->setup_api_v1_config_system_routes($config);
-
+    $self->setup_api_v1_pfqueues_routes($root);
     $self->setup_api_v1_translations_routes($root);
     $self->setup_api_v1_fingerbank_routes($root);
     $self->setup_api_v1_services_routes($root);
     $self->setup_api_v1_system_services_routes($root);
     $self->setup_api_v1_users_routes($root);
-
+    $self->setup_api_v1_system_summary_route($root);
+    my $config = $root->under("/config")->name("api.v1.Configurator.Config");
+    $self->setup_api_v1_config_bases_routes($config, 1);
+    $self->setup_api_v1_config_fingerbank_settings_routes($config);
+    $self->setup_api_v1_config_interfaces_routes($config);
+    $self->setup_api_v1_config_system_routes($config);
     return;
 }
 
@@ -2203,6 +2228,7 @@ sub setup_api_v1_emails_route {
     my $resource_route = $root->any("email")->to(controller => "Emails" )->name("api.v1.Emails");
     $resource_route->register_sub_action({ method => 'POST', action => 'preview', path => 'preview'});
     $resource_route->register_sub_action({ method => 'POST', action => 'send_email', path => 'send'});
+    $resource_route->register_sub_action({ method => 'POST', action => 'pfmailer', path => 'pfmailer'});
     return ;
 }
 
@@ -2212,7 +2238,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
