@@ -106,7 +106,7 @@ sub normalize_sort_specs {
             my $dir       = 'asc';
             my $s         = $sort_spec;
             if ($s =~ s/  *(DESC|ASC)$//i) {
-                $dir = lc($dir);
+                $dir = lc($1);
             }
 
             { field => $s, dir => $dir }
@@ -359,8 +359,9 @@ sub cleanup_item {
 
 sub is_sortable {
     my ($self, $cs, $id, $item) = @_;
+    my $section = $cs->_formatSectionName($id);
     my $default_section = $cs->default_section;
-    return (defined($cs->default_section) && $id eq $default_section) ? $self->json_true : $self->json_false;
+    return ((defined($cs->default_section) && $id eq $default_section) || $cs->is_section_in_import($section)) ? $self->json_true : $self->json_false;
 }
 
 sub create {
@@ -458,11 +459,20 @@ sub make_location_url {
     return "$url/$id";
 }
 
+sub can_delete {
+    return (200, '');
+}
+
 sub remove {
     my ($self) = @_;
+    my ($status, $msg, $errors) = $self->can_delete();
+    if (is_error($status)) {
+        return $self->render_error($status, $msg, $errors);
+    }
+
     my $id = $self->id;
     my $cs = $self->config_store;
-    my ($msg, $deleted) = $cs->remove($id, 'id');
+    ($msg, my $deleted) = $cs->remove($id, 'id');
     if (!$deleted) {
         return $self->render_error(422, "Unable to delete $id - $msg");
     }
@@ -816,7 +826,8 @@ Create the resource options
 
 sub resource_options {
     my ($self) = @_;
-    my ($status, $form) = $self->form($self->item);
+    my $item = $self->item;
+    my ($status, $form) = $self->form($item);
     if (is_error($status)) {
         return $self->render_error($status, $form);
     }
@@ -829,6 +840,7 @@ sub resource_options {
     my $parent = {
         placeholder => $self->_cleanup_placeholder($inheritedValues)
     };
+    $form->process($self->form_process_parameters_for_cleanup($item));
     for my $field ($form->fields) {
         next if $field->inactive;
         my $name = $field->name;
@@ -906,6 +918,10 @@ sub field_placeholder {
     my ($self, $field, $defaults) = @_;
     my $name = $field->name;
     my $value;
+    if ($field->type_attr eq 'password') {
+        return '**************';
+    }
+
     if ($defaults) {
         $value = $defaults->{$name};
     }
@@ -1379,7 +1395,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
