@@ -23,6 +23,8 @@ has 'form_class' => 'pfappserver::Form::Config::Pf';
 has 'primary_key' => 'base_id';
 
 use pf::ConfigStore::Pf;
+use pf::pfqueue::status_updater::redis;
+use pf::util::pfqueue qw(consumer_redis_client);
 use pf::config;
 use pf::util;
 use pfappserver::Form::Config::Pf;
@@ -30,7 +32,13 @@ use pf::I18N::pfappserver;
 use pf::error qw(is_error);
 use pf::ConfigStore::Pf;
 use pf::ConfigStore::Network;
-use pf::config qw(%Config);
+use pf::config qw(
+    %Config
+    %Doc_Config
+);
+use Data::UUID;
+
+my $GENERATOR = Data::UUID->new;
 
 sub _update_domain_networks_conf {
     my ($self) = @_;
@@ -45,6 +53,25 @@ sub _update_domain_networks_conf {
     }
 }
 
+sub validate_item {
+    my ($self, $item) = @_;
+    my $id = $item->{id};
+    while ( my ($key, $val) = each %$item) {
+        my $doc_section = "$id.$key";
+        unless (exists $Doc_Config{$doc_section} && defined $val  ) {
+            next;
+        }
+        my $doc = $Doc_Config{$doc_section};
+        if ($doc->{type} eq 'array') {
+            if (!ref $val) {
+                $item->{$key} = [$val];
+            }
+        }
+    }
+
+    return $self->SUPER::validate_item($item);
+}
+
 sub replace {
     my ($self) = @_;
     $self->_update_domain_networks_conf();
@@ -104,14 +131,36 @@ sub database_secure_installation {
         return;
     }
 
+    if ($json->{async}) {
+        my $task_id = $self->task_id;
+        my $subprocess = Mojo::IOLoop->subprocess;
+        $subprocess->run(
+            sub {
+                my ($subprocess) = @_;
+                my $updater = pf::pfqueue::status_updater::redis->new( connection => consumer_redis_client(), task_id => $task_id );
+                $updater->start;
+                my ($status, $data) = $self->do_database_secure_installation($json);
+                $updater->completed($data);
+            },
+            sub {},
+        );
+
+        return $self->render( json => {status => 202, task_id => $task_id }, status => 202);
+    }
+
+    my ($status, $data) = $self->do_database_secure_installation($json);
+    return $self->render(json => $data, status => $status);
+}
+
+sub do_database_secure_installation {
+    my ($self, $json) = @_;
     my ($status, $status_msg) = $self->database_model->connect("mysql", $json->{username});
     if(is_error($status)) {
-        $self->render(json => {message => pf::I18N::pfappserver->localize($status_msg)}, status => $status);
-        return;
+        return $status, {message => pf::I18N::pfappserver->localize($status_msg), status => $status};
     }
 
     ($status, $status_msg) = $self->database_model->secureInstallation($json->{username}, $json->{password});
-    $self->render(json => {message => pf::I18N::pfappserver->localize($status_msg)}, status => $status);
+    return $status, {message => pf::I18N::pfappserver->localize($status_msg), status => $status};
 }
 
 sub database_create {
@@ -122,32 +171,48 @@ sub database_create {
         return;
     }
 
+    if ($json->{async}) {
+        my $task_id = $self->task_id;
+        my $subprocess = Mojo::IOLoop->subprocess;
+        $subprocess->run(
+            sub {
+                my ($subprocess) = @_;
+                my $updater = pf::pfqueue::status_updater::redis->new( connection => consumer_redis_client(), task_id => $task_id );
+                $updater->start;
+                my ($status, $data) = $self->do_database_create($json);
+                $updater->completed($data);
+            },
+            sub {},
+        );
+
+        return $self->render( json => {status => 202, task_id => $task_id }, status => 202);
+    }
+
+    my ($status, $data) = $self->do_database_create($json);
+    return $self->render(json => $data, status => $status);
+}
+
+sub do_database_create {
+    my ($self, $json) = @_;
     my ($status, $status_msg) = $self->database_model->connect("mysql", $json->{username}, $json->{password});
     if(is_error($status)) {
-        $self->render(json => {message => pf::I18N::pfappserver->localize($status_msg)}, status => $status);
-        return;
+        return $status, {message => pf::I18N::pfappserver->localize($status_msg), status => $status};
     }
 
     ($status, $status_msg) = $self->database_model->create($json->{database}, $json->{username}, $json->{password});
     if(is_error($status)) {
-        $self->render(json => {message => pf::I18N::pfappserver->localize($status_msg)}, status => $status);
-        return;
+        return $status, {message => pf::I18N::pfappserver->localize($status_msg), status => $status};
     }
 
     ($status, $status_msg) = $self->database_model->schema($json->{database}, $json->{username}, $json->{password});
     if(is_error($status)) {
-        $self->render(json => {message => pf::I18N::pfappserver->localize($status_msg)}, status => $status);
-        return;
+        return $status, {message => pf::I18N::pfappserver->localize($status_msg), status => $status};
     }
 
-    require pfappserver::Model::Config::Pfconfig;
-    pfappserver::Model::Config::Pfconfig->new->update_db_name($json->{database});
-
     my $pf_cs = pf::ConfigStore::Pf->new;
     $pf_cs->update("database", {db => $json->{database}});
     $pf_cs->commit();
-    
-    $self->render(json => {message => "Created database and loaded the schema"}, status => 200);
+    return 200, {message => "Created database and loaded the schema"};
 }
 
 sub database_assign {
@@ -226,7 +291,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
