@@ -59,7 +59,7 @@ standardPlaceholder
 sub standardPlaceholder {
     my ($self) = @_;
     my $params = $self->req->query_params->to_hash;
-    my $group = $params->{group};
+    my $group = $params->{group} || $params->{type};
     if (!defined $group || $group eq 'default' ) {
         return $self->SUPER::standardPlaceholder();
     }
@@ -103,7 +103,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
