@@ -37,6 +37,8 @@ use pf::SwitchFactory;
 use pf::util qw(valid_ip valid_mac clean_mac);
 use pf::Connection::ProfileFactory;
 use pf::log;
+use pf::enforcement;
+use pf::person;
 
 our %STATUS_TO_MSG = (
     %pf::UnifiedApi::Controller::STATUS_TO_MSG,
@@ -950,6 +952,7 @@ sub import_item {
         return { item => $item, errors => \@errors, message => 'Cannot save node', status => 422 };
     }
 
+    $item->{mac} = clean_mac($item->{mac});
     my $logger = get_logger();
     my $mac = $item->{mac};
     my $pid = $item->{pid} || $default_pid;
@@ -1033,17 +1036,34 @@ sub validate {
     }
 
     if (@errors) {
-            return 422, {
-                    message => 'Invalid request',
-                    errors => \@errors,
-            };
+        return 422, {
+            message => 'Invalid request',
+            errors => \@errors,
+        };
     }
+
     if ($mac) {
         $json->{mac} = clean_mac($mac);
     }
+
     return 200, undef;
 }
 
+sub do_get {
+    my ($self, $data) = @_;
+    my ($status, $item) = $self->dal->find($data);
+    if (is_error($status)) {
+        $item = undef;
+    } else {
+        $item->_load_locationlog;
+        $item = $item->to_hash();
+        my $end_time = $item->{last_end_time};
+        $item->{not_deletable} = defined $end_time && $end_time eq '0000-00-00 00:00:00' ? $self->json_true : $self->json_false;
+    }
+
+    return ($status, $item);
+}
+
 sub status_to_error_msg {
     my ($self, $status) = @_;
     return exists $STATUS_TO_MSG{$status} ? $STATUS_TO_MSG{$status} : "Server error";
@@ -1059,6 +1079,63 @@ sub can_remove {
     return (422, $msg);
 }
 
+sub bulk_delete {
+    my ($self) = @_;
+    my ($status, $data) = $self->parse_json;
+    if (is_error($status)) {
+        return $self->render(json => $data, status => $status);
+    }
+
+    my $items = $data->{items} // [];
+    ($status, my $iter) = $self->dal->search(
+        -columns => [qw(mac)],
+        -where => {
+            mac => { -in => $items},
+        },
+        -with_class => undef,
+    );
+
+    if (is_error($status)) {
+        return $self->render_error($status, "Error deleting nodes");
+    }
+
+    my ($indexes, $results) = bulk_init_results($items);
+    my $nodes = $iter->all;
+    for my $node (@$nodes) {
+        my $mac = $node->{mac};
+        my $index = $indexes->{$mac};
+        my ($status, $msg) = $self->_do_remove($node);
+        $results->[$index]{status} = $status;
+        $results->[$index]{message} = is_error($status) ? ($msg // "Unable to remove resource") : "Deleted $mac successfully";
+    }
+
+    return $self->render(status => 200, json => { items => $results });
+}
+
+sub do_remove {
+    my ($self) = @_;
+    return $self->_do_remove($self->build_item_lookup);
+}
+
+=head2 _do_remove
+
+_do_remove
+
+=cut
+
+sub _do_remove {
+    my ($self, $lookup) = @_;
+    my $mac = $lookup->{mac};
+    my ($result, $msg) = pf::node::_can_delete($mac);
+    if (!$result) {
+        pf::node::node_deregister($mac);
+        pf::enforcement::reevaluate_access($mac, "admin_modify", sync => 1);
+        pf::locationlog::locationlog_update_end_mac($mac);
+    }
+
+    return $self->dal->remove_by_id($lookup);
+}
+
 =head2 create_data_update
 
 create_data_update
@@ -1072,6 +1149,33 @@ sub create_data_update {
     }
 
     $data->{category_id} = 1;
+    return;
+}
+
+sub ensure_person_exists {
+    my ($self, $data) = @_;
+    my $pid = $data->{pid};
+    if(defined $pid && !person_exist($pid)) {
+        person_add($pid);
+    }
+}
+
+sub make_create_data {
+    my ($self) = @_;
+    my ($status, $data) = $self->SUPER::make_create_data();
+    $self->ensure_person_exists($data);
+    return ($status, $data);
+}
+
+sub update_data {
+    my ($self) = @_;
+    my $data = $self->SUPER::update_data();
+    if (defined $data->{unregdate} && $data->{unregdate} eq '') {
+        $data->{unregdate} = '0000-00-00 00:00:00';
+    }
+
+    $self->ensure_person_exists($data);
+    return $data;
 }
 
 =head1 AUTHOR
@@ -1080,7 +1184,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
