@@ -24,7 +24,10 @@ use pf::constants;
 use pf::person qw(person_security_events person_unassign_nodes person_delete person_modify);
 use pf::node;
 use pf::constants qw($default_pid);
-use pf::error qw(is_error);
+use pf::error qw(is_error is_success);
+use pf::UnifiedApi::Search::Builder::Users;
+
+has 'search_builder_class' => 'pf::UnifiedApi::Search::Builder::Users';
 
 has dal => 'pf::dal::person';
 has url_param_name => 'user_id';
@@ -195,6 +198,17 @@ sub bulk_deregister {
     return $self->render(json => { items => $results });
 }
 
+sub create_obj {
+    my ($self, $data) = @_;
+    my $obj = $self->dal->new($data);
+    my $status = $data->{pid_overwrite} ? $obj->create_or_update() : $obj->insert();
+    if (is_error($status)) {
+        return ($status, {message => $self->status_to_error_msg($status)});
+    }
+
+    return ($status, $obj);
+}
+
 =head2 bulk_close_security_events
 
 bulk_close_security_events
@@ -502,9 +516,16 @@ sub bulk_delete {
     my $items = $data->{items} // [];
     my ($indexes, $results) = bulk_init_results($items);
     for my $pid ( @$items ) {
-         person_unassign_nodes($pid);
-         person_delete($pid);
-         $results->[$indexes->{$pid}]->{status} = 200;
+        my ($status, $msg) = _can_remove($pid);
+        if(is_success($status)) {
+            person_unassign_nodes($pid);
+            person_delete($pid);
+            $results->[$indexes->{$pid}]->{status} = 200;
+        }
+        else {
+            $results->[$indexes->{$pid}]->{status} = $status;
+            $results->[$indexes->{$pid}]->{msg} = $msg;
+        }
     }
 
     return $self->render(json => { items => $results });
@@ -584,6 +605,7 @@ sub import_item {
     my @actions = (
         { type => 'valid_from', value => $item->{valid_from} },
         { type => 'expiration', value => $item->{expiration} },
+        @{$item->{actions}}
     );
     $result = pf::password::generate($pid, \@actions, $item->{password});
 
@@ -621,13 +643,28 @@ sub import_item_check_for_errors {
     return @errors;
 }
 
+sub can_remove {
+    my ($self) = @_;
+    return _can_remove($self->id);
+}
+
+sub _can_remove {
+    my ($id) = @_;
+    if(exists $pf::constants::BUILTIN_USERS{$id}) {
+        return (422, "Cannot delete a built-in user");
+    }
+    else {
+        return (200, '');
+    }
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
