@@ -109,7 +109,15 @@ sub addAnswer {
     my $value = $a->{tmpl}->pre_process($args, \%FUNCS);
     $self->updateAnswerNameValue($name, $value, $radius_reply);
     my @values = split(';', $value);
-    $radius_reply->{$name} = (@values > 1) ? \@values : $values[0];
+    if (exists($radius_reply->{$name})) {
+        if (reftype($radius_reply->{$name}) eq 'ARRAY') {
+            push @{$radius_reply->{$name}}, @values;
+        } else {
+            $radius_reply->{$name} = [$radius_reply->{$name}, @values];
+        }
+    } else {
+        $radius_reply->{$name} = (@values > 1) ? \@values : $values[0];
+    }
 }
 
 sub updateAnswerNameValue {
@@ -244,7 +252,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
