@@ -18,7 +18,7 @@ use warnings;
 use pf::log;
 use Readonly;
 use pf::accounting_events_history;
-use pf::config::pfmon qw(%ConfigPfmon);
+use pf::config::pfcron qw(%ConfigCron);
 use pf::config::tenant;
 use pf::util qw(make_node_id);
 use pf::error qw(is_success);
@@ -91,6 +91,13 @@ my %direction_field = (
     TOT => 'total_bytes',
 );
 
+my %mac_grouping_dates = (
+    daily   => 'CURDATE()',
+    weekly  => 'DATE_SUB(CURDATE(), INTERVAL WEEKDAY(CURDATE()) DAY)',
+    monthly => 'DATE_ADD(CURDATE(),INTERVAL -DAY(CURDATE())+1 DAY)',
+    yearly  => 'DATE_ADD(CURDATE(),INTERVAL -DAYOFYEAR(CURDATE())+1 DAY)',
+);
+
 =head1 SUBROUTINES
 
 =over
@@ -173,7 +180,7 @@ sub acct_maintenance {
     }
 
     # Commit the data and give 3 times the acct_maintenance interval as a TTL which should be plenty for the next loop to populate this again
-    $events_history->commit($events_history_hash, $ConfigPfmon{acct_maintenance}{interval}*3) if $history_added;
+    $events_history->commit($events_history_hash, $ConfigCron{acct_maintenance}{interval}*3) if $history_added;
     return $TRUE;
 }
 
@@ -193,6 +200,7 @@ SQL
     }
     my $field = $direction_field{$direction};
     my $date = $grouping_dates{$interval};
+    my $date2 = $mac_grouping_dates{$interval};
     my $sql2 = <<"SQL";
 SELECT
     tenant_id,
@@ -205,15 +213,15 @@ SELECT
             mac,
             SUM($field) AS $field 
         FROM bandwidth_accounting
-        WHERE node_id BETWEEN ? AND ? GROUP BY node_id, $date 
-        UNION ALL SELECT 
+        WHERE DATE(time_bucket) >= $date2 and node_id BETWEEN ? AND ? GROUP BY node_id, $date
+        UNION ALL SELECT
             $date AS time_bucket,
             node_id,
             tenant_id,
             mac,
-            SUM($field) AS $field 
+            SUM($field) AS $field
         FROM bandwidth_accounting_history
-        WHERE node_id BETWEEN ? AND ? GROUP BY node_id, $date 
+        WHERE DATE(time_bucket) >= $date2 and node_id BETWEEN ? AND ? GROUP BY node_id, $date
         ) AS X GROUP BY node_id, time_bucket HAVING SUM($field) >= ?;
 SQL
 
@@ -614,13 +622,6 @@ SQL
     return;
 }
 
-my %mac_grouping_dates = (
-    daily   => 'CURDATE()',
-    weekly  => 'DATE_SUB(CURDATE(), INTERVAL WEEKDAY(CURDATE()) DAY)',
-    monthly => 'DATE_ADD(CURDATE(),INTERVAL -DAY(CURDATE())+1 DAY)',
-    yearly  => 'DATE_ADD(CURDATE(),INTERVAL -DAYOFYEAR(CURDATE())+1 DAY)',
-);
-
 sub node_accounting_bw {
     my ($mac, $interval) = @_;
     my $tenant_id = pf::config::tenant::get_tenant();
@@ -649,7 +650,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
