@@ -51,6 +51,8 @@ use pf::services();
 use pf::firewallsso();
 use pf::pfqueue::stats();
 use pf::pfqueue::producer::redis();
+use pf::util qw(mysql_date);
+use pf::bandwidth_accounting qw();
 
 use List::MoreUtils qw(uniq);
 use List::Util qw(pairmap any);
@@ -75,6 +77,8 @@ use Hash::Merge qw (merge);
 use pf::constants::api;
 use pf::constants::realm;
 use DateTime::Format::MySQL;
+use pf::constants::domain qw($NTLM_REDIS_CACHE_HOST $NTLM_REDIS_CACHE_PORT);
+use pf::Redis;
 
 my $logger = pf::log::get_logger();
 
@@ -982,7 +986,7 @@ sub trigger_scan :Public :Fork :AllowedAsAction($ip, mac, $mac, net_type, TYPE)
     if ( $postdata{'net_type'} eq 'registration' ) { # On Registration Scans
 
         if( any { pf::util::isenabled($_->{'_registration'}) } @scanners ) {
-            $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::SCAN_SECURITY_EVENT_ID );
+            $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::SCAN_SECURITY_EVENT_ID, (ticket_ref => "Scan in progress, started at: ".mysql_date()));
         }
 
         return if (!defined($added) || $added == 0 || $added == -1);
@@ -1007,7 +1011,7 @@ sub trigger_scan :Public :Fork :AllowedAsAction($ip, mac, $mac, net_type, TYPE)
     } elsif ( pf::util::is_prod_interface($postdata{'net_type'}) ) { # Post Registration Scans
 
         if( any { pf::util::isenabled($_->{'_post_registration'}) } @scanners ) {
-            $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::POST_SCAN_SECURITY_EVENT_ID );
+            $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::POST_SCAN_SECURITY_EVENT_ID, (ticket_ref => "Scan in progress, started at: ".mysql_date()));
         }
 
         return if (!defined($added) || $added == 0 || $added == -1);
@@ -1032,7 +1036,7 @@ sub trigger_scan :Public :Fork :AllowedAsAction($ip, mac, $mac, net_type, TYPE)
     } else { # Pre Registration Scans
 
         if (any { pf::util::isenabled($_->{'_pre_registration'}) } @scanners ) {
-                $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::PRE_SCAN_SECURITY_EVENT_ID );
+                $added = pf::security_event::security_event_add( $postdata{'mac'}, $pf::constants::scan::PRE_SCAN_SECURITY_EVENT_ID, (ticket_ref => "Scan in progress, started at: ".mysql_date()));
             }
 
         return if (!defined($added) || $added == 0 || $added == -1);
@@ -1524,6 +1528,7 @@ sub firewallsso_accounting : Public {
         my $firewallsso_method = "Stop";
         my $timeout = '3600'; #Default to 1 hour
         my $client = pf::client::getClient();
+        my $username = $RAD_REQUEST{'User-Name'} // undef;
 
         if ($node->{status} eq $pf::node::STATUS_REGISTERED) {
             $firewallsso_method = "Update";
@@ -1542,7 +1547,7 @@ sub firewallsso_accounting : Public {
         $firewallsso_method = ($RAD_REQUEST{'Acct-Status-Type'} == $ACCOUNTING::STOP) ? "Stop" : "Update";
 
         $logger->warn("Firewall SSO Notify");
-        $client->notify( 'firewallsso', (method => $firewallsso_method, mac => $mac, ip => $ip, timeout => $timeout) );
+        $client->notify( 'firewallsso', (method => $firewallsso_method, mac => $mac, ip => $ip, timeout => $timeout, username => $username) );
     }
 }
 
@@ -1742,6 +1747,11 @@ sub update_role_configuration : Public :AllowedAsAction(role, $role) {
 
     my $role = delete $postdata{'role'};
 
+    if(!$role) {
+        pf::log::get_logger->error("Undefined role for update_role_configuration. Skipping reconfiguration.");
+        return $pf::config::FALSE;
+    }
+
     my $tc_cs = pf::ConfigStore::TrafficShaping->new;
     if ($postdata{'upload'} == 0 && $postdata{'download'} == 0) {
         $tc_cs->remove($role);
@@ -1831,13 +1841,70 @@ sub queue_submit_delayed :Public {
     return $id;
 }
 
+=head2 insert_user_in_redis_cache
+
+insert_user_in_redis_cache
+
+=cut
+
+sub insert_user_in_redis_cache :Public {
+    my ($class ,$domain, $user, $nthash) = @_;
+
+    my $logger = pf::log::get_logger();
+    my $config = $pf::config::ConfigDomain{$domain};
+
+    my $expire = (pf::cluster::isSlaveMode()) ? 86400 : $config->{ntlm_cache_expiry};
+    # pf::Redis has a cache for the connection
+    my $redis = pf::Redis->new(server => "$NTLM_REDIS_CACHE_HOST:$NTLM_REDIS_CACHE_PORT", reconnect => 5);
+
+    my $key = "NTHASH:$domain:$user";
+    $logger->info("Inserting '$key' => '$nthash'");
+    $redis->set($key, $nthash, 'EX', $expire);
+}
+
+=head2 update_user_in_redis_cache
+
+Update a user/NT hash combination inside redis for a given domain
+
+=cut
+
+sub update_user_in_redis_cache {
+    my ($class, $domain, $username) = @_;
+    my $logger = pf::log::get_logger();
+    my $config = $pf::config::ConfigDomain{$domain};
+
+    my $expire = (pf::cluster::isSlaveMode()) ? 86400 : $config->{ntlm_cache_expiry};
+    # pf::Redis has a cache for the connection
+    my $redis = pf::Redis->new(server => "$NTLM_REDIS_CACHE_HOST:$NTLM_REDIS_CACHE_PORT", reconnect => 5);
+
+
+    my $key = "NTHASH:$domain:$username";
+    my $nthash = $redis->get($key);
+    if (defined($nthash)) {
+        $redis->set($key, $nthash, 'EX', $expire);
+        $logger->info("Updating '$key' => '$nthash'");
+    }
+}
+
+=head2 bandwidth_trigger
+
+bandwidth_trigger
+
+=cut
+
+sub bandwidth_trigger :Public {
+    my ($class, $args) = @_;
+    pf::bandwidth_accounting::trigger_bandwidth();
+    return $pf::config::TRUE;
+}
+
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
