@@ -18,13 +18,12 @@ Services managed by PacketFence:
   fingerbank-collector   | Fingerprinting data collection daemon
   galera-autofix         | Automated recovery of Galera clusters
   haproxy-admin          | haproxy admin daemon
-  haproxy-portal         | haproxy portal daemon
   haproxy-db             | haproxy database daemon
+  haproxy-portal         | haproxy portal daemon
   httpd.aaa              | Apache AAA webservice
-  httpd.admin            | Apache Web admin
+  httpd.admin_dispatcher | Admin GUI dispatcher
   httpd.collector        | Apache Collector daemon
   httpd.dispatcher       | Captive portal dispatcher
-  httpd.admin_dispatcher | Admin GUI dispatcher
   httpd.portal           | Apache Captive Portal
   httpd.proxy            | Apache Proxy Interception
   httpd.webservices      | Apache Webservices
@@ -34,13 +33,13 @@ Services managed by PacketFence:
   pfacct                 | Netflow and Radius Accounting service
   pf                     | all services that should be running based on your config
   pfcertmanager          | Certificate Manager Service
+  pfcron                 | PF Cron daemon
   pfdetect               | PF snort alert parser
   pfdhcp                 | dhcpd daemon
   pfdhcplistener         | PF DHCP monitoring daemon
   pfdns                  | DNS daemon
-  pfipset                | IPSET daemon
   pffilter               | PF conditions filtering daemon
-  pfmon                  | PF monitoring daemon
+  pfipset                | IPSET daemon
   pfperl-api             | Perl daemon providing API
   pfpki                  | PKI daemon
   pfqueue                | PF queueing service
@@ -148,8 +147,7 @@ sub _run {
 
 sub postPfStartService {
     my ($managers) = @_;
-    my $count = true {$_->status ne '0'} @$managers;
-    pf::config::configreload(1) unless $count;
+    pf::config::configreload(1);
 }
 
 
@@ -423,7 +421,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
