@@ -37,7 +37,7 @@ Check if the is true
 =cut
 
 sub match {
-    my ($self, $arg) = @_;
+    my ($self, $arg, $args) = @_;
     return $FALSE if(!defined($arg));
     my $value = eval {
         $self->ast->value($arg)
@@ -55,7 +55,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
