@@ -36,9 +36,10 @@ Match if the argument if not equal to the value
 =cut
 
 sub match {
-    my ($self,$arg) = @_;
+    my ($self,$arg,$args) = @_;
     return $FALSE if(!defined($arg));
-    return $arg ne $self->value;
+    my $value = $self->evalParam($self->value, $args);
+    return $arg ne $value;
 }
 
 =head1 AUTHOR
@@ -47,7 +48,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
