@@ -27,8 +27,8 @@ Match if argument does not match the regex defined
 =cut
 
 sub match {
-    my ($self,$arg) = @_;
-    my $match = $self->value;
+    my ($self,$arg,$args) = @_;
+    my $match = $self->evalParam($self->value, $args);
     return 0 if(!defined($arg));
     return $arg !~ $match;
 }
@@ -39,7 +39,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
