@@ -422,6 +422,17 @@ our %OP_BINARY = (
     "<=" => 'lower_equals',
 );
 
+our %OP_BINARY_INVERSE = (
+    "==" => 'not_equals',
+    "!=" => 'equals',
+    "=~" => 'not_regex',
+    "!~" => 'regex',
+    ">"  => 'lower_equals',
+    ">=" => 'lower',
+    "<"  => 'greater_equals',
+    "<=" => 'greater',
+);
+
 
 our %ROP_BINARY = map { $OP_BINARY{$_} => $_ } keys %OP_BINARY;
 
@@ -457,7 +468,11 @@ sub _ast_to_object {
                 return { op => "not_$OPS_WITH_VALUES{$sub_op}", values => [map { _ast_to_object($_) } @{$sub}[1..(@{$sub} - 1)] ] };
             }
 
-            return { op => "not", values => [ _ast_to_object($sub) ]};
+            if (exists $OP_BINARY_INVERSE{$sub_op}) {
+                return { op => $OP_BINARY_INVERSE{$sub_op}, field => $sub->[1], value => $sub->[2] };
+            }
+
+            return { op => "not_and", values => [ _ast_to_object($sub) ]};
         }
 
         return undef;
@@ -511,7 +526,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
