@@ -54,6 +54,7 @@ use pf::constants::config qw(
   $NET_TYPE_INLINE
   $NET_TYPE_INLINE_L2
   $NET_TYPE_INLINE_L3
+  $NET_TYPE_OTHER
 
   $TIME_MODIFIER_RE
   $ACCT_TIME_MODIFIER_RE
@@ -174,8 +175,12 @@ our (
     %ConfigAuthenticationLdap,
 # Radius sources
     %ConfigAuthenticationRadius,
+# Eduroam source
+    %ConfigAuthenticationEduroam,
 # TLS configuration
     %ConfigEAP,
+# EDIR sources
+    %ConfigAuthenticationEdir,
 );
 
 BEGIN {
@@ -198,7 +203,7 @@ BEGIN {
         $WIPS_SECURITY_EVENT_ID $thread $fqdn $reverse_fqdn
         $IF_INTERNAL $IF_ENFORCEMENT_VLAN $IF_ENFORCEMENT_INLINE $IF_ENFORCEMENT_DNS
         $WIRELESS_802_1X $WIRELESS_MAC_AUTH $WIRED_802_1X $WIRED_MAC_AUTH $WIRED_SNMP_TRAPS $UNKNOWN $INLINE $WEBAUTH $WEBAUTH_WIRED $WEBAUTH_WIRELESS $VIRTUAL_VPN $VIRTUAL_CLI
-        $NET_TYPE_INLINE $NET_TYPE_INLINE_L2 $NET_TYPE_INLINE_L3
+        $NET_TYPE_INLINE $NET_TYPE_INLINE_L2 $NET_TYPE_INLINE_L3 $NET_TYPE_OTHER
         $WIRELESS $WIRED $EAP $VIRTUAL
         $WEB_ADMIN_NONE $WEB_ADMIN_ALL
         $VOIP $NO_VOIP $NO_PORT $NO_VLAN
@@ -212,6 +217,7 @@ BEGIN {
         access_duration
         $BANDWIDTH_DIRECTION_RE $BANDWIDTH_UNITS_RE
         is_vlan_enforcement_enabled is_inline_enforcement_enabled is_dns_enforcement_enabled is_type_inline
+        netflow_enabled
         $LOG4PERL_RELOAD_TIMER
         @Profile_Filters %Profiles_Config
         %ConfigFirewallSSO
@@ -240,7 +246,9 @@ BEGIN {
         %ConfigSelfService
         %ConfigAuthenticationLdap
         %ConfigAuthenticationRadius
+        %ConfigAuthenticationEduroam
         %ConfigEAP
+        %ConfigAuthenticationEdir
     );
 }
 
@@ -321,8 +329,11 @@ tie %ConfigAuthenticationLdap, 'pfconfig::cached_hash', 'resource::authenticatio
 
 tie %ConfigAuthenticationRadius, 'pfconfig::cached_hash', 'resource::authentication_sources_radius';
 
+tie %ConfigAuthenticationEduroam, 'pfconfig::cached_hash', 'resource::authentication_sources_eduroam';
+
 tie %ConfigEAP, 'pfconfig::cached_hash', 'resource::eap_config';
 
+tie %ConfigAuthenticationEdir, 'pfconfig::cached_hash', 'resource::authentication_sources_edir';
 
 $thread = 0;
 
@@ -751,6 +762,8 @@ sub get_network_type {
         # deprecated isolation
         $logger->warn("networks.conf network type isolation is deprecated use vlan-isolation instead");
         return $NET_TYPE_VLAN_ISOL;
+    } elsif ($type =~ /^other$/) {
+        return $NET_TYPE_OTHER;
     }
 
     $logger->warn("Unknown network type for network $network");
@@ -863,6 +876,20 @@ sub load_configdata_into_db {
     pf::Survey::reload_from_config( \%pf::config::ConfigSurvey );
 }
 
+sub netflow_enabled {
+    if (isenabled($Config{advanced}{netflow_on_all_networks})) {
+        return $TRUE;
+    }
+
+    while( my ($network, $data) = each %ConfigNetworks ) {
+        # We skip non-inline networks/interfaces
+        next if ( !pf::config::is_network_type_inline($network) );
+        return $TRUE if isenabled($data->{netflow_accounting_enabled} || 'disabled');
+    }
+
+    return $FALSE;
+}
+
 =back
 
 =head1 AUTHOR
@@ -873,7 +900,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
