@@ -40,6 +40,7 @@ use pf::constants::config qw($DEFAULT_SMTP_PORT $DEFAULT_SMTP_PORT_SSL $DEFAULT_
 use IO::Socket::SSL qw(SSL_VERIFY_NONE);
 use pf::constants::config qw($TIME_MODIFIER_RE);
 use pf::constants::realm;
+use Encode qw(encode);
 use File::Basename;
 use Net::MAC::Vendor;
 use Net::SMTP;
@@ -62,7 +63,7 @@ BEGIN {
   our ( @ISA, @EXPORT );
   @ISA = qw(Exporter);
   @EXPORT = qw(
-    whitelisted_mac ip2interface ip2device
+    ip2interface ip2device
     pfmailer send_email get_all_internal_ips
     get_internal_nets get_routed_isolation_nets
     get_routed_registration_nets get_inline_nets
@@ -100,22 +101,6 @@ sub trappable_mac {
     }
 }
 
-sub whitelisted_mac {
-    my ($mac) = @_;
-    my $logger = get_logger();
-    return (0) if ( !valid_mac($mac) );
-    $mac = clean_mac($mac);
-    foreach
-        my $whitelist ( split( /\s*,\s*/, $Config{'fencing'}{'whitelist'} ) )
-    {
-        if ( $mac eq clean_mac($whitelist) ) {
-            $logger->info("$mac is whitelisted, skipping");
-            return (1);
-        }
-    }
-    return (0);
-}
-
 sub ip2interface {
     my ($ip) = @_;
     return (0) if ( !valid_ip($ip) );
@@ -193,7 +178,7 @@ sub build_email {
     my $msg = MIME::Lite::TT->new(
         To          => $email,
         Bcc         => $data->{'bcc'} || '',
-        Subject     => $subject,
+        Subject     => encode('MIME-Header', $subject),
         Encoding    => 'base64',
         Template    => "emails-$template.html",
         TmplOptions => \%TmplOptions,
@@ -701,7 +686,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
