@@ -34,26 +34,6 @@ our @SyslogInfo = (
         'name'       => 'httpd.aaa.access',
         'conditions' => [ '$programname contains "httpd_aaa"' ]
     },
-    {
-        'description' => 'httpd.admin Apache access log',
-        'name'       => 'httpd.admin.access',
-        'conditions' => [ '$syslogtag contains "httpd_admin_access"' ]
-    },
-    {
-        'description' => 'httpd.admin Catalyst log',
-        'name'       => 'httpd.admin.catalyst',
-        'conditions' => [ '$syslogtag contains "admin_catalyst"' ]
-    },
-    {
-        'description' => 'httpd.admin Apache error log',
-        'name'       => 'httpd.admin.error',
-        'conditions' => [ '$syslogtag contains "httpd_admin_err"' ]
-    },
-    {
-        'description' => 'httpd.admin general log',
-        'name'       => 'httpd.admin.log',
-        'conditions' => [ '$syslogtag contains "httpd_admin"' ]
-    },
     {
         'description' => 'httpd.collector Apache error log',
         'name'       => 'httpd.collector.error',
@@ -166,9 +146,9 @@ our @SyslogInfo = (
         'conditions' => [ '$programname == "pffilter"' ]
     },
     {
-        'description' => 'pfmon general log',
-        'name'       => 'pfmon.log',
-        'conditions' => [ '$programname == "pfmon"' ]
+        'description' => 'pfcron general log',
+        'name'       => 'pfcron.log',
+        'conditions' => [ '$programname == "pfcron"' ]
     },
     {
         'description' => 'pfsso general log',
@@ -267,7 +247,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
