@@ -133,11 +133,19 @@ sub db_execute {
             $logger->warn("database query failed with: $errstr (errno: $err), will try again");
             next;
         }
-        return $STATUS::OK, $sth;
+        my $mysql_info = $dbh->{mysql_info};
+        my $warnings = $sth->{mysql_warning_count};
+        if ($warnings) {
+            my $warnings = $dbh->selectall_arrayref('SHOW WARNINGS');
+            for my $w (@$warnings) {
+                $logger->warn(join(": ", @$w));
+            }
+        }
+        return $STATUS::OK, $sth, $mysql_info;
     } continue {
         $attempts--;
     }
-    return $status, undef;
+    return $status, undef, undef;
 }
 
 sub mysql_error_to_status_code {
@@ -328,19 +336,21 @@ update items
 
 sub update_items {
     my ($proto, @args) = @_;
-    my ($status, $sth) = $proto->do_update(
+    my ($status, $sth, $info) = $proto->do_update(
         -table => $proto->table,
         @args,
     );
     return $status, undef if is_error($status);
     my $rows = $sth->rows;
-    $sth->finish;
-    my $info = $sth->{Database}{mysql_info};
     if ($info && $info =~ /^.*: (\d+).*: (\d+).*: (\d+)/) {
+        $proto->logger->trace("Info : $info");
         my ($matched, $row, $warning) = ($1, $2, $3);
+        $sth->finish;
         return $STATUS::OK, $matched;
     }
 
+    $sth->finish;
+
     return $STATUS::OK, $rows;
 }
 
@@ -756,10 +766,10 @@ Wrap new and insert
 
 sub create {
     my ($self, $args) = @_;
-    my $obj = $self->new($args);
     my %insert_args = (
         -ignore => delete $args->{-ignore},
     );
+    my $obj = $self->new($args);
 
     return $obj->insert(%insert_args);
 }
@@ -897,21 +907,28 @@ sub set_tenant {
         return $TRUE
     }
 
-    my ($status, $count) = pf::dal->count(
-        -where => {
-            id => $tenant_id,
-        },
-        -from => 'tenant',
-    );
-
-    if (is_error($status)) {
-        get_logger->error("Problem looking up tenant ID ($tenant_id) in database");
+    if ($tenant_id < 0) {
+        get_logger->error("Cannot set a tenant id below 0");
         return $FALSE;
     }
 
-    if ($count == 0) {
-        get_logger->error("Invalid tenant ID ($tenant_id) specified, ignoring it and keeping current tenant");
-        return $FALSE;
+    if ($tenant_id > 1) {
+        my ($status, $count) = pf::dal->count(
+            -where => {
+                id => $tenant_id,
+            },
+            -from => 'tenant',
+        );
+
+        if (is_error($status)) {
+            get_logger->error("Problem looking up tenant ID ($tenant_id) in database");
+            return $FALSE;
+        }
+
+        if ($count == 0) {
+            get_logger->error("Invalid tenant ID ($tenant_id) specified, ignoring it and keeping current tenant");
+            return $FALSE;
+        }
     }
 
     get_logger->debug("Setting current tenant ID to $tenant_id");
@@ -1157,10 +1174,16 @@ Wrap call to pf::SQL::Abstract->delete and db_execute
 =cut
 
 sub do_delete {
-    my ($proto, @args) = @_;
+    my ($proto, %args) = @_;
     my $sqla          = $proto->get_sql_abstract;
-    @args = $proto->update_params_for_delete(@args);
+    my $ignore        = delete $args{'-ignore'};
+    my @args = $proto->update_params_for_delete(%args);
     my ($stmt, @bind) = $sqla->delete(@args);
+    if ($ignore) {
+        my $s = $sqla->_sqlcase('delete ignore ');
+        $stmt =~ s/delete /$s/ie;
+    }
+
     return $proto->db_execute($stmt, @bind);
 }
 
@@ -1323,7 +1346,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
