@@ -55,6 +55,7 @@ use pf::config qw(
     @radius_ints
     @dhcp_ints
     @dns_ints
+    netflow_enabled
 );
 use pf::file_paths qw($generated_conf_dir $conf_dir);
 use pf::util;
@@ -125,7 +126,7 @@ sub iptables_generate {
         'routed_postrouting_inline' => '','input_inter_vlan_if' => '',
         'domain_postrouting' => '','mangle_postrouting_inline' => '',
         'filter_forward_isol_vlan' => '', 'input_inter_isol_vlan_if' => '',
-        'filter_forward' => '',
+        'filter_forward' => '', 'forward_netflow' => '',
     );
 
     # global substitution variables
@@ -188,6 +189,7 @@ sub iptables_generate {
   );
 
     generate_domain_rules(\$tags{'filter_forward_domain'}, \$tags{'domain_postrouting'});
+    generate_netflow_rules(\$tags{'forward_netflow'});
 
     parse_template( \%tags, "$conf_dir/iptables.conf", "$generated_conf_dir/iptables.conf" );
     $self->iptables_restore("$generated_conf_dir/iptables.conf");
@@ -207,6 +209,7 @@ sub generate_filter_if_src_to_chain {
     my $rules_forward = '';
     my $passthrough_enabled = (isenabled($Config{'fencing'}{'passthrough'}) || isenabled($Config{'fencing'}{'isolation_passthrough'}));
     my $isolation_passthrough_enabled = isenabled($Config{'fencing'}{'isolation_passthrough'});
+    my $internal_portal_ip = $Config{captive_portal}{ip_address};
 
     # internal interfaces handling
     foreach my $interface (@internal_nets) {
@@ -239,7 +242,7 @@ sub generate_filter_if_src_to_chain {
             $rules .= "# DHCP Sync\n";
             $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647 -j ACCEPT\n" if ($pf::cluster_enabled);
             $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 67 -j ACCEPT\n";
-            $rules .= "-A INPUT --in-interface $dev -d 192.0.2.1 --jump $chain\n";
+            $rules .= "-A INPUT --in-interface $dev -d $internal_portal_ip --jump $chain\n";
             $rules .= "-A INPUT --in-interface $dev -d ".$cluster_ip." --jump $chain\n" if ($cluster_enabled);
             $rules .= "-A INPUT --in-interface $dev -d " . $interface->tag("vip") . " --jump $chain\n" if $interface->tag("vip");
             $rules .= "-A INPUT --in-interface $dev -d " . $interface->tag("ip") . " --jump $chain\n";
@@ -261,7 +264,7 @@ sub generate_filter_if_src_to_chain {
             $rules .= "# DHCP Sync\n";
             $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 647 -j ACCEPT\n" if ($cluster_enabled);
             $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 67 -j ACCEPT\n";
-            $rules .= "-A INPUT --in-interface $dev -d 192.0.2.1 --jump $FW_FILTER_INPUT_INT_VLAN\n";
+            $rules .= "-A INPUT --in-interface $dev -d $internal_portal_ip --jump $FW_FILTER_INPUT_INT_VLAN\n";
             $rules .= "-A INPUT --in-interface $dev -d ".$cluster_ip." --jump $FW_FILTER_INPUT_INT_INLINE\n" if ($cluster_enabled);
             $rules .= "-A INPUT --in-interface $dev --protocol udp --match udp --dport 53 --jump $FW_FILTER_INPUT_INT_INLINE\n";
             $rules .= "-A INPUT --in-interface $dev --protocol tcp --match tcp --dport 53 --jump $FW_FILTER_INPUT_INT_INLINE\n";
@@ -481,7 +484,7 @@ sub generate_passthrough_rules {
                     $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $int -j SNAT --to ".$if->address."\n";
                 }
             } else {
-                $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $mgmt_int -j SNAT --to ".$if->address."\n";
+                $$nat_rules_ref .= "-A POSTROUTING -s $network/$network_obj->{BITS} -o $int -j SNAT --to ".$if->address."\n";
             }
         }
     }
@@ -802,6 +805,13 @@ sub generate_domain_rules {
     $$domain_postrouting .= "-A POSTROUTING -s $domain_network -o $mgmt_int -j SNAT --to-source $mgmt_ip \n"
 }
 
+sub generate_netflow_rules {
+    my ($forward_netflow_ref) = @_;
+    if (netflow_enabled()) {
+        $$forward_netflow_ref .= "-I FORWARD -j NETFLOW\n";
+    }
+}
+
 =back
 
 =head1 AUTHOR
@@ -812,7 +822,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
