@@ -30,6 +30,7 @@ our %FUNCS = (
     log => sub { get_logger()->info("mini_template:" . Dumper(\@_)  ); ''},
     replace => \&replaceStr,
     BuildFromMatch => \&extract,
+    if => sub { $_[0] ? $_[1] : $_[2] }
 );
 
 sub replaceStr {
@@ -189,12 +190,18 @@ sub _parse_var {
         if (/\G\s*\(\s*/gc) {
             my $n = join('.', @names);
             $_[0]->{funcs}{$n} = undef;
-            return ['F', $n, _parse_func($_[0])];
+            my $f = ['F', $n, _parse_func($_[0])];
+            if (!/\G\s*\}/gc) {
+                die format_parse_error("no matching }", $_, pos);
+            }
+
+            return _optimize([$f, _parse_text($_[0])]);
         }
 
         if (!/\G\s*\}/gc) {
             die format_parse_error("no matching }", $_, pos);
         }
+
         if (@names == 1) {
             $_[0]->{vars}{$names[0]} = undef;
             return [['V', @names], _parse_text($_[0])];
@@ -337,7 +344,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
