@@ -281,6 +281,9 @@ sub _update_from_actions {
     my @values = grep { $_->{type} eq $Actions::SET_ROLE } @{$actions};
     if (scalar @values > 0) {
         my $role_id = nodecategory_lookup( $values[0]->{value} );
+        if(!defined($role_id) && nodecategory_exist($values[0]->{value})) {
+            $role_id = $values[0]->{value};
+        }
         $data->{'category'} = $role_id;
     }
 }
@@ -296,6 +299,11 @@ sub _update_field_for_action {
     my @values = grep { $_->{type} eq $action } @{$actions};
     if ( scalar @values > 0 ) {
         $data->{$field} = $values[0]->{value};
+        if ($action eq $Actions::SET_ACCESS_LEVEL) {
+            if (ref($data->{$field}) eq 'ARRAY') {
+                $data->{$field} = join(",", @{$data->{$field}});
+            }
+        }
     }
     else {
         $data->{$field} = $default;
@@ -603,7 +611,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
