@@ -72,6 +72,7 @@ use pf::dal;
 use pf::security_event;
 use pf::constants::security_event qw($LOST_OR_STOLEN);
 use pf::Redis;
+use pf::constants::eap_type qw($EAP_TLS $MS_EAP_AUTHENTICATION $EAP_PSK);
 
 our $VERSION = 1.03;
 
@@ -129,7 +130,7 @@ sub authorize {
         goto AUDIT;
     }
 
-    $switch->setCurrentTenant();
+    $switch->setCurrentTenant($radius_request);
     my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
 
     if (!$mac) {
@@ -169,6 +170,7 @@ sub authorize {
         ifIndex => $port,
         ifDesc => $ifDesc,
         user_name => $user_name,
+        username => $user_name,
         nas_port_id => $nas_port_type // '',
         session_id => $session_id,
         connection_type => $connection_type,
@@ -246,7 +248,7 @@ sub authorize {
     $options->{'last_connection_sub_type'} = $args->{'connection_sub_type'};
     $options->{'last_connection_type'}     = connection_type_to_str($args->{'connection_type'});
     $options->{'last_switch'}              = $switch_id;
-    $options->{'last_port'}                = $args->{'switch'}->{switch_port} if (defined($args->{'switch'}->{switch_port}));
+    $options->{'last_port'}                = $port if defined $port && length($port);
     $options->{'last_vlan'}                = $args->{'vlan'} if (defined($args->{'vlan'}));
     $options->{'last_ssid'}                = $args->{'ssid'} if (defined($args->{'ssid'}));
     $options->{'last_dot1x_username'}      = $args->{'user_name'} if (defined($args->{'user_name'}));
@@ -255,8 +257,16 @@ sub authorize {
     $options->{'fingerbank_info'}     = $args->{'fingerbank_info'};
 
     my $profile = pf::Connection::ProfileFactory->instantiate($args->{'mac'},$options);
-    $args->{'profile'} = $profile; 
+    $args->{'profile'} = $profile;
+    $args->{'portal'} = $profile->getName;
     
+    (my $dpsk_accept, $connection, $connection_type, $connection_sub_type, $args) = $self->handleUnboundDPSK($radius_request, $switch, $profile, $connection, $args);
+    if(!$dpsk_accept) {
+        $logger->error("Unable to find a valid PSK for this request. Rejecting user.");
+        $RAD_REPLY_REF = [ $RADIUS::RLM_MODULE_USERLOCK, ('Reply-Message' => "Invalid PSK") ];
+        goto CLEANUP;
+    }
+
     $args->{'autoreg'} = 0;
     # should we auto-register? let's ask the VLAN object
     my ( $status, $status_msg );
@@ -274,6 +284,7 @@ sub authorize {
         if (is_error($status)) {
             $logger->error("auto-registration of node failed $status_msg");
             $do_auto_reg = 0;
+            $node_obj->{status} = "unreg";
             $RAD_REPLY_REF = [ $RADIUS::RLM_MODULE_USERLOCK, ('Reply-Message' => $status_msg) ];
             goto CLEANUP;
         }
@@ -389,7 +400,7 @@ sub accounting {
         return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Switch is not managed by PacketFence" ) ];
     }
 
-    $switch->setCurrentTenant();
+    $switch->setCurrentTenant($radius_request);
     my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
 
     # update last_seen of MAC address as some activity from it has been seen
@@ -407,6 +418,7 @@ sub accounting {
 
     if($isStart || $isUpdate){
         pf::accounting->cache->set($mac, $radius_request);
+        pf::fingerbank::process($mac);
     }
 
     if ($isStop || $isUpdate) {
@@ -530,7 +542,7 @@ sub update_locationlog_accounting {
         return [ $RADIUS::RLM_MODULE_FAIL, ( 'Reply-Message' => "Switch is not managed by PacketFence" ) ];
     }
 
-    $switch->setCurrentTenant();
+    $switch->setCurrentTenant($radius_request);
     if ($switch->supportsRoamingAccounting()) {
         my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
         my $locationlog_mac = locationlog_last_entry_mac($mac);
@@ -829,7 +841,7 @@ sub switch_access {
         );
         return [ $RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "Switch is not managed by PacketFence") ];
     }
-    if ( isdisabled($switch->{_cliAccess}) && !$switch->supportsVPN()) {
+    if ( !$switch->canDoCliAccess && !$switch->supportsVPN()) {
         $logger->warn("CLI Access is not permit on this switch $switch->{_id}");
         return [ $RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "CLI or VPN Access is not allowed by PacketFence on this switch") ];
     }
@@ -853,7 +865,7 @@ sub switch_access {
     $options->{'last_connection_sub_type'} = $connection_sub_type;
     $options->{'last_connection_type'}     = connection_type_to_str($connection_type);
     $options->{'last_switch'}              = $switch->{_id};
-    $options->{'last_port'}                = $args->{'switch'}->{switch_port} if (defined($args->{'switch'}->{switch_port}));
+    $options->{'last_port'}                = $port if defined $port && length($port);
     $options->{'last_vlan'}                = $args->{'vlan'} if (defined($args->{'vlan'}));
     $options->{'last_ssid'}                = $args->{'ssid'} if (defined($args->{'ssid'}));
     $options->{'last_dot1x_username'}      = $args->{'user_name'} if (defined($args->{'username'}));
@@ -908,13 +920,13 @@ sub switch_access {
         }
     }
     else {
-            my $profile = pf::Connection::ProfileFactory->instantiate("de:fa:ce:db:ab:e0",$options);
+            my $profile = pf::Connection::ProfileFactory->instantiate($FAKE_MAC,$options);
             $args->{'profile'} = $profile;
             @sources = $profile->getFilteredAuthenticationSources($args->{'stripped_user_name'}, $args->{'realm'});
     }
     my ( $return, $message, $source_id, $extra );
     $source_id = \@sources;
-    if (!defined($args->{'radius_request'}{'MS-CHAP-Challenge'})) {
+    if (!defined($args->{'radius_request'}{'MS-CHAP-Challenge'}) && defined($radius_request->{"EAP-Type"}) && $radius_request->{"EAP-Type"} != $EAP_TLS && $radius_request->{"EAP-Type"} != $MS_EAP_AUTHENTICATION) {
         ( $return, $message, $source_id, $extra ) = pf::authentication::authenticate( {
                 'username' =>  $radius_request->{'User-Name'},
                 'password' =>  $radius_request->{'User-Password'},
@@ -964,6 +976,7 @@ our %ARGS_TO_RADIUS_ATTRIBUTES = (
     connection_type => 'PacketFence-Connection-Type',
     user_role => 'PacketFence-Role',
     time => 'PacketFence-Request-Time',
+    portal => 'PacketFence-Profile',
 );
 
 our %NODE_ATTRIBUTES_TO_RADIUS_ATTRIBUTES = (
@@ -1025,7 +1038,8 @@ sub handleNtlmCaching {
         my $cache_key = "$domain.$radius_username";
         my $username = pf::domain::ntlm_cache::get_from_cache($cache_key);
         if (defined($usedNtHash) && $usedNtHash && defined($username)) {
-            $self->update_user_in_redis_cache($domain,$username);
+            my $client = pf::api::queue_cluster->new(queue => "general");
+            $client->cluster_notify_all("update_user_in_redis_cache", $domain, $username);
         }
         else {
             my $client = pf::api::queue->new(queue => "general");
@@ -1073,7 +1087,7 @@ sub radius_filter {
         return [ $RADIUS::RLM_MODULE_FAIL, ('Reply-Message' => "Switch is not managed by PacketFence") ];
     }
 
-    $switch->setCurrentTenant();
+    $switch->setCurrentTenant($radius_request);
     my ($nas_port_type, $eap_type, $mac, $port, $user_name, $nas_port_id, $session_id, $ifDesc) = $switch->parseRequest($radius_request);
 
     if (!$mac) {
@@ -1137,26 +1151,28 @@ sub check_lost_stolen {
     }
 }
 
-=head2 update_user_in_redis_cache
-
-Update a user/NT hash combination inside redis for a given domain
-
-=cut
-
-sub update_user_in_redis_cache {
-    my ($self, $domain, $user) = @_;
+sub handleUnboundDPSK {
+    my ($self, $radius_request, $switch, $profile, $connection, $args) = @_;
     my $logger = get_logger;
-    my $config = $ConfigDomain{$domain};
-
-    # pf::Redis has a cache for the connection
-    my $redis = pf::Redis->new(server => "$NTLM_REDIS_CACHE_HOST:$NTLM_REDIS_CACHE_PORT", reconnect => 5);
-
-
-    my $key = "NTHASH:$domain:$user";
-    my $nthash = $redis->get($key);
-    if (defined($nthash)) {
-        $redis->set($key, $nthash, 'EX', $config->{ntlm_cache_expiry});
-        $logger->info("Updating '$key' => '$nthash'");
+    
+    if($profile->unboundDpskEnabled()) {
+        my $accept = $FALSE;
+        if(my $pid = $switch->find_user_by_psk($radius_request)) {
+            $logger->info("Unbound DPSK user found $pid. Changing this request to use the 802.1x logic");
+            $connection->isMacAuth($FALSE);
+            $connection->is8021X($TRUE);
+            $connection->isEAP($TRUE);
+            $connection->subType($EAP_PSK);
+            $connection->_attributesToString;
+            $args->{connection_type} = $connection->attributesToBackwardCompatible;
+            $args->{connection_sub_type} = $connection->subType;
+            $args->{username} = $args->{stripped_user_name} = $args->{user_name} = $pid;
+            $accept = $TRUE;
+        }
+        return ($accept, $connection, $args->{connection_type}, $args->{connection_sub_type}, $args);
+    }
+    else {
+        return ($TRUE, $connection, $args->{connection_type}, $args->{connection_sub_type}, $args);
     }
 }
 
@@ -1168,7 +1184,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
