@@ -24,7 +24,7 @@ use pf::log;
 use pf::person;
 use pf::lookup::person;
 use pf::security_event;
-use pf::constants::node qw($STATUS_REGISTERED);
+use pf::constants::node qw($STATUS_REGISTERED $STATUS_UNREGISTERED);
 use pf::util;
 use pf::util::statsd qw(called);
 use pf::dal::person;
@@ -48,8 +48,9 @@ sub setup_node_for_registration {
 
     my $status_msg = "";
     my $pid = $node->pid;
-    if ( $node->{__old_data}->{status} ne "reg" &&  pf::node::is_max_reg_nodes_reached($mac, $pid, $node->category, $node->category_id) ) {
+    if ( ($node->{__old_data}->{pid} ne $pid || $node->{__old_data}->{status} ne "reg") &&  pf::node::is_max_reg_nodes_reached($mac, $pid, $node->category, $node->category_id) ) {
         if (!($action eq $Actions::SET_ROLE_FROM_SOURCE)) {
+            $node->status($STATUS_UNREGISTERED);
             $status_msg = "max nodes per pid met or exceeded";
             $status_msg = "no role computed by any sources" if (!defined($node->category));
             $logger->error( "$status_msg - registration of $mac to $pid failed" );
@@ -134,7 +135,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
