@@ -585,11 +585,6 @@ sub security_event_trigger {
     return (0) if ( !$tid );
     $type = lc($type);
 
-    if (whitelisted_mac($mac)) {
-        $logger->info("security_event not added, $mac is whitelisted! trigger ${type}::${tid}");
-        return 0;
-    }
-
     if (!valid_mac($mac)) {
         $logger->info("security_event not added, MAC $mac is invalid! trigger ${type}::${tid}");
         return 0;
@@ -638,7 +633,7 @@ sub security_event_trigger {
             next;
         }
         # Compute the release date
-        my $date = 0;
+        my $date = $ZERO_DATE;
         my %data;
 
         my $class = class_view($security_event_id);
@@ -1023,7 +1018,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
