@@ -22,10 +22,9 @@ has '+name' => (default => sub { 'galera-autofix' } );
 
 sub isManaged {
     my ($self) = @_;
-    return $self->SUPER::isManaged() && $cluster_enabled;
+    return $self->SUPER::isManaged() && $cluster_enabled && !pf::cluster::isSlaveMode();
 }
 
-
 =head1 AUTHOR
 
 Inverse inc. <info@inverse.ca>
@@ -34,7 +33,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
