@@ -42,7 +42,6 @@ has '+haproxy_config_template' => (default => sub { "$conf_dir/haproxy-admin.con
 my $host_id = $pf::config::cluster::host_id;
 
 tie our %NetworkConfig, 'pfconfig::cached_hash', "resource::network_config($host_id)";
-tie @config_cluster_servers, 'pfconfig::cached_array', "resource::all_cluster_servers";
 
 sub generateConfig {
     my ($self,$quick) = @_;
@@ -68,7 +67,7 @@ sub generateConfig {
         $mgmt_cluster_ip = pf::cluster::cluster_ip($mgmt_int) || $mgmt_cfg->{'vip'} || $mgmt_cfg->{'ip'};
         my @mgmt_backend_ip;
         if ($cluster_enabled) {
-            @mgmt_backend_ip = map { $_->{'management_ip'} } @config_cluster_servers;
+            @mgmt_backend_ip = map { $_->{'management_ip'} } pf::cluster::config_enabled_servers;
         } else {
             @mgmt_backend_ip = values %{pf::cluster::members_ips($mgmt_int)};
         }
@@ -90,8 +89,8 @@ backend 127.0.0.1-netdata
         option httpclose
         option http_proxy
         option forwardfor
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         acl paramsquery query -m found
         http-request lua.admin
         http-request set-uri http://127.0.0.1:19999%[var(req.path)]?%[query] if paramsquery
@@ -132,8 +131,9 @@ backend $mgmt_back_ip-api
         balance source
         option httpclose
         option forwardfor
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        http-response set-header X-Frame-Options SAMEORIGIN
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         server $mgmt_back_ip $mgmt_back_ip:9999 weight 1 maxconn 100 ssl verify none
 EOT
 
@@ -144,22 +144,23 @@ backend api
         balance source
         option httpclose
         option forwardfor
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
 $mgmt_backend_ip_api_config
 
 frontend admin-https-$mgmt_cluster_ip
         bind $mgmt_cluster_ip:1443 ssl no-sslv3 crt /usr/local/pf/conf/ssl/server.pem
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         capture request header Host len 40
         reqadd X-Forwarded-Proto:\\ https
         http-request lua.change_host
         acl host_exist var(req.host) -m found
         http-request set-header Host %[var(req.host)] if host_exist
+        http-response set-header X-Frame-Options SAMEORIGIN
         http-request lua.admin
         use_backend %[var(req.action)]
-        http-request redirect location /admin/alt if { lua.redirect 1 }
+        http-request redirect location /admin if { lua.redirect 1 }
 EOT
             if (isenabled($Config{services}{httpd_admin})) {
         $tags{'http_admin'} .= <<"EOT";
@@ -184,8 +185,8 @@ $tags{'http_admin'} .= <<"EOT";
 
 frontend admin-https-$mgmt_ip
         bind $mgmt_ip:1443 ssl no-sslv3 crt /usr/local/pf/conf/ssl/server.pem
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         capture request header Host len 40
         reqadd X-Forwarded-Proto:\\ https
         http-request lua.change_host
@@ -195,7 +196,7 @@ frontend admin-https-$mgmt_ip
         use_backend $mgmt_ip-api if url_api
         http-request lua.admin
         use_backend %[var(req.action)]
-        http-request redirect location /admin/alt if { lua.redirect 1 }
+        http-request redirect location /admin if { lua.redirect 1 }
 EOT
             if (isenabled($Config{services}{httpd_admin})) {
         $tags{'http_admin'} .= <<"EOT";
@@ -242,22 +243,23 @@ backend api
         balance source
         option httpclose
         option forwardfor
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         server 127.0.0.1 127.0.0.1:9999 weight 1 maxconn 100 check  ssl verify none
 
 frontend admin-https-0.0.0.0
         bind 0.0.0.0:1443 ssl no-sslv3 crt /usr/local/pf/conf/ssl/server.pem
-        errorfile 502 /usr/local/pf/html/pfappserver/root/static/502.json.http
-        errorfile 503 /usr/local/pf/html/pfappserver/root/static/503.json.http
+        errorfile 502 /usr/local/pf/html/pfappserver/root/errors/502.json.http
+        errorfile 503 /usr/local/pf/html/pfappserver/root/errors/503.json.http
         capture request header Host len 40
         reqadd X-Forwarded-Proto:\\ https
         http-request lua.change_host
+        http-response set-header X-Frame-Options SAMEORIGIN
         acl host_exist var(req.host) -m found
         http-request set-header Host %[var(req.host)] if host_exist
         http-request lua.admin
         use_backend %[var(req.action)]
-        http-request redirect location /admin/alt if { lua.redirect 1 }
+        http-request redirect location /admin if { lua.redirect 1 }
 
 EOT
     }
@@ -280,11 +282,12 @@ The creates the portal preview ip addresss
 
 sub portal_preview_ip {
     my ($self) = @_;
+    my $internal_portal_ip = $Config{captive_portal}{ip_address};
     if (!$cluster_enabled) {
         return "127.0.0.1";
     }
     my  @ints = uniq (@internal_nets, @portal_ints);
-    return $ints[0]->{Tvip} ? $ints[0]->{Tvip} : $ints[0]->{Tip};
+    return $ints[0]->{Tvip} ? $ints[0]->{Tvip} : $ints[0]->{Tip} ? $ints[0]->{Tip} : $internal_portal_ip;
 }
 
 =head1 AUTHOR
@@ -295,7 +298,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
