@@ -64,6 +64,8 @@ sub generateConfig {
     my ($package, $filename, $line) = caller();
     $logger->info("$package, $filename, $line");
 
+    my $internal_portal_ip = $Config{captive_portal}{ip_address};
+
     my %tags;
     $tags{'template'} = "$conf_dir/keepalived.conf";
     
@@ -81,11 +83,16 @@ sub generateConfig {
     $tags{'vrrp'} .= <<"EOT";
 
 static_ipaddress {
-    192.0.2.1 dev lo scope link
+    $internal_portal_ip dev lo scope link
     $ips
 }
 
 static_routes {
+
+#Static from packetfence config
+$Config{'network'}{'staticroutes'}
+
+#PacketFence managed networks
 $routes
 }
 
@@ -99,7 +106,7 @@ EOT
             next unless $cfg;
             my $priority = 100 - pf::cluster::reg_cluster_index();
             my $process_tracking = "haproxy_portal";
-            if ($Config{"interface $interface"}{'type'} =~ /management/i) {
+            if ($Config{"interface $interface"}{'type'} =~ /management/i || $Config{"interface $interface"}{'type'} =~ /radius/i) {
                 $process_tracking = "radius_load_balancer";
                 $priority = 100 - pf::cluster::cluster_index();
             }
@@ -215,7 +222,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
