@@ -22,6 +22,8 @@ use List::MoreUtils qw(any uniq);
 use Moo;
 use NetAddr::IP;
 use Template;
+use Data::Dumper;
+use File::Slurp qw(write_file);
 
 use pfconfig::cached_array;
 use pfconfig::cached_hash;
@@ -32,6 +34,7 @@ use pf::util;
 use Socket;
 
 use pf::constants qw($TRUE $FALSE);
+use pf::error qw(is_error);
 
 use pf::file_paths qw(
     $conf_dir
@@ -43,6 +46,8 @@ use pf::config qw(
     %Config
     $management_network
     %ConfigDomain
+    %ConfigRealm
+    @ConfigOrderedRealm
     $local_secret
     @radius_ints
     %ConfigAuthenticationLdap
@@ -109,13 +114,14 @@ sub _generateConfig {
     $self->generate_radiusd_eapconf($tt);
     $self->generate_radiusd_restconf();
     $self->generate_radiusd_sqlconf();
-    $self->generate_radiusd_sitesconf();
+    $self->generate_radiusd_sitesconf($tt);
     $self->generate_radiusd_proxy();
     $self->generate_radiusd_cluster($tt);
     $self->generate_radiusd_cliconf($tt);
     $self->generate_radiusd_eduroamconf($tt);
     $self->generate_radiusd_ldap($tt);
     $self->generate_radiusd_mschap($tt);
+    $self->generate_multi_domain_constants();
 }
 
 
@@ -124,13 +130,19 @@ Generates the packetfence and packetfence-tunnel configuration file
 =cut
 
 sub generate_radiusd_sitesconf {
+    my ($self, $tt) = @_;
     my %tags;
 
+    $tags{'remote'} = "";
     $tags{'authorize_eap_choice'} = "";
     $tags{'authentication_auth_type'} = "";
+    $tags{'authorize_eap_choice_degraded'} = "";
+    $tags{'authentication_auth_type_degraded'} = "";
 
     generate_eap_choice(\$tags{'authorize_eap_choice'}, \$tags{'authentication_auth_type'});
 
+    generate_eap_choice(\$tags{'authorize_eap_choice_degraded'}, \$tags{'authentication_auth_type_degraded'}, "eap-degraded");
+
     if(isenabled($Config{radius_configuration}{record_accounting_in_sql})){
         $tags{'accounting_sql'} = "sql";
     }
@@ -186,8 +198,40 @@ EOT
 EOT
     }
 
-    $tags{'template'}    = "$conf_dir/raddb/sites-enabled/packetfence";
-    parse_template( \%tags, "$conf_dir/radiusd/packetfence", "$install_dir/raddb/sites-enabled/packetfence" );
+    # Remote config
+
+    if (pf::cluster::isSlaveMode()) {
+
+        $tags{'remote'} = "YES";
+        $tags{'management_ip'} = defined($management_network->tag('vip')) ? $management_network->tag('vip') : $management_network->tag('ip');
+
+        $tags{'members'} = '';
+        $tags{'config'} ='';
+        my $i = 0;
+        my $radius_remote = pf::cluster::getDBMaster();
+
+        $tags{'members'} .= <<"EOT";
+home_server pf.remote {
+        type = auth+acct
+        ipaddr = $radius_remote
+        src_ipaddr = $tags{'management_ip'}
+        port = 1812
+        secret = $local_secret
+        response_window = 6
+        status_check = status-server
+        revive_interval = 120
+        check_interval = 30
+        num_answers_to_alive = 3
+}
+EOT
+            $tags{'home_server'} .= <<"EOT";
+        home_server =  pf.remote
+EOT
+    }
+
+    $tags{proxy_pfacct} = isenabled($Config{services}{pfacct});
+
+    $tt->process("$conf_dir/radiusd/packetfence", \%tags, "$install_dir/raddb/sites-enabled/packetfence") or die $tt->error();
 
     %tags = ();
 
@@ -263,12 +307,17 @@ EOT
 
     generate_eap_choice(\$tags{'authorize_eap_choice'}, \$tags{'authentication_auth_type'});
 
-    $tags{'template'}    = "$conf_dir/raddb/sites-enabled/packetfence-tunnel";
-    parse_template( \%tags, "$conf_dir/radiusd/packetfence-tunnel", "$install_dir/raddb/sites-enabled/packetfence-tunnel" );
+    $tags{'authorize_ldap_choice'} = "";
+    $tags{'authentication_ldap_auth_type'} = "";
+    $tags{'edir_configuration'} = "";
+
+    generate_ldap_choice(\$tags{'authorize_ldap_choice'}, \$tags{'authentication_ldap_auth_type'}, \$tags{'edir_configuration'});
+
+    $tt->process("$conf_dir/radiusd/packetfence-tunnel", \%tags, "$install_dir/raddb/sites-enabled/packetfence-tunnel") or die $tt->error();
 
     %tags = ();
     $tags{'template'}    = "$conf_dir/raddb/sites-enabled/packetfence-cli";
-    parse_template( \%tags, "$conf_dir/radiusd/packetfence-cli", "$install_dir/raddb/sites-enabled/packetfence-cli" );
+    $tt->process("$conf_dir/radiusd/packetfence-cli", \%tags, "$install_dir/raddb/sites-enabled/packetfence-cli") or die $tt->error();
 
 }
 
@@ -325,6 +374,11 @@ sub generate_radiusd_authconf {
         }
     }
 
+    $tags{'virtual_server'} = "packetfence";
+    if (pf::cluster::isSlaveMode()) {
+        $tags{'virtual_server'} = "pf-remote";
+    }
+
     $tags{'listen_ips'} = [uniq @listen_ips];
     $tags{'pid_file'} = "$var_dir/run/radiusd.pid";
     $tags{'socket_file'} = "$var_dir/run/radiusd.sock";
@@ -612,7 +666,9 @@ EOT
 }
 
 =head2 generate_radiusd_eapconf
+
 Generates the eap.conf configuration file
+
 =cut
 
 sub generate_radiusd_eapconf {
@@ -672,12 +728,26 @@ sub generate_radiusd_ldap {
     my $ldap_config = $FALSE;
     foreach my $ldap (keys %ConfigAuthenticationLdap) {
         my $searchattributes = '';
-        if (scalar @{$ConfigAuthenticationLdap{$ldap}->{searchattributes}} == 0) {
-            next;
+        my $edir_options;
+        if ($ConfigAuthenticationLdap{$ldap}->{type} eq 'EDIR') {
+            $edir_options .= << "EOT";
+
+    # Enable Novell eDirectory support
+    edir = yes
+    edir_account_policy_check = yes
+    #
+    # eDirectory attribute for Universal Password
+    password_attribute = nspmPassword
+
+EOT
+        } else {
+            $edir_options = '';
         }
 
-        foreach my $searchattribute (@{$ConfigAuthenticationLdap{$ldap}->{searchattributes}}) {
-            $searchattributes .= '('.$searchattribute.'=%{User-Name})('.$searchattribute.'=%{Stripped-User-Name})';
+        if (scalar @{$ConfigAuthenticationLdap{$ldap}->{searchattributes}}) {
+            foreach my $searchattribute (@{$ConfigAuthenticationLdap{$ldap}->{searchattributes}}) {
+                $searchattributes .= '('.$searchattribute.'=%{User-Name})('.$searchattribute.'=%{Stripped-User-Name})';
+            }
         }
         $ldap_config = $TRUE;
         my $server_list;
@@ -702,6 +772,8 @@ $server_list
     base_filter     = "(objectclass=user)"
     rebind          = "yes"
     chase_referrals = "yes"
+$edir_options
+
     update {
         control:AD-Samaccountname := 'sAMAccountName'
         request:PacketFence-UserNameAttribute := "$ConfigAuthenticationLdap{$ldap}->{usernameattribute}"
@@ -795,10 +867,16 @@ type = $pf::config::ConfigRealm{$realm}->{'radius_auth_proxy_type'}
 EOT
             push(@radius_sources, split(',',$pf::config::ConfigRealm{$realm}->{'radius_auth'}));
             foreach my $radius (split(',',$pf::config::ConfigRealm{$realm}->{'radius_auth'})) {
-
+                if (pf::authentication::getAuthenticationSource($radius)->{'type'} eq "Eduroam") {
+                    $tags{'config'} .= <<"EOT";
+home_server = eduroam_server1
+home_server = eduroam_server2
+EOT
+                } else {
                 $tags{'config'} .= <<"EOT";
 home_server = $radius
 EOT
+                }
             }
             $tags{'config'} .= <<"EOT";
 }
@@ -891,6 +969,7 @@ EOT
     }
     foreach my $radius (uniq @radius_sources) {
         my $source = pf::authentication::getAuthenticationSource($radius);
+        next if ($source->{'type'} eq "Eduroam");
         my @addresses = gethostbyname($source->{'host'});
         my @ips = map { inet_ntoa($_) } @addresses[4 .. $#addresses];
         my $src_ip = pf::util::find_outgoing_srcip($ips[0]);
@@ -943,6 +1022,34 @@ EOT
         $tags{'eduroam'} = "# Eduroam integration is not configured";
     }
 
+    if(isenabled($Config{services}{pfacct})) {
+        my $management_ip = defined($management_network->tag('vip')) ? $management_network->tag('vip') : $management_network->tag('ip');
+        $tags{'pfacct'} = <<"EOT";
+# pfacct configuration
+
+realm pfacct {
+    acct_pool = pfacct_pool
+    nostrip
+}
+
+home_server_pool pfacct_pool {
+    home_server = pfacct_local
+}
+
+home_server pfacct_local {
+    type = acct
+    ipaddr = 127.0.0.1
+    port = 1813
+    secret = '$local_secret'
+    src_ipaddr = $management_ip
+}
+
+EOT
+    }
+    else {
+        $tags{'pfacct'} = "# pfacct is not enabled";
+    }
+
     parse_template( \%tags, "$conf_dir/radiusd/proxy.conf.inc", "$install_dir/raddb/proxy.conf.inc" );
 
     undef %tags;
@@ -1167,8 +1274,10 @@ EOT
 
         
         push @radius_backend, $cluster_ip;
-        foreach my $radius_back (@radius_backend) {
-            $tags{'config'} .= <<"EOT";
+        push @radius_backend, map { $_->{management_ip} } pf::cluster::config_enabled_servers();
+
+        foreach my $radius_back (uniq(@radius_backend)) {
+        $tags{'config'} .= <<"EOT";
 client $radius_back {
         ipaddr = $radius_back
         secret = $local_secret
@@ -1211,14 +1320,18 @@ Generate the configuration for eap choice
 =cut
 
 sub generate_eap_choice {
-    my ($authorize_eap_choice, $authentication_auth_type) = @_;
-        my $if = 'if';
-        foreach my $key ( @pf::config::ConfigOrderedRealm ) {
-            next if $pf::config::ConfigRealm{$key}->{'eap'} eq 'default';
-            my $choice = $key;
-            $choice = $pf::config::ConfigRealm{$key}->{'regex'} if (defined $pf::config::ConfigRealm{$key}->{'regex'} && $pf::config::ConfigRealm{$key}->{'regex'} ne '');
-            my $eap = ( defined($pf::config::ConfigRealm{$key}->{'eap'}) && $pf::config::ConfigRealm{$key}->{'eap'} ne '') ? $pf::config::ConfigRealm{$key}->{'eap'} : 'eap';
-            $$authorize_eap_choice .= <<"EOT";
+    my ($authorize_eap_choice, $authentication_auth_type, $suffix) = @_;
+    if (!(defined($suffix) && $suffix ne "" )) {
+        $suffix = "";
+    }
+    my $if = 'if';
+    foreach my $key ( @pf::config::ConfigOrderedRealm ) {
+        next if $pf::config::ConfigRealm{$key}->{'eap'} eq 'default';
+        my $choice = $key;
+        $choice = $pf::config::ConfigRealm{$key}->{'regex'} if (defined $pf::config::ConfigRealm{$key}->{'regex'} && $pf::config::ConfigRealm{$key}->{'regex'} ne '');
+        my $eap = ( defined($pf::config::ConfigRealm{$key}->{'eap'}) && $pf::config::ConfigRealm{$key}->{'eap'} ne '') ? $pf::config::ConfigRealm{$key}->{'eap'} : 'eap';
+        $eap = $eap."-".$suffix if ($suffix ne "" && $suffix ne "eap-degraded");
+        $$authorize_eap_choice .= <<"EOT";
             $if (Realm =~ /$choice/) {
                 $eap {
                     ok = return
@@ -1226,31 +1339,121 @@ sub generate_eap_choice {
             }
 EOT
             $if = 'elsif';
-        }
-        if ($if eq 'elsif') {
-            $$authorize_eap_choice .= <<"EOT";
+    }
+    if ($if eq 'elsif') {
+        $$authorize_eap_choice .= <<"EOT";
             else {
                 eap {
                     ok = return
                 }
             }
 EOT
-        } else {
-            $$authorize_eap_choice .= <<"EOT";
-            eap {
+    } else {
+        my $eap = (defined($suffix) && $suffix ne "" ) ? $suffix : "eap";
+        $$authorize_eap_choice .= <<"EOT";
+            $eap {
                 ok = return
             }
 EOT
-        }
-        foreach my $key (keys %ConfigEAP) {
-            next if $key eq 'default';
-            $$authentication_auth_type .= <<"EOT";
+    }
+    foreach my $key (keys %ConfigEAP) {
+        next if $key eq 'default';
+        $key = $key."-".$suffix if ($suffix ne "");
+        $$authentication_auth_type .= <<"EOT";
         Auth-Type $key {
             $key
         }
 EOT
+    }
+    if ($suffix ne "") {
+    $$authentication_auth_type .= <<"EOT";
+        Auth-Type $suffix {
+            $suffix
         }
+EOT
+    }
+}
 
+sub generate_ldap_choice {
+    my ($authorize_ldap_choice, $authentication_ldap_auth_type, $edir_configuration) = @_;
+    my $if = 'if';
+    my $of = 'if';
+    my $edir_config = "";
+    foreach my $key ( @pf::config::ConfigOrderedRealm ) {
+        my $choice = $key;
+        if (defined($pf::config::ConfigRealm{$key}->{ldap_source_ttls_pap}) && exists($pf::config::ConfigRealm{$key}->{ldap_source_ttls_pap})) {
+            $choice = $pf::config::ConfigRealm{$key}->{'regex'} if (defined $pf::config::ConfigRealm{$key}->{'regex'} && $pf::config::ConfigRealm{$key}->{'regex'} ne '');
+            $$authorize_ldap_choice .= <<"EOT";
+        $if (Realm =~ /$choice/) {
+            $pf::config::ConfigRealm{$key}->{'ldap_source_ttls_pap'}
+            update control {
+                Auth-Type := $pf::config::ConfigRealm{$key}->{'ldap_source_ttls_pap'}
+            }
+        }
+EOT
+            $if = 'elsif';
+            $$authentication_ldap_auth_type .= <<"EOT";
+        Auth-Type $pf::config::ConfigRealm{$key}->{ldap_source_ttls_pap} {
+            $pf::config::ConfigRealm{$key}->{ldap_source_ttls_pap}
+        }
+EOT
+
+        }
+        if (defined($pf::config::ConfigRealm{$key}->{edir_source}) && exists($pf::config::ConfigRealm{$key}->{edir_source})) {
+            $choice = $pf::config::ConfigRealm{$key}->{'regex'} if (defined $pf::config::ConfigRealm{$key}->{'regex'} && $pf::config::ConfigRealm{$key}->{'regex'} ne '');
+            $edir_config .= <<"EOT";
+            $of (Realm =~ /$choice/) {
+                -$pf::config::ConfigRealm{$key}->{edir_source}
+                if (updated) {
+                    update control {
+                        &MS-CHAP-Use-NTLM-Auth := No
+                    }
+                }
+            }
+EOT
+            my $of = 'elsif';
+        }
+    }
+    if ($edir_config ne "") {
+        $$edir_configuration .= << "EOT"
+        update control {
+            Cache-Status-Only = 'yes'
+        }
+        cache_password
+        if (ok) {
+            update control {
+                &MS-CHAP-Use-NTLM-Auth := No
+            }
+        }
+        if (notfound) {
+$edir_config
+        }
+        cache_password
+EOT
+    }
+}
+
+sub generate_multi_domain_constants {
+    my $data = {};
+    my ($status, $iter) = pf::dal::tenant->search();
+    if (is_error($status)) {
+        die "Unable to fetch tenants to generate the multi-domain constants";
+    }
+    for my $tenant (@{$iter->all}) {
+        my $tenant_id = $tenant->id;
+        pf::config::tenant::set_tenant($tenant_id);
+        $data->{$tenant_id} = {
+            ConfigRealm => { %ConfigRealm }, 
+            ConfigOrderedRealm => [ @ConfigOrderedRealm ],
+            ConfigDomain => { %ConfigDomain }, 
+        };
+    }
+    $Data::Dumper::Purity = 1;
+    my $content = "package multi_domain_constants;\n\n";
+    $content .= "our " . Dumper($data);
+    $content .= "our \$DATA = \$VAR1;\n";
+    $content .= "1;\n";
+    write_file("$install_dir/raddb/mods-config/perl/multi_domain_constants.pm", $content);
 }
 
 =head1 AUTHOR
@@ -1260,7 +1463,7 @@ Inverse inc. <info@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 =head1 LICENSE
 
