@@ -19,6 +19,7 @@ use warnings;
 no warnings 'portable';
 
 use Cwd;
+use Socket;
 use Number::Range;
 use File::Basename;
 use POSIX::2008;
@@ -110,6 +111,9 @@ BEGIN {
         os_detection
         random_from_range
         extract
+        ends_with
+        split_pem
+        resolve
     );
 }
 
@@ -1700,6 +1704,34 @@ sub extract {
     return $default;
 }
 
+sub ends_with {
+    return $_[1] eq substr($_[0], -length($_[1]));
+}
+
+sub split_pem {
+    my ($s) = @_;
+    my @parts;
+    while ($s =~ /-----BEGIN (.*?)-----/g ) {
+        my $type = $1;
+        if ( $s =~ /(.*?)-----END \Q$type\E-----/gs) {
+            push @parts, "-----BEGIN $type-----\n$1-----END $type-----\n";
+        }
+    }
+    return @parts;
+}
+
+sub resolve {
+    my ($name) = @_;
+    my $logger = get_logger;
+    my @addresses = gethostbyname($name);
+    unless(@addresses) {
+        $logger->error("Unable to resolve $name");
+        return undef;
+    }
+    @addresses = map { inet_ntoa($_) } @addresses[4 .. $#addresses];
+    return \@addresses;
+}
+
 =back
 
 =head1 AUTHOR
@@ -1710,7 +1742,7 @@ Minor parts of this file may have been contributed. See CREDITS.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2005-2020 Inverse inc.
+Copyright (C) 2005-2021 Inverse inc.
 
 Copyright (C) 2005 Kevin Amorin
 
